clear all
set more off
set maxvar 32767
set matsize 11000
capture log close _all

global working_dir	${Projectfolder}/work_files/
global account_dir	${Projectfolder}/account_rating/
global staff_dir	${project_data}/Projectfolder/tea/peims/staff/
global rdd_output	${working_dir}/rdd_output/
global LPM_success	${working_dir}/LPM_success/
*This script is the visual and iv analysis of the principals RDD for small, medium, and large campuses



***************On/Off Switch for parts of the analysis On=1 Off=0***************

*Set Bandwidths
local bandwidths 0

*Polynomial Variables
local polyvars 0

*RD analysis at Acceptable Boundary
local acceptable_RDD 0


*****************Bandwidths and Polynomial Interactions*****************
if `bandwidths'==1{

*load data for elementary and middle school principals
use ${working_dir}consistent_sample_gp, clear

*merge in the ratings_all.dta to get prior year ratings for all campuses
merge 1:1 campus year using ${account_dir}ratings_all, nogen keep(match)

*restrict sample to years after >=2001
keep if year>=2001

*round binding scores
replace acc_bind=round(acc_bind, 0.01)
replace rec_bind=round(rec_bind, 0.01)
replace exe_bind=round(exe_bind, 0.01)

****** Make variables for pct change salary to use in RD reg loops ******
	gen sal=st_pgrowth_total
	gen sal_2=st_pgrowth_total2
	gen adjsal=st_pgrowth_adj_total
	gen adjsal_2=st_pgrowth_adj_total2
	
	gen l_total_2yr=log(total_2yr)
	gen l_adj_total_pay=log(adj_total_pay)
	gen l_adj_total_2yr=log(adj_total_2yr)
	
	*changes in log salary measures
	gen dl_total_2yr=l_total_2yr-l_total_pay
	gen dl_adj_total_2yr=l_adj_total_2yr-l_adj_total_pay
	
	*change in acheivement/working conditions
	gen d_predict_pass_2yr=l2_st_predict_pass-st_predict_pass
	replace d_predict_pass_2yr=. if dl_adj_total_2yr==.

*Use rdbwselect to determine optimal bandwidths
preserve
*naming convention: `runningvar'_`bandwidthtype'bw_`outcometype'
			* acc2_CCTbw_a1 -> acc_bind2=runningvar; CCTbw= Calonico, Cattaneo, & Titiunik; a1=success_a1
			* adding _2 to the end signifies second year outcomes
			
	*Acceptable boundary
		keep if acc_bind>=-10 & acc_bind<=10
	*we don't want to count ratings higher than acceptable as failures
		replace acceptable=1 if c_rating2>=101

		*select for first stage
		
			rdbwselect acceptable acc_bind, c(0) p(1) kernel(tri) bwselect(mserd) vce(cluster acc_bind)
			gen acc_bw_tri=e(h_mserd)
			
			rdbwselect acceptable acc_bind, c(0) p(1) kernel(uni) bwselect(mserd) vce(cluster acc_bind)
			gen acc_bw_uni=e(h_mserd)
			
	saveold ${working_dir}acclin_elem_mid_RDD_sample_bw_taks, replace 
	
restore, preserve
	*Recognized boundary
		keep if rec_bind>=-10 & rec_bind<=10
	*we don't want to count ratings higher than acceptable as failures
		replace recognized=1 if c_rating2>=102
		
		*select for first stage
		
			rdbwselect recognized rec_bind, c(0) p(1) kernel(tri) bwselect(mserd) vce(cluster rec_bind)
			gen rec_bw_tri=e(h_mserd)
			
			rdbwselect recognized rec_bind, c(0) p(1) kernel(uni) bwselect(mserd) vce(cluster rec_bind)
			gen rec_bw_uni=e(h_mserd)
			
	saveold ${working_dir}reclin_elem_mid_RDD_sample_bw_taks, replace 
				
restore	
	*Exemplary boundary
		keep if exe_bind>=-10 & exe_bind<=10
	*we don't want to count ratings higher than acceptable as failures
		replace exemplary=1 if c_rating2>=103
		
		*select for first stage
		
			rdbwselect exemplary exe_bind, c(0) p(1) kernel(tri) bwselect(mserd) vce(cluster exe_bind)
			gen exe_bw_tri=e(h_mserd)
			
			rdbwselect exemplary exe_bind, c(0) p(1) kernel(uni) bwselect(mserd) vce(cluster exe_bind)
			gen exe_bw_uni=e(h_mserd)
			
	saveold ${working_dir}exelin_elem_mid_RDD_sample_bw_taks, replace 			
			
*Mark samples using band width estimates
*Acceptable
use ${working_dir}acclin_elem_mid_RDD_sample_bw_taks, clear

foreach i in acc {
	foreach j in tri uni {
		gen `i'_`j'=1 if `i'_bind>=(0-`i'_bw_`j') & `i'_bind<=`i'_bw_`j'
	}
}

saveold ${working_dir}acclintri_elem_mid_RDD_sample_bw_taks, replace
*Recognized
use ${working_dir}reclin_elem_mid_RDD_sample_bw_taks, clear

foreach i in rec {
	foreach j in tri uni {
		gen `i'_`j'=1 if `i'_bind>=(0-`i'_bw_`j') & `i'_bind<=`i'_bw_`j'
	}
}

saveold ${working_dir}reclintri_elem_mid_RDD_sample_bw_taks, replace
*exemplary
use ${working_dir}exelin_elem_mid_RDD_sample_bw_taks, clear

foreach i in exe {
	foreach j in tri uni {
		gen `i'_`j'=1 if `i'_bind>=(0-`i'_bw_`j') & `i'_bind<=`i'_bw_`j'
	}
}

saveold ${working_dir}exelintri_elem_mid_RDD_sample_bw_taks, replace


}




if `polyvars'==1{
*Acceptable
use ${working_dir}acclintri_elem_mid_RDD_sample_bw_taks, clear
*create squared running variable and interactions 
drop *_above
drop *_below

gen	acc_above=0
replace acc_above=1 if acc_bind>=0

gen acc_bind_sq=acc_bind^2

gen acc_above_bind=acc_above*acc_bind

gen acc_above_bind_sq=acc_above*acc_bind_sq

saveold ${working_dir}acclintri_elem_mid_RDD_sample_bw_poly_taks, replace

*Recognized
use ${working_dir}reclintri_elem_mid_RDD_sample_bw_taks, clear
*create squared running variable and interactions 
drop *_above
drop *_below

gen	rec_above=0
replace rec_above=1 if rec_bind>=0

gen rec_bind_sq=rec_bind^2

gen rec_above_bind=rec_above*rec_bind

gen rec_above_bind_sq=rec_above*rec_bind_sq

saveold ${working_dir}reclintri_elem_mid_RDD_sample_bw_poly_taks, replace

*Exemplary
use ${working_dir}exelintri_elem_mid_RDD_sample_bw_taks, clear
*create squared running variable and interactions 
drop *_above
drop *_below

gen	exe_above=0
replace exe_above=1 if exe_bind>=0

gen exe_bind_sq=exe_bind^2

gen exe_above_bind=exe_above*exe_bind

gen exe_above_bind_sq=exe_above*exe_bind_sq

saveold ${working_dir}exelintri_elem_mid_RDD_sample_bw_poly_taks, replace
}



*****************Acceptable RDD*****************
if `acceptable_RDD'==1{

*Schools not rated unacceptable
use ${working_dir}acclintri_elem_mid_RDD_sample_bw_poly_taks, clear
	*keep the schools not rated unacceptable
		drop if c_rating2_1==100

*save log file of RD results
log using ${working_dir}ACC_RDDlog_NoUnacc.txt, replace text

*These are optimal bandwidths calculated for uniform and triangular kernel density estimation
	*acc_bw_uni=3.46
	*acc_bw_tri=3.82


********************************************Retained 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust retained2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_ret2_NoUnacc.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_ret2_NoUnacc.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust retained2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_ret2_NoUnacc.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_ret2_NoUnacc.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace



eststo clear
*trianglular kernel ITT with covariates
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) covs(sex black hispanic master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) covs(sex black hispanic master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
//eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) covs(sex black hispanic other master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) covs(sex black hispanic master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)

eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) covs(sex black hispanic master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
 //not unacceptable
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) covs(sex black hispanic master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_ret2_NoUnacc_wcovs.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace



log close


********************************************************************************************************************************************************************************************
*Schools rated unacceptable
use ${working_dir}acclintri_elem_mid_RDD_sample_bw_poly_taks, clear
	*keep the schools rated unacceptable
		keep if c_rating2_1==100

*save log file of RD results
log using ${working_dir}ACC_RDDlog_Unacc.txt, replace text

*These are optimal bandwidths calculated for uniform and triangular kernel density estimation
	*acc_bw_uni=3.46
	*acc_bw_tri=3.82

********************************************Retained 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust retained2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_ret2_Unacc.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_ret2_Unacc.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust retained2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_ret2_Unacc.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_ret2_Unacc.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*trianglular kernel ITT with covariates
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) covs(sex black hispanic master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) covs(sex black hispanic master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
//eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) covs(sex black hispanic other master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) covs(sex black hispanic master doctorate tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
/*
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) covs(sex black hispanic experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
*/ //unacceptable
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) covs(sex black hispanic tenure2 experyrs share_male share_black share_hisp share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_ret2_Unacc_wcovs.csv, b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace



log close


}



