clear all
set more off
set maxvar 32767
set matsize 11000
capture log close _all

global working_dir	${Projectfolder}/work_files/
global account_dir	${Projectfolder}/account_rating/
global staff_dir	${project_data}/Projectfolder/tea/peims/staff/
global rdd_output	${working_dir}/rdd_output/
global LPM_success	${working_dir}/LPM_success/

*This script makes the RDD figures for the principals paper. 
*These figures will span a bandwidth of 10 percentage points to either side of the ratings thresholds
	*Estimates will also be calculated using local linear regressions and rectangular(uniform) kernel densities 



************ON/OFF switches************
local firststage 1 /* make Figure 2 */
local ittfigures 1 /* make Figures 3, 4, 5, and A2 */
local covfigures 1 /* balance test RD figures that are not in final version of paper */
local mcdensity  1 /* make Figuer A1 */
***************************************

***********Define locals for loops***********
local outcomes "success_a2_2 retained2 successin2 movein2 successout2 sal_2 leave2 dl_total_2yr d_predict_pass_2yr" 
	*since salary growth isn't a probability I make figures outside of the loops
local c_covars  "share_black share_white share_hisp share_disadv share_gifted share_speced"
local p_covars1 "black white hispanic bachelor master doctor sex"
local p_covars2 "tenure2 experyrs"
*********************************************

*load data for elementary and middle school principals
use ${working_dir}consistent_sample_gp, clear

*restrict sample to years after >=2001
keep if year>=2001

*round binding scores
	replace acc_bind=round(acc_bind, 0.01)
	replace rec_bind=round(rec_bind, 0.01)
	replace exe_bind=round(exe_bind, 0.01)

*need to make interaction of running variable and indicator for above threshold
	gen a_above_bind=acc_above*acc_bind
	gen r_above_bind=rec_above*rec_bind
	gen e_above_bind=exe_above*exe_bind

****** Make variables for pct change salary to use in RD reg loops ******
	gen sal=st_pgrowth_total
	gen sal_2=st_pgrowth_total2
	gen adjsal=st_pgrowth_adj_total
	gen adjsal_2=st_pgrowth_adj_total2
	
	gen l_total_2yr=log(total_2yr)
	gen l_adj_total_pay=log(adj_total_pay)
	gen l_adj_total_2yr=log(adj_total_2yr)
	
	*changes in log salary measures
	gen dl_total_2yr=l_total_2yr-l_total_pay
	gen dl_adj_total_2yr=l_adj_total_2yr-l_adj_total_pay
		*we want to make sure that samples are consisten between unadjusted an adjusted salary changes
		replace dl_total_2yr=. if dl_adj_total_2yr==.
		
	*change in acheivement/working conditions
	gen d_predict_pass_2yr=l2_st_predict_pass-st_predict_pass
	replace d_predict_pass_2yr=. if dl_adj_total_2yr==.

preserve

*FIRST STAGE FIGURES	
if `firststage'==1 {	
	*Acceptable boundary
	keep if acc_bind>=-10 & acc_bind<=10
		*we don't want to count ratings higher than acceptable as failures
		replace acceptable=1 if c_rating2>=101
		
	*First stage figure 
		
		*First we run the first stage regression
			reg acceptable acc_above acc_bind a_above_bind, vce(cluster district)
			
			*Now predict probability of acceptable and the standard errors of predictions
				predict pr_acceptable, xb
				predict se_pr_acceptable, stdp
				
			*Make upper and lower 95% CI of predictions
				gen lo95=pr_acceptable-(1.96*se_pr_acceptable)
				gen hi95=pr_acceptable+(1.96*se_pr_acceptable)
				
		*Now create binned average probability of higher rating
			egen bins=cut(acc_bind), at(-10(0.5)10)
			bys bins: egen pr_acc=mean(acceptable)
			bys bins: gen bin_N=_N
			
		*Put everything together into one graph
			line pr_acceptable acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
			line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
			line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
			line pr_acceptable acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
			line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
			line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
			scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
			graphregion(col(white)) ///
			legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
			xtitle("Acceptable Running Variable") ytitle("Probability of Acceptable")
			
			graph export ${rdd_output}Figures/acc_first_10.png, width(4800) replace
			
			scatter pr_acc bins
			
restore, preserve
			
	*Recognized boundary
	keep if rec_bind>=-10 & rec_bind<=10
		*we don't want to count ratings higher than acceptable as failures
		replace recognized=1 if c_rating2>=102

	*First stage figure 
		
		*First we run the first stage regression
			reg recognized rec_above rec_bind r_above_bind, vce(cluster district)
			
			*Now predict probability of acceptable and the standard errors of predictions
				predict pr_recognized, xb
				predict se_pr_recognized, stdp
				
			*Make upper and lower 95% CI of predictions
				gen lo95=pr_recognized-(1.96*se_pr_recognized)
				gen hi95=pr_recognized+(1.96*se_pr_recognized)
				
		*Now create binned average probability of higher rating
			egen bins=cut(rec_bind), at(-10(0.5)10)
			bys bins: egen pr_rec=mean(recognized)
			bys bins: gen bin_N=_N
			
		*Put everything together into one graph
			line pr_recognized rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
			line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
			line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
			line pr_recognized rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
			line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
			line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
			scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
			graphregion(col(white)) ///
			legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
			xtitle("Recognized Running Variable") ytitle("Probability of Recognized")	
			
			graph export ${rdd_output}Figures/rec_first_10.png, width(4800) replace
			
restore, preserve
			
	*Exemplary boundary
	keep if exe_bind>=-10 & exe_bind<=10
		*we don't want to count ratings higher than acceptable as failures
		replace exemplary=1 if c_rating2>=103
	
	*First stage figure 
		
		*First we run the first stage regression
			reg exemplary exe_above exe_bind e_above_bind, vce(cluster district)
			
			*Now predict probability of acceptable and the standard errors of predictions
				predict pr_exemplary, xb
				predict se_pr_exemplary, stdp
				
			*Make upper and lower 95% CI of predictions
				gen lo95=pr_exemplary-(1.96*se_pr_exemplary)
				gen hi95=pr_exemplary+(1.96*se_pr_exemplary)
				
		*Now create binned average probability of higher rating
			egen bins=cut(exe_bind), at(-10(0.5)10)
			bys bins: egen pr_exe=mean(exemplary)
			bys bins: gen bin_N=_N
			
		*Put everything together into one graph
			line pr_exemplary exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
			line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
			line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
			line pr_exemplary exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
			line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
			line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
			scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
			graphregion(col(white)) ///
			legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
			xtitle("Exemplary Running Variable") ytitle("Probability of Exemplary")		

			graph export ${rdd_output}Figures/exe_first_10.png, width(4800) replace
			
restore, preserve

}


*ITT FIGURES
if `ittfigures'==1 {

	*Acceptable boundary

		foreach var in `outcomes' {
		
				keep if acc_bind>=-10 & acc_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace acceptable=1 if c_rating2>=101
		
		*Run ITT regs and make figures
			if `var'!=sal_2 {
				
				if `var'==retained2 {
					local y="Probability of Retention"
				}
				if `var'==leave2 {
					local y="Probability of Exit"
				}
				if `var'!=leave2 & `var'!=retained2 {
					local y="Probability"
				}
			
				*Dichotamous Outcomes
					reg `var' acc_above acc_bind a_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(acc_bind), at(-10(0.5)10)
					bys bins: egen pr_acc=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
					line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line pr_`var' acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
					line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Acceptable Running Variable") ytitle("`y'")
			
					graph export ${rdd_output}Figures/acc_itt_`var'_10.png, width(4800) replace
			
					restore, preserve
			}
			
			if `var'==sal_2 {
				*Continuous Outcomes
					reg `var' acc_above acc_bind a_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(acc_bind), at(-10(0.5)10)
					bys bins: egen pr_acc=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
					line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line pr_`var' acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
					line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-.2(.05).2) ///
					xtitle("Acceptable Running Variable") ytitle("Percent Change")
			
					graph export ${rdd_output}Figures/acc_itt_`var'_10.png, width(4800) replace
			
					restore, preserve
			}
			
			
			if `var'==dl_total_2yr {
			
					keep if acc_bind>=-10 & acc_bind<=10
					*we don't want to count ratings higher than acceptable as failures
					replace acceptable=1 if c_rating2>=101
				*Continuous Outcomes
					reg `var' acc_above acc_bind a_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(acc_bind), at(-10(0.5)10)
					bys bins: egen pr_acc=mean(`var')
					bys bins: gen bin_N=_N
			
			
				*Put everything together into one graph
					line pr_`var' acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
					line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line pr_`var' acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
					line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-0.1(.05)0.1) ///
					xlabel(-10(5)10) ///
					xtitle("Acceptable Running Variable") ytitle("Change in Log Salary")
			
					graph export ${rdd_output}Figures/acc_itt_chlsal_10.png, width(4800) replace
			
					restore, preserve
			}
			
			if `var'==d_predict_pass_2yr {
			
					keep if acc_bind>=-10 & acc_bind<=10
					*we don't want to count ratings higher than acceptable as failures
					replace acceptable=1 if c_rating2>=101
				*Continuous Outcomes
					reg `var' acc_above acc_bind a_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(acc_bind), at(-10(0.5)10)
					bys bins: egen pr_acc=mean(`var')
					bys bins: gen bin_N=_N
			
			
				*Put everything together into one graph
					line pr_`var' acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
					line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line pr_`var' acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
					line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-0.5(.25)0.5) ///
					xlabel(-10(5)10) ///
					xtitle("Acceptable Running Variable") ytitle("Change in Student Composition")
			
					graph export ${rdd_output}Figures/acc_itt_chach_10.png, width(4800) replace
			
					restore, preserve
			}
			
		}	
		
		
	*Recognized boundary

		foreach var in `outcomes' {
		
				keep if rec_bind>=-10 & rec_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace recognized=1 if c_rating2>=102
		
		*Run ITT regs and make figures
			if `var'!=sal_2 {
				
				if `var'==retained2 {
					local y="Probability of Retention"
				}
				if `var'==leave2 {
					local y="Probability of Exit"
				}
				if `var'!=leave2 & `var'!=retained2 {
					local y="Probability"
				}
			
				*Dichotamous Outcomes
					reg `var' rec_above rec_bind r_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(rec_bind), at(-10(0.5)10)
					bys bins: egen pr_rec=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
					line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line pr_`var' rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
					line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Recognized Running Variable") ytitle("`y'")
			
					graph export ${rdd_output}Figures/rec_itt_`var'_10.png, width(4800) replace
			
					restore, preserve
			}
			
			if `var'==sal_2 {
				*Continuous Outcomes
					reg `var' rec_above rec_bind r_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(rec_bind), at(-10(0.5)10)
					bys bins: egen pr_rec=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
					line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line pr_`var' rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
					line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-.2(.05).2) ///
					xtitle("Recognized Running Variable") ytitle("Percent Change")
			
					graph export ${rdd_output}Figures/rec_itt_`var'_10.png, width(4800) replace
			
					restore, preserve
			}
			
			if `var'==dl_total_2yr {
			
					keep if rec_bind>=-10 & rec_bind<=10
					*we don't want to count ratings higher than acceptable as failures
					replace recognized=1 if c_rating2>=102
				*Continuous Outcomes
					reg `var' rec_above rec_bind r_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(rec_bind), at(-10(0.5)10)
					bys bins: egen pr_rec=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
					line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line pr_`var' rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
					line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-.1(.05).1) ///
					xtitle("Recognized Running Variable") ytitle("Change in Log Salary")
			
					graph export ${rdd_output}Figures/rec_itt_chlsal_10.png, width(4800) replace
			
					restore, preserve
			}
			
			if `var'==d_predict_pass_2yr {
			
					keep if rec_bind>=-10 & rec_bind<=10
					*we don't want to count ratings higher than acceptable as failures
					replace recognized=1 if c_rating2>=102
				*Continuous Outcomes
					reg `var' rec_above rec_bind r_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(rec_bind), at(-10(0.5)10)
					bys bins: egen pr_rec=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
					line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line pr_`var' rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
					line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-0.5(.25)0.5) ///
					xtitle("Recognized Running Variable") ytitle("Change in Student Composition")
			
					graph export ${rdd_output}Figures/rec_itt_chach_10.png, width(4800) replace
			
					restore, preserve
			}
			
		}	
		
		
	*Exemplary boundary

		foreach var in `outcomes' {
		
				keep if exe_bind>=-10 & exe_bind<=10
			
		
		*Run ITT regs and make figures
			if `var'!=sal_2 {
				
				if `var'==retained2 {
					local y="Probability of Retention"
				}
				if `var'==leave2 {
					local y="Probability of Exit"
				}
				if `var'!=leave2 & `var'!=retained2 {
					local y="Probability"
				}
			
				*Dichotamous Outcomes
					reg `var' exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_`var' exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) xlabel(-10(5)10) ///
					xtitle("Exemplary Running Variable") ytitle("`y'")
			
					graph export ${rdd_output}Figures/exe_itt_`var'_10.png, width(4800) replace
			
					restore, preserve
			}
			
			if `var'==sal_2 {
				*Continuous Outcomes
					reg `var' exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_`var' exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-.2(.05).2) ///
					xtitle("Exemplary Running Variable") ytitle("Percent Change")
			
					graph export ${rdd_output}Figures/exe_itt_`var'_10.png, width(4800) replace
			
					restore, preserve
			}
			
			if `var'==dl_total_2yr {
			
					keep if exe_bind>=-10 & exe_bind<=10
					
				*Continuous Outcomes
					reg `var' exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_`var' exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-.1(.05).1) ///
					xtitle("Exemplary Running Variable") ytitle("Change in Log Salary")
			
					graph export ${rdd_output}Figures/exe_itt_chlsal_10.png, width(4800) replace
			
					restore, preserve
			}
			
			if `var'==d_predict_pass_2yr {
			
					keep if exe_bind>=-10 & exe_bind<=10
					
				*Continuous Outcomes
					reg `var' exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_`var' exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-0.5(.25)0.5) ///
					xtitle("Exemplary Running Variable") ytitle("Change in Student Composition")
			
					graph export ${rdd_output}Figures/exe_itt_chach_10.png, width(4800) replace
			
					restore, preserve
			}
			
		}	
		
		keep if exe_bind>=-10 & exe_bind<=10
			
				*Dichotamous Outcomes
					reg retained2 exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_retained2, xb
					predict se_pr_retained2, stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_retained2-(1.96*se_pr_retained2)
					gen hi95=pr_retained2+(1.96*se_pr_retained2)
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(retained2)
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_retained2 exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_retained2 exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Exemplary Running Variable") ytitle("Probability of Retention")
			
					graph export ${rdd_output}Figures/exe_itt_retained2_10.png, width(4800) replace
			
					restore, preserve
			

}
				

*COVAR FIGURES
if `covfigures'==1 {

	*Acceptable boundary
		*Campus Covariates
		foreach var in `c_covars' {
		
				keep if acc_bind>=-10 & acc_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace acceptable=1 if c_rating2>=101
			
		
			*Run covar regs and make figures
				reg `var' acc_above acc_bind a_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(acc_bind), at(-10(0.5)10)
					bys bins: egen pr_acc=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
					line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line pr_`var' acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
					line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Acceptable Running Variable") ytitle("Share")
			
					graph export ${rdd_output}Figures/acc_cvar_`var'_10.png, replace
			
					restore, preserve
					
			}

					
		*Principal Dichotamous Covariates
		foreach var in `p_covars1' {
		
				keep if acc_bind>=-10 & acc_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace acceptable=1 if c_rating2>=101
		
			*Run covar regs and make figures
				reg `var' acc_above acc_bind a_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(acc_bind), at(-10(0.5)10)
					bys bins: egen pr_acc=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
					line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line pr_`var' acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
					line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Acceptable Running Variable") ytitle("Probability")
			
					graph export ${rdd_output}Figures/acc_cvar_`var'_10.png, replace
			
					restore, preserve
			}
			
		*Principal Continuous Covariates
		foreach var in `p_covars2' {
		
				keep if acc_bind>=-10 & acc_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace acceptable=1 if c_rating2>=101
		
			*Run covar regs and make figures
				reg `var' acc_above acc_bind a_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(acc_bind), at(-10(0.5)10)
					bys bins: egen pr_acc=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
					line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line pr_`var' acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
					line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(5)25) ///
					xtitle("Acceptable Running Variable") ytitle("Years")
			
					graph export ${rdd_output}Figures/acc_cvar_`var'_10.png, replace
			
					restore, preserve
			}
			
			
		*Principal FE quality measure
				keep if NPs>1
			
				keep if acc_bind>=-10 & acc_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace acceptable=1 if c_rating2>=101
		
			*Run covar regs and make figures
				reg st_asyfe2 acc_above acc_bind a_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_st_syfe2, xb
					predict se_pr_st_syfe2, stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_st_syfe2-(1.96*se_pr_`var')
					gen hi95=pr_st_syfe2+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(acc_bind), at(-10(0.5)10)
					bys bins: egen pr_acc=mean(st_asyfe2)
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_st_syfe2 acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
					line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line pr_st_syfe2 acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
					line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
					scatter pr_acc bins [w=bin_N], msymbol(circle_hollow) msize(tiny) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-.5(.25).5) ///
					xtitle("Acceptable Running Variable") ytitle("Principal FE")
			
					graph export ${rdd_output}Figures/acc_cvar_st_syfe2_10.png, replace
			
					restore, preserve
			

	*Recognized boundary
		*Campus Covariates
		foreach var in `c_covars' {
		
				keep if rec_bind>=-10 & rec_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace recognized=1 if c_rating2>=102
		
			*Run covar regs and make figures
				reg `var' rec_above rec_bind r_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(rec_bind), at(-10(0.5)10)
					bys bins: egen pr_rec=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
					line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line pr_`var' rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
					line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Recognized Running Variable") ytitle("Share")
			
					graph export ${rdd_output}Figures/rec_cvar_`var'_10.png, replace
			
					restore, preserve
			}
			
		*Principal Dichotamous Covariates
		foreach var in `p_covars1' {
		
				keep if rec_bind>=-10 & rec_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace recognized=1 if c_rating2>=102
		
			*Run covar regs and make figures
				reg `var' rec_above rec_bind r_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(rec_bind), at(-10(0.5)10)
					bys bins: egen pr_rec=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
					line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line pr_`var' rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
					line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Recognized Running Variable") ytitle("Probability")
			
					graph export ${rdd_output}Figures/rec_cvar_`var'_10.png, replace
			
					restore, preserve
			}
			
		*Principal Continuous Covariates
		foreach var in `p_covars2' {
		
				keep if rec_bind>=-10 & rec_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace recognized=1 if c_rating2>=102
		
			*Run covar regs and make figures
				reg `var' rec_above rec_bind r_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(rec_bind), at(-10(0.5)10)
					bys bins: egen pr_rec=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
					line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line pr_`var' rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
					line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(5)25) ///
					xtitle("Recognized Running Variable") ytitle("Years")
			
					graph export ${rdd_output}Figures/rec_cvar_`var'_10.png, replace
			
					restore, preserve
			}
			
			
		*Principal FE quality measure
				keep if NPs>1
			
				keep if rec_bind>=-10 & rec_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace recognized=1 if c_rating2>=102
		
			*Run covar regs and make figures
				reg st_asyfe2 rec_above rec_bind r_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_st_syfe2, xb
					predict se_pr_st_syfe2, stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_st_syfe2-(1.96*se_pr_`var')
					gen hi95=pr_st_syfe2+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(rec_bind), at(-10(0.5)10)
					bys bins: egen pr_rec=mean(st_asyfe2)
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_st_syfe2 rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
					line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line pr_st_syfe2 rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
					line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
					scatter pr_rec bins [w=bin_N], msymbol(circle_hollow) msize(small) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-.5(.25).5) ///
					xtitle("Recognized Running Variable") ytitle("Principal FE")
			
					graph export ${rdd_output}Figures/rec_cvar_st_syfe2_10.png, replace
			
					restore, preserve			
			
	
	*Exemplary boundary
		*Campus Covariates
		foreach var in `c_covars' {
		
				keep if exe_bind>=-10 & exe_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace exemplary=1 if c_rating2>=103
		
			*Run covar regs and make figures
				reg `var' exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_`var' exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Exemplary Running Variable") ytitle("Share")
			
					graph export ${rdd_output}Figures/exe_cvar_`var'_10.png, replace
			
					restore, preserve
			}
			
		*Principal Dichotamous Covariates
		foreach var in `p_covars1' {
		
				keep if exe_bind>=-10 & exe_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace exemplary=1 if c_rating2>=103
		
			*Run covar regs and make figures
				reg `var' exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_`var' exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(.2)1) ///
					xtitle("Exemplary Running Variable") ytitle("Probability")
			
					graph export ${rdd_output}Figures/exe_cvar_`var'_10.png, replace
			
					restore, preserve
			}
			
		*Principal Continuous Covariates
		foreach var in `p_covars2' {
		
				keep if exe_bind>=-10 & exe_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace exemplary=1 if c_rating2>=103
		
			*Run covar regs and make figures
				reg `var' exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_`var', xb
					predict se_pr_`var', stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_`var'-(1.96*se_pr_`var')
					gen hi95=pr_`var'+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(`var')
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_`var' exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_`var' exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(0(5)25) ///
					xtitle("Exemplary Running Variable") ytitle("Years")
			
					graph export ${rdd_output}Figures/exe_cvar_`var'_10.png, replace
			
					restore, preserve
			}
			
			
		*Principal FE quality measure
				keep if NPs>1
			
				keep if exe_bind>=-10 & exe_bind<=10
			*we don't want to count ratings higher than acceptable as failures
				replace exemplary=1 if c_rating2>=103
		
			*Run covar regs and make figures
				reg st_asyfe2 exe_above exe_bind e_above_bind, vce(cluster district)
					*outreg2 using ${rdd_output}itt_test.xls, replace 
			
				*Now predict probability of acceptable and the standard errors of predictions
					predict pr_st_syfe2, xb
					predict se_pr_st_syfe2, stdp
				
				*Make upper and lower 95% CI of predictions
					gen lo95=pr_st_syfe2-(1.96*se_pr_`var')
					gen hi95=pr_st_syfe2+(1.96*se_pr_`var')
				
				*Now create binned average probability of higher rating
					egen bins=cut(exe_bind), at(-10(0.5)10)
					bys bins: egen pr_exe=mean(st_asyfe2)
					bys bins: gen bin_N=_N
			
				*Put everything together into one graph
					line pr_st_syfe2 exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
					line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line pr_st_syfe2 exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
					line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
					scatter pr_exe bins [w=bin_N], msymbol(circle_hollow) msize(vsmall) ///
					graphregion(col(white)) ///
					legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
					ylabel(-.5(.25).5) ///
					xtitle("Exemplary Running Variable") ytitle("Principal FE")
			
					graph export ${rdd_output}Figures/exe_cvar_st_syfe2_10.png, replace
			
					restore, preserve			
			
		
}	


*MCCRARY FIGURES
if `mcdensity'==1 {

	*Acceptable boundary
		*only want obs within 10 percentage points of the threshold
			keep if acc_bind>=-10 & acc_bind<=10
		*we don't want to count ratings higher than acceptable as failures
			replace acceptable=1 if c_rating2>=101
			
			/*DCdensity acc_bind, breakpoint(0) generate(Xj Yj r0 fhat se_fhat) graphname(${rdd_output}Figures/acc_mcdens_10.png)
			

			*Brute force the DCdensity results in memory to make a prettier graph
			local breakpoint 0
			local cellmpname Xj
			local cellvalname Yj
			local evalname r0
			local cellsmname fhat
			local cellssename se_fhat
			*drop if `cellmpname'<-10 | `cellmpname'>10
			*drop if `evalname'<-10 | `evalname'>10
			tempvar hi
			quietly gen `hi'=`cellsmname' + 1.96*`cellssename'
			tempvar lo
			quietly gen `lo'=`cellsmname' - 1.96*`cellssename'
				scatter `cellvalname' `cellmpname', msymbol(circle_hollow) mcolor(gray) || ///
				line `cellsmname' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(medthick) || ///
				line `cellsmname' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(medthick) || ///
				line `hi' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `lo' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `hi' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `lo' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(vthin) xline(`breakpoint', lcolor(red)) ///
				legend(off) graphregion(col(white)) xlabel(-10(5)10) xtitle("Acceptable Running Variable") ytitle("Density")
				
			graph export ${rdd_output}Figures/acc_mcdens_10.png, replace
			
			drop Xj Yj r0 fhat se_fhat
			restore, preserve
			*/
			
		
		*make a linear figure with fitted line
		keep if acc_bind>=-10 & acc_bind<=10
		*we don't want to count ratings higher than acceptable as failures
		replace acceptable=1 if c_rating2>=101
		
		*make bins
		egen bins=cut(acc_bind), at(-10(0.25)10)
		bys bins: gen pr_acc=_N
		gen total=_N
		bys bins: gen pr_acc2=pr_acc/total
		
		*First we run the first stage regression
			reg pr_acc2 acc_above acc_bind a_above_bind, vce(cluster district)
			
			*Now predict probability of acceptable and the standard errors of predictions
				predict pr_acceptable, xb
				predict se_pr_acceptable, stdp
				
			*Make upper and lower 95% CI of predictions
				gen lo95=pr_acceptable-(1.96*se_pr_acceptable)
				gen hi95=pr_acceptable+(1.96*se_pr_acceptable)
				
		*Now keep one obs per bin
			bys bins: gen bin_N=_N
			
			bys bins: keep if _n==1
			egen total_temp=total(pr_acc2)
			tab total_temp
			
			//dfsdfsfd
			
		*Put everything together into one graph
			line pr_acceptable acc_bind if acc_bind<0, xline(0, lcolor(red)) col(black) sort(acc_bind) || ///
			line hi95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
			line lo95 acc_bind if acc_bind<0, col(black) lpattern(shortdash) sort(acc_bind) || ///
			line pr_acceptable acc_bind if acc_bind>=0, col(black) sort(acc_bind) || /// 
			line hi95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
			line lo95 acc_bind if acc_bind>=0, col(black) lpattern(shortdash) sort(acc_bind) || ///
			scatter pr_acc2 bins, msymbol(circle) ///
			graphregion(col(white)) ///
			ylabel(0(.01).05) ///
			legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
			xtitle("Acceptable Running Variable") ytitle("Share of Campuses")
			
			graph export ${rdd_output}Figures/acc_princbyrunvar_wfl_gp.png, width(4800) replace
			
		*make a plain old scatter plot
			
			scatter pr_acc2 bins, xline(0) msymbol(circle) ///
			graphregion(col(white)) ///
			ylabel(0(.01).05) ///
			xtitle("Acceptable Running Variable") ytitle("Share of Campuses")
			
			graph export ${rdd_output}Figures/acc_princbyrunvar_gp.png, width(4800) replace
		
		restore, preserve
			
	*Recognized boundary
		*only want obs within 10 percentage points of the threshold
			keep if rec_bind>=-10 & rec_bind<=10
		*we don't want to count ratings higher than acceptable as failures
			replace recognized=1 if c_rating2>=102
		
			/*DCdensity rec_bind, breakpoint(0) generate(Xj Yj r0 fhat se_fhat) graphname(${rdd_output}Figures/rec_mcdens_10.png)
			
		*do it again for optimal bandwidth
			*keep if rec_bind>=-2.490613 & rec_bind<=2.490613
			*DCdensity rec_bind, breakpoint(0) generate(Xj Yj r0 fhat se_fhat)
			
			*Brute force the DCdensity results in memory to make a prettier graph
			local breakpoint 0
			local cellmpname Xj
			local cellvalname Yj
			local evalname r0
			local cellsmname fhat
			local cellssename se_fhat
			*drop if `cellmpname'<-10 | `cellmpname'>10
			*drop if `evalname'<-10 | `evalname'>10
			tempvar hi
			quietly gen `hi'=`cellsmname' + 1.96*`cellssename'
			tempvar lo
			quietly gen `lo'=`cellsmname' - 1.96*`cellssename'
				scatter `cellvalname' `cellmpname', msymbol(circle_hollow) mcolor(gray) || ///
				line `cellsmname' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(medthick) || ///
				line `cellsmname' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(medthick) || ///
				line `hi' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `lo' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `hi' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `lo' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(vthin) xline(`breakpoint', lcolor(red)) ///
				legend(off) graphregion(col(white)) xlabel(-10(5)10) xtitle("Recognized Running Variable") ytitle("Density")
				
			graph export ${rdd_output}Figures/rec_mcdens_10.png, replace
			
			drop Xj Yj r0 fhat se_fhat
			restore, preserve
		*/
		
		*make a linear figure with fitted line
		keep if rec_bind>=-10 & rec_bind<=10
		*we don't want to count ratings higher than acceptable as failures
		replace recognized=1 if c_rating2>=102
		
		*make bins
		egen bins=cut(rec_bind), at(-10(0.25)10)
		bys bins: gen pr_rec=_N
		gen total=_N
		bys bins: gen pr_rec2=pr_rec/total
		
		*First we run the first stage regression
			reg pr_rec2 rec_above rec_bind r_above_bind, vce(cluster district)
			
			*Now predict probability of acceptable and the standard errors of predictions
				predict pr_acceptable, xb
				predict se_pr_acceptable, stdp
				
			*Make upper and lower 95% CI of predictions
				gen lo95=pr_acceptable-(1.96*se_pr_acceptable)
				gen hi95=pr_acceptable+(1.96*se_pr_acceptable)
				
		*Now keep one obs per bin
			bys bins: gen bin_N=_N
			
		*Put everything together into one graph
			line pr_acceptable rec_bind if rec_bind<0, xline(0, lcolor(red)) col(black) sort(rec_bind) || ///
			line hi95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
			line lo95 rec_bind if rec_bind<0, col(black) lpattern(shortdash) sort(rec_bind) || ///
			line pr_acceptable rec_bind if rec_bind>=0, col(black) sort(rec_bind) || /// 
			line hi95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
			line lo95 rec_bind if rec_bind>=0, col(black) lpattern(shortdash) sort(rec_bind) || ///
			scatter pr_rec2 bins, msymbol(circle) ///
			graphregion(col(white)) ///
			ylabel(0(.01).05) ///
			legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
			xtitle("Recognized Running Variable") ytitle("Share of Campuses")
			
			graph export ${rdd_output}Figures/rec_princbyrunvar_wfl_gp.png, width(4800) replace
			
		*make a plain old scatter plot
			
			scatter pr_rec2 bins, xline(0) msymbol(circle) ///
			graphregion(col(white)) ///
			ylabel(0(.01).05) ///
			xtitle("Recognized Running Variable") ytitle("Share of Campuses")
			
			graph export ${rdd_output}Figures/rec_princbyrunvar_gp.png, width(4800) replace
		
		restore, preserve
					
	*Exemplary boundary
		*only want obs within 10 percentage points of the threshold
			keep if exe_bind>=-10 & exe_bind<=10
		*we don't want to count ratings higher than acceptable as failures
			replace exemplary=1 if c_rating2>=103
		
			/*DCdensity exe_bind, breakpoint(0) generate(Xj Yj r0 fhat se_fhat) graphname(${rdd_output}Figures/exe_mcdens_10.png)
		
		*do it again with optimal bandwidth
			*keep if exe_bind>=-3.255753 & exe_bind<=3.255753
			*DCdensity exe_bind, breakpoint(0) generate(Xj Yj r0 fhat se_fhat)
			
			
			*Brute force the DCdensity results in memory to make a prettier graph
			local breakpoint 0
			local cellmpname Xj
			local cellvalname Yj
			local evalname r0
			local cellsmname fhat
			local cellssename se_fhat
			*drop if `cellmpname'<-10 | `cellmpname'>10
			*drop if `evalname'<-10 | `evalname'>10
			tempvar hi
			quietly gen `hi'=`cellsmname' + 1.96*`cellssename'
			tempvar lo
			quietly gen `lo'=`cellsmname' - 1.96*`cellssename'
				scatter `cellvalname' `cellmpname', msymbol(circle_hollow) mcolor(gray) || ///
				line `cellsmname' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(medthick) || ///
				line `cellsmname' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(medthick) || ///
				line `hi' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `lo' `evalname' if `evalname' < `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `hi' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(vthin) || ///
				line `lo' `evalname' if `evalname' >= `breakpoint', lcolor(black) lwidth(vthin) xline(`breakpoint', lcolor(red)) ///
				legend(off) graphregion(col(white)) xlabel(-10(5)10) xtitle("Exemplary Running Variable") ytitle("Density")
				
			graph export ${rdd_output}Figures/exe_mcdens_10.png, replace
			
			drop Xj Yj r0 fhat se_fhat
			restore, preserve
			*/
		
		*make a linear figure with fitted line
		keep if exe_bind>=-10 & exe_bind<=10
		*we don't want to count ratings higher than acceptable as failures
		replace exemplary=1 if c_rating2>=103
		
		*make bins
		egen bins=cut(exe_bind), at(-10(0.25)10)
		bys bins: gen pr_exe=_N
		gen total=_N
		bys bins: gen pr_exe2=pr_exe/total
		
		*First we run the first stage regression
			reg pr_exe2 exe_above exe_bind e_above_bind, vce(cluster district)
			
			*Now predict probability of acceptable and the standard errors of predictions
				predict pr_acceptable, xb
				predict se_pr_acceptable, stdp
				
			*Make upper and lower 95% CI of predictions
				gen lo95=pr_acceptable-(1.96*se_pr_acceptable)
				gen hi95=pr_acceptable+(1.96*se_pr_acceptable)
				
		*Now keep one obs per bin
			bys bins: gen bin_N=_N
			
		*Put everything together into one graph
			line pr_acceptable exe_bind if exe_bind<0, xline(0, lcolor(red)) col(black) sort(exe_bind) || ///
			line hi95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
			line lo95 exe_bind if exe_bind<0, col(black) lpattern(shortdash) sort(exe_bind) || ///
			line pr_acceptable exe_bind if exe_bind>=0, col(black) sort(exe_bind) || /// 
			line hi95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
			line lo95 exe_bind if exe_bind>=0, col(black) lpattern(shortdash) sort(exe_bind) || ///
			scatter pr_exe2 bins, msymbol(circle) ///
			graphregion(col(white)) ///
			ylabel(0(.01).05) ///
			legend(on order(1 2) label(1 "Fitted Values") label(2 "95% CI")) ///
			xtitle("Exemplary Running Variable") ytitle("Share of Campuses")
			
			graph export ${rdd_output}Figures/exe_princbyrunvar_wfl_gp.png, width(4800) replace
			
		*make a plain old scatter plot
			
			scatter pr_exe2 bins, xline(0) msymbol(circle) ///
			graphregion(col(white)) ///
			ylabel(0(.01).05) ///
			xtitle("Exemplary Running Variable") ytitle("Share of Campuses")
			
			graph export ${rdd_output}Figures/exe_princbyrunvar_gp.png, width(4800) replace
		
		restore, preserve			

}	
