/*

This is a master do file that replcates the analysis of principal performance and labor market returns. 
Researchers wishing to replicate these analyses need to get an approved project from the Education 
Research Center at The University of Texas at Dallas, University of Texas at Austin, or University of Houston.

Directories should be set up as follows: 

Projectfolder
	-dofiles 				"STATA do files are stored here"
	-work_files				"Intermediate data files and output will be stored here"
		-RDD_output			
			-Figures
		-LPM_success
	-account_rating			"Publicly available school accountabiliy data available from the Texas Education Agency (TEA.gov) are stored here"
Project_data				"This folder will follow internal structure of the Education Research Center databases"

*/


******Run do files in this order******

*1) pub_accountability.do. 
	*This file will assemble publicly available accountabiliy rating data for further analysis
	do pub_accountability.dofiles

*2)	AYP_data.dofiles
	*This file will assemble publicy available AYP data for Texas public schools
	do AYP_data.do
	
*3) all_sbyfes.do
	*Once you assemble a panel of student by year data that of demographics, standardized math and reading scores, schools, districts, and principal IDs this will compute school-by-year value added measures to attribute to principals
	do all_sbyfes.do
	
*4) sby_averages.do
	*Uses infomration from all_sbyfes.do to compute average principal value added measure over their spell as principal in a campus
	do sby_averages.do
	
*5) VA_validity_t1.do
	*Tests valididy of Value added measures and produces information in column 1 of Table 3
	do VA_validity_t1.do 
	
*6) VA_validity_t2.do 
	*Tests valididy of Value added measures and produces information in column 2 of Table 3
	do VA_validity_t2.do
	
*7) principal_marginal_data.do
	*Builds principal level data set for analysis and produces information for Table 1
	*Runs nested do files
		*adjusted_salary.do 
		*pub_marginalgroups.do 
		*pub_enrollment.do 
		*predicted_achievement.do  -this files also produces information for Table A1
		*connected_networks.do
		*ratings.do  
	do principal_marginal_data.do 
	
*8) perform_distrib_mlogit.do 
	*This file takes analysis sample and produces Figure 1, and Tables 1, 2, 8, A2, and A3
	do perform_distrib_mlogit.do 
	
*9) RD_analysis.do
	*Run basic Regression discontinuity models and produce estimates in tables 4-7, and A7-A18
	do RD_analysis.do 
	
*10) RD_analysis_withcovars.do
	*Run additional Regression discontinuity models that include campus level covariates and produce estimates in tables 4-7, and A7-A18
	do RD_analysis_withcovars.do 
	
*11) PrUnacc_RD_analysis.do 
	*Run Regression discontinuity models for campuses that were previously rated as Unacceptable. Produces estimates in Table A9
	do PrUnacc_RD_analysis.do 
	
*12) RD_figures.do 
	*Produce figures for regression discontinuity analysis: Figures 2-5, A1, and A2
	do RD_figures.do 