	clear all
	set more off
	set maxvar 32000
	set matsize 11000

/*  SET GLOBAL MACROS  */
	global working_dir	${Projectfolder}/working_data

/*  LOAD AND CLEAN DATA  */

	use "${working_dir}/analysis_data.dta", clear
	

	tostring campus, generate(campus_str)
	replace campus_str = "0" + campus_str if length(campus_str) ==8
	replace campus_str = "00" + campus_str if length(campus_str) ==7

	*district isn't fully populated for all observations, but campus is
	*we can substring the campus varaiable to get the district
	drop district
	gen district = substr(campus_str, 1, 6)
	destring district, replace
	
	*I WANT TO CREATE A VALUE ADDED MEASURE FOR EACH PRINCIPAL CAMPUS COMBINATION
	*group campus and principalid(newid)
	sort newid campus year
	egen prcamp=group(newid campus)
	*also want to group campus and year for s-b-y fixed effects
	egen campyr=group(campus year)
	
	*now I want to flag all the first years of each principals spell at a campus
	sort newid campus year prcamp
	bys prcamp: egen temp1=min(year)
	*if the current year is equal to the minimum year of the prcamp variable then it's the first year of the principal's spell
	gen FYS_flag=(year==temp1) 
	
	*do the same thing for the last year of each principals spell at a campus
	sort newid campus year prcamp
	bys prcamp: egen temp2=max(year)
	*if the current year is equal to the maximum year of the prcamp variable then it's the last year of the principal's spell
	gen LYS_flag=(year==temp2) 
	
	*make an annual enrollment variable
	bys campus year: gen n_enrolled=_N
	
*estimate school by year FEs for all
	areg st_ascore l_st_mscore* l_st_rscore* female non_lep non_title1 nata asian black hisp mover special_ed  av_* year#grade if FYS_flag==0, absorb(campyr)
	predict asyfe3, d
	sum asyfe3
	
	*I don't want to accidently keep an observation from an ommitted grade when I collapse the data to one obs per campus-year
	bys campus year: egen casyfe3=max(asyfe3) 
	drop asyfe3 
	rename casyfe3 asyfe3
	
	
	*now keep one observation from each principal(campus) and year combination
	duplicates drop campus year, force
	duplicates drop newid year, force
	
	
	/*these lines are for testing the code below, COMMENT OUT FOR THE REAL DEAL RUN
		use "C:\Users\gphelan\Dropbox\JHR RandR\test_data.dta", clear
		sort newid year
		save "C:\Users\gphelan\Dropbox\JHR RandR\test_data.dta", replace */
	
	*these lines are for the TSP data run, MAKE SURE THEYRE NOT COMMENTED OUT FOR THE REAL DEAL RUN
		save ${Projectfolder}/work_files/sbyfes_gp.dta, replace
	
*track transitions and then see who the principals are on either side of each transition. 
	*Should be able to use the FYS_flag variable to see everytime there is a new principal at a campus_str
	use ${Projectfolder}/work_files/sbyfes_gp.dta, clear
	xtset campus year
	*grab enrollment from 3 years after and 3 years before each transition
		gen f2_enrolled=f2.n_enrolled
		gen l3_enrolled=l3.n_enrolled
	
	*I want to get previous principal and new principal for each transitions
	*new principal is easy
	by campus: gen new_newid=newid if FYS_flag==1
	*get previous principal now
	by campus: gen old_newid=l1.newid if FYS_flag==1
	*order campus year newid FYS_flag new_newid old_newid /*cool, looks like this works too*/
	
	*Now I should be able to keep a file of just the campus, year, new_newid, old_newid, and school-by-year FEs for just the transitions
	*so this will just be a file of transitions. 
	*I should also go ahead and make the differences between school by year FEs before I collapse the data*/
	xtset campus year
	*difference from t-1 to t+1, where t is the first year of the new principal
	by campus: gen dif_sbyfe_l1f1 = (f1.asyfe3 - l1.asyfe3) if FYS_flag==1
	*difference from t-2 to t+1, where t is the first year of the new principal
	by campus: gen dif_sbyfe_l2f1 = (f1.asyfe3 - l2.asyfe3) if FYS_flag==1	
	order campus year FYS_flag dif_sbyfe* new_newid old_newid
	*Later on I want to make a third difference variable here that takes the value of the t-2 to t+1 difference if the previous principal was in the campus 2 years ago. If the previous principal wasnt around 2 years before the transition then it should have the value of the t-1 to t+1 difference. 
	
	*now I want to collapse the data down so it just has one record for each campus transition. 
	*I can use the FYS_flag variable to do this along with a condition that there be a new_newid and old_newid for that year too
		keep if FYS_flag==1 & new_newid!=. & old_newid!=. 
		sort campus year
		save ${Projectfolder}/work_files/principal_transitions_Fall2020_gp.dta, replace
		
	*now save a file with just the new_newid
		preserve 
		keep campus year new_newid  
		rename new_newid newid /*this is so I can match back to the sbyfes tempfile*/
		sort newid year
		save ${Projectfolder}/work_files/newps_data_gp.dta, replace
		
	*now save a file with jus the old_newid
		restore 
		keep campus year old_newid
		rename old_newid newid /*this is so I can match back to the sbyfes tempfile*/
		sort newid year
		*I also need to change year to t-1 so things work out when I calcualte averages
		replace year=(year-1)
		save ${Projectfolder}/work_files/oldps_data_gp.dta, replace
		
		
*now lets tackle the incoming principal side of the transitions
	use ${Projectfolder}/work_files/sbyfes_gp.dta, clear
	merge m:1 newid year using ${Projectfolder}/work_files/newps_data_gp.dta
	gen newtrans=1 if _merge==3
	drop _merge
	
	*I want to compute averages of every school by year FE associated with the new principals that leaves out their first and second year at the new campus_str
	sort newid year 
	xtset newid year
	order newid year campus newtrans FYS_flag
	*I need to make sure newtrans=1 for the first 2 years after each new transition
	by newid: replace newtrans=1 if (l1.newtrans==1 & l1.FYS_flag==1) /* This works */
	bys newid campus: egen VA_new_newid=mean(asyfe3) if newtrans!=1 /*works correctly on test data*/
	*need to populate the variable for just the transiton year
		*just brute force it. 
		bys newid campus: egen VA_new_newid2=mean(VA_new_newid)
		drop VA_new_newid
		rename VA_new_newid2 VA_new_newid
	*now just keep the transition year so we can merge it back to the Principal transition data file I saved earlier
	sort newid year
	keep campus year VA_new_newid newtrans FYS_flag
	keep if newtrans==1 & FYS_flag==1
	drop newtrans FYS_flag
	*now this file can get merged back to the transition data file
	sort campus year
	merge 1:1 campus year using ${Projectfolder}/work_files/principal_transitions_Fall2020_gp.dta, nogen
	
	*now save again 
	sort campus year
	save ${Projectfolder}/work_files/ptrans_fall2020_wnews_t2_gp.dta, replace
	
*now I need to tackle the average for the old principals for each transitions
	use ${Projectfolder}/work_files/sbyfes_gp.dta, clear
	merge 1:1 newid year using ${Projectfolder}/work_files/oldps_data_gp.dta
	gen oldtrans=1 if _merge==3
	drop _merge
	duplicates drop campus year, force
	xtset campus year
	by campus: gen temp3=1 if newid==l1.newid & oldtrans==1 /* I have to l1.newid here bc ive already subtracted 1 from each year for this dataset */
	sort newid year
	xtset newid year
	by newid: replace temp3=1 if newid==f1.newid & f1.temp3==1 & f1.oldtrans==1
	*okay so this works the way i wanted it to, i'll make means for all observations where temp3!=1
	
	sort newid year 
	*their mean if they only were at the campus for 1 year
	bys newid campus: egen VA_old_newid1=mean(asyfe3)
	*their mean if they were at the campus for more than 2 year
	bys newid campus: egen VA_old_newid2=mean(asyfe3) if temp3!=1 /* this works on the test data */
	*need to populate the variable for just the transiton year
		*just brute force it. 
		bys newid campus: egen VA_old_newid2_2=mean(VA_old_newid2)
		drop VA_old_newid2
		rename VA_old_newid2_2 VA_old_newid2
	*now just keep the transition year so we can merge it back to the Principal transition data file I saved earlier
	*I have to remember to change year from t-1 back to t though
	order campus year VA_old_newid* oldtrans temp3 LYS_flag
	keep campus year VA_old_newid* oldtrans
	keep if oldtrans==1 
	*change year back to the real year of the transition by adding 1
		replace year=year+1
	*now make a third VA_old_newid variable that has the average VA if the old principal only served one year, but the average minus their last year if they served more than one year
		gen VA_old_newid=VA_old_newid1
		replace VA_old_newid=VA_old_newid2 if VA_old_newid1!=VA_old_newid2 & VA_old_newid2!=. 
			/* added the last condition so I don't accidently replace the variable with missing values */
			/* it shouldn't happen anyway, but the test data didn't have an example where it would happen */
	*now this file can get merged back to the transition file that includes the new principal averages. 
	sort campus year
	merge 1:1 campus year using ${Projectfolder}/work_files/ptrans_fall2020_wnews_t2_gp.dta, nogen
	
	*now save again 
	sort campus year
	save ${Projectfolder}/work_files/ptrans_fall2020_wnews_wolds_t2_gp.dta, replace
	
*now I want to make a third difference variable here that takes the value of the t-2 to t+1 difference if the previous principal was in the campus 2 years ago. If the previous principal wasnt around 2 years before the transition then it should have the value of the t-1 to t+1 difference. 
	*gen dif_sbyfe=dif_sbyfe_l1f1  
	*replace dif_sbyfe=dif_sbyfe_l2f1 if VA_old_newid1!=VA_old_newid2 & VA_old_newid2!=.
	*order dif_sbyfe*  /* works on the test data */
	
*make differences in average principal VA variables
	*gen Pr_dif_1 = VA_new_newid - VA_old_newid1
	gen Pr_dif_2 = VA_new_newid - VA_old_newid2
	*gen Pr_dif = VA_new_newid - VA_old_newid
	
*compute average enrollment across the period for weighted regressions
	egen avg_enrolled=rowmean(l3_enrolled f2_enrolled) 
	replace avg_enrolled=round(avg_enrolled)	
	
*Now I can run all the validity regressions. 
	*t-2 to t_1
	reg dif_sbyfe_l2f1 Pr_dif_2, robust
	outreg2 using ${Projectfolder}/work_files/LPM_success/New_ValueAdded_Validity_t2_gp.xls, replace keep(Pr_dif_2) addtext(Year Indicators, No, Enrollment Weight, No) dec(3)
	
	reg dif_sbyfe_l2f1 Pr_dif_2 [fw=avg_enrolled], robust
	outreg2 using ${Projectfolder}/work_files/LPM_success/New_ValueAdded_Validity_t2_gp.xls, append keep(Pr_dif_2) addtext(Year Indicators, No, Enrollment Weight, Yes) dec(3)
	
	*everything with year effects
	*t-2 to t_1
	reg dif_sbyfe_l2f1 Pr_dif_2 i.year, robust
	outreg2 using ${Projectfolder}/work_files/LPM_success/New_ValueAdded_Validity_t2_gp.xls, append keep(Pr_dif_2) addtext(Year Indicators, No, Enrollment Weight, No) dec(3)
	
	reg dif_sbyfe_l2f1 Pr_dif_2 i.year [fw=avg_enrolled], robust
	outreg2 using ${Projectfolder}/work_files/LPM_success/New_ValueAdded_Validity_t2_gp.xls, append keep(Pr_dif_2) addtext(Year Indicators, No, Enrollment Weight, Yes) dec(3)
	
	
	
	
