*This file takes the estimation sample and creates adjusted income 

clear all
set more off
set maxvar 32767
set matsize 11000
capture log close _all

global working_dir	${Projectfolder}/work_files/
global account_dir	${Projectfolder}/account_rating/
global staff_dir	${project_data}/Projectfolder/tea/peims/staff/
global rdd_output	${working_dir}/rdd_output/
global LPM_success	${working_dir}/LPM_success/


*start with the sample of principals 
	use ${working_dir}RDD_sample_05_2016, clear
	
	*now keep one observation per pid/ssnrep
		bys ssnrep: keep if _n==1
		
	*now just keep ssnrep
		keep ssnrep
		
	*now this file is just a list of principals in our sample
		saveold ${working_dir}princ_list, replace
		
	
*now get the principals_panel data
	use ${working_dir}principals_panel, clear
	
	*merge with princ_list and keep matches
	merge m:1 ssnrep using ${working_dir}princ_list, nogen keep(match)
	
	*keep if year>=2001
	keep if year>=2001
	
	tab year
	
*need to get campus and district demographics and campus achievment data merged in
	*achievment 
	merge m:1 campus year using ${account_dir}pred_achievement, nogen keep(master match)
	*campus demogs
	merge m:1 campus year using ${account_dir}campdemogs, nogen keep(master match)
	*district demogs
	merge m:1 district year using ${account_dir}distdemogs, nogen keep(master match)
	
	duplicates drop
	
*use cpi info to calculate real salary
	gen cpi=.
	replace cpi=152.4 if year==1995
	replace cpi=156.9 if year==1996
	replace cpi=160.5 if year==1997
	replace cpi=163.0 if year==1998
	replace cpi=166.6 if year==1999
	replace cpi=172.2 if year==2000
	replace cpi=177.1 if year==2001
	replace cpi=179.9 if year==2002
	replace cpi=184.0 if year==2003
	replace cpi=188.9 if year==2004
	replace cpi=195.3 if year==2005
	replace cpi=201.6 if year==2006
	replace cpi=207.342 if year==2007
	replace cpi=215.303 if year==2008
	replace cpi=214.537 if year==2009
	replace cpi=218.056 if year==2010
	replace cpi=224.939 if year==2011
	
	*calculate real wages in 2003 dollars using cpi
	gen base_pay =(basepay/fte)*(184.0/cpi)
		label variable base_pay "Base Pay 2003 dollars"
	gen total_pay=(totalpay/fte)*(184.0/cpi)
		label variable total_pay "Total Pay 2003 dollars"
	gen l_base_pay=log(base_pay)
		label variable l_base_pay "Log Base Pay 2003 dollars"
	gen l_total_pay=log(total_pay)
		label variable l_total_pay "Log Total Pay 2003 dollars"
	gen supp_pay =total_pay-base_pay
		label variable supp_pay "Supplemental Pay 2003 dollars"
	gen l_supp_pay=log(supp_pay)
		label variable l_supp_pay "Log Supplemental Pay 2003 dollars"
	
*keep full time employees and drop any remaining duplicates 
	keep if fte==1
	
	*duplicates drop ssnrep campus year role, force
	
*create indicators for campus and district employees
	gen indcamp=(assigrp==1)
	gen inddist=1-indcamp
	
	
*now lets run these adjusted salary regressions 
	cd ${working_dir}/
	
	local cgroups "disadv asian black hisp white speced gifted lep passred passmth pass"
	local dgroups "disadv asian black hisp white speced gifted lep"
	
	*make campus share variables zero for those working in district position and vice versa 
	*this is just to make sure we aren't throwing out observations because stata thinks they are missing information when we run the salary regs
	foreach i in `cgroups' {
		replace share_`i'=0 if inddist==1
	}
	foreach i in `dgroups' {
		replace dshare_`i'=0 if indcamp==1
	}
	
	*campus interaction variables 
	foreach i in `cgroups' {
		gen c_share_`i'=indcamp * share_`i'
	}	
	
	*district interaction variables 
	foreach i in `dgroups' {
		gen d_share_`i'=inddist * dshare_`i'
	}
	
	*save data to merge back with parameter estimates 
	saveold ${working_dir}princ_list2, replace
	
	local cvars "c_share_disadv c_share_asian c_share_black c_share_hisp c_share_white c_share_speced c_share_gifted c_share_lep c_share_passred c_share_passmth"
	local dvars "d_share_disadv d_share_asian d_share_black d_share_hisp d_share_white d_share_speced d_share_gifted d_share_lep"
	
	areg total_pay `cvars' `dvars', absorb(district) vce(robust)
	
	parmest, format(estimate) saving(adj_sal, replace)
	
	use adj_sal, clear
	
	keep parm estimate
	
	gen group="e"

	reshape wide est, i(group) j(parm) string
	
	drop group
	
	saveold ${working_dir}adj_sal_est, replace
	
*now merge the adj_sal_est data with princ_list2 data
	use ${working_dir}princ_list2, clear
	append using ${working_dir}adj_sal_est
	
	*make the estimate* consitent across all observations
	local allvars "_cons c_share_disadv c_share_asian c_share_black c_share_hisp c_share_white c_share_speced c_share_gifted c_share_lep c_share_passred c_share_passmth d_share_disadv d_share_asian d_share_black d_share_hisp d_share_white d_share_speced d_share_gifted d_share_lep"
	
	foreach i in `allvars' {
		egen est`i'=max(estimate`i')
	}
	
	drop estimate*
	drop if ssnrep==.
	
	gen adj_total_pay=total_pay - (estc_share_disadv*c_share_disadv + estc_share_asian*c_share_asian + estc_share_black*c_share_black + estc_share_hisp*c_share_hisp + estc_share_white*c_share_white + estc_share_speced*c_share_speced + estc_share_gifted*c_share_gifted + estc_share_lep*c_share_lep + estc_share_passred*c_share_passred + estc_share_passmth*c_share_passmth + estd_share_disadv*d_share_disadv + estd_share_asian*d_share_asian + estd_share_black*d_share_black + estd_share_hisp*d_share_hisp + estd_share_white*d_share_white + estd_share_speced*d_share_speced + estd_share_gifted*d_share_gifted + estd_share_lep*d_share_lep)
	
	*now just keep ssnrep year adj_total_pay
	keep ssnrep campus year role adj_total_pay
	
	duplicates tag ssnrep year, gen(dup1)
	drop if dup1>0
	drop dup1

	
*save data
	saveold ${working_dir}adj_salary_data, replace
	
	*now this data can be merged in the principal_marginal_data_rnd2 do file
