	clear all
	set more off
	set maxvar 32000
	set matsize 11000

/*  SET GLOBAL MACROS  */
	global working_dir	${Projectfolder}/working_data

/*  LOAD AND CLEAN DATA  */

	use "${working_dir}/analysis_data.dta", clear

	*need to do some work to create a district variable from the campus information
	tostring campus, generate(campus_str)
	replace campus_str = "0" + campus_str if length(campus_str) ==8
	replace campus_str = "00" + campus_str if length(campus_str) ==7

	*district isn't fully populated for all observations, but campus is
	*we can substring the campus varaiable to get the district
	drop district
	gen district = substr(campus_str, 1, 6)
	destring district, replace
	
	*I WANT TO CREATE A VALUE ADDED MEASURE FOR EACH PRINCIPAL CAMPUS COMBINATION
	*group campus and principalid(newid)
	sort newid campus year
	egen prcamp=group(newid campus)
	*also want to group campus and year for s-b-y fixed effects
	egen campyr=group(campus year)
	
	*now I want to flag all the first years of each principals spell at a campus
	sort newid campus year prcamp
	bys prcamp: egen temp1=min(year)
	*if the current year is equal to the minimum year of the prcamp variable then it's the first year of the principal's spell
	gen FYS_flag=(year==temp1) 
	
	*do the same thing for the last year of each principals spell at a campus
	sort newid campus year prcamp
	bys prcamp: egen temp2=max(year)
	*if the current year is equal to the maximum year of the prcamp variable then it's the last year of the principal's spell
	gen LYS_flag=(year==temp2) 
	
	*make an annual enrollment variable
	bys campus year: gen n_enrolled=_N
	
*estimate school by year FEs for all
	gen byte touse=.
	markout touse l_st_mscore l_st_mscore2 l_st_mscore3 l_st_rscore l_st_rscore2 l_st_rscore3 female non_lep non_title1 nata asian black hisp mover special_ed av_female av_non_lep av_non_title1 av_nata av_asian av_black av_hisp av_mover av_special_ed
	keep if touse!=0
	areg st_ascore l_st_mscore l_st_mscore2 l_st_mscore3 l_st_rscore l_st_rscore2 l_st_rscore3 female non_lep non_title1 nata asian black hisp mover special_ed av_female av_non_lep av_non_title1 av_nata av_asian av_black av_hisp av_mover av_special_ed i.year#i.grade if touse!=0, absorb(campyr)
	predict resids, residuals
	predict dresids, dresiduals
	gen asyfe4 = dresids - resids
	sum asyfe4
	
	*I don't want to accidently keep an observation from an ommitted grade when I collapse the data to one obs per campus-year
	bys campus year: egen casyfe4=max(asyfe4) 
	drop asyfe4 
	rename casyfe4 asyfe4
	
	duplicates drop campus year, force
	duplicates drop newid year, force
	
	
	/*these lines are for testing the code below, COMMENT OUT FOR THE REAL DEAL RUN
		use "C:\Users\gphelan\Dropbox\JHR RandR\test_data.dta", clear
		sort newid year
		save "C:\Users\gphelan\Dropbox\JHR RandR\test_data.dta", replace */
	*these lines are for the TSP data run, MAKE SURE THEYRE NOT COMMENTED OUT FOR THE REAL DEAL RUN
		
		
save ${Projectfolder}/work_files/allsybfes_gp.dta, replace
		
sort campus year
xtset campus year

gen asyfe4_p2=F2.asyfe4
gen asyfe4_p3=F3.asyfe4

sort campus year

keep campus year asyfe4 asyfe4_p2 asyfe4_p3

save ${Projectfolder}/work_files/allsybfes_projections.dta, replace
