*LPM of success on ratings and va

clear all
set more off
set maxvar 32767
set matsize 11000
capture log close _all

global working_dir	${Projectfolder}/work_files/
global account_dir	${Projectfolder}/account_rating/
global staff_dir	${project_data}/Projectfolder/tea/peims/staff/
global rdd_output	${working_dir}/rdd_output/
global LPM_success	${working_dir}/LPM_success/

*On/Off switches
local kdensfigs 0 /* This section generates Figure 1 */
local shareouts 0 
local summarytab 0 /* This section completes Tables 1 and 2 */ 
local mlogit 0 /* This section generates results in Table 8*/
local pfeshares 0 /* This section generates data for Tables A2 and A3 */
*On/Off switches

*get principal data, make sure we are using the ..._Jan2020_1210 data
	use ${working_dir}RDD_sample_05_2016_taks_Jan2020_1210, clear
	
*create leave variable
	gen leave=0
	replace leave=1 if transition==4
	gen leave2=0 
	replace leave2=1 if transition2==4
	
*creates tenure dummies
	gen ten1=0
	replace ten1=1 if tenure2==1
	gen ten2=0
	replace ten2=1 if tenure2==2
	gen ten3=0
	replace ten3=1 if tenure2==3
	gen ten4=0
	replace ten4=1 if tenure2>=4
	
*make campus groups for fixed effects
	egen school=group(campus)
	egen distfe=group(district)
	egen distyr=group(district year)
	
*make squared and cubic polynomial terms for pass rates
	gen schmth_sqr=passmath^2
	gen schmth_cub=passmath^3
	gen schmth_qrt=passmath^4
	gen schred_sqr=passread^2
	gen schred_cub=passread^3
	gen schred_qrt=passread^4
	
	*egen passrate=rowmean(passread passmath)
	gen passrate2=passrate^2
	gen passrate3=passrate^3
	gen passrate4=passrate^4
	replace passrate =round(passrate, 0.01)
	replace passrate2=round(passrate2, 0.01)
	replace passrate3=round(passrate3, 0.01)
	replace passrate4=round(passrate4, 0.01)
	
	egen passrate_1=rowmean(cschmthrate_1 cschredrate_1)
	replace passrate_1 =round(passrate_1, 0.01)
	*replace passrate_1 = passrate_1/100
	
*make difference in pass rate variable
	gen dpassrate=passrate-passrate_1 if passrate!=. & passrate_1!=.
	
*create locals for independent variables
	local ratingdum	"unacceptable recognized exemplary"
	local tendum 	"tendum3 tendum4 experyrs"
	local ethndum	"sex black hispanic white "
	local degreedum	"master doctorate"
	local studshare "share_male share_black share_hisp share_white share_disadv share_title1 share_lep share_speced share_gifted share_mover"
	local PRs	"passrate"
	local PRs2	"passmath passread"
	local PRs_sqr	"passrate2"
	local PRs_cub	"passrate3"
	local PRs_qrt	"passrate4"
	
*define outcomes
gen retained=0
replace retained=1 if transition==1
gen retained2=0
replace retained2=1 if transition2==1
*any successful move
gen othersucc=0
replace othersucc=1 if transition!=1 & success_a2==1
gen othersucc2=0
replace othersucc2=1 if transition2!=1 & success_a2_2==1
*within district success
gen successin=0
replace successin=1 if success_a2==1 & district==district_1yr
gen movein=0
replace movein=1 if othersucc==1 & district==district_1yr & transition!=1 & transition!=4
gen successin2=0
replace successin2=1 if success_a2_2==1 & district==district_2yr
gen movein2=0
replace movein2=1 if othersucc2==1 & district==district_2yr & transition2!=1 & transition2!=4
*out of district success
gen successout=0
replace successout=1 if success_a2==1 & district!=district_1yr & leave!=1
gen moveout=0
replace moveout=1 if othersucc==1 & district!=district_1yr & transition!=1 & transition!=4
gen successout2=0
replace successout2=1 if success_a2_2==1 & district!=district_2yr & leave2!=1
gen moveout2=0
replace moveout2=1 if othersucc2==1 & district!=district_2yr & transition2!=1 & transition2!=4
*no success
gen nosuccess=0
replace nosuccess=1 if success_a2_2==0
gen nosuccess2=0
replace nosuccess2=1 if success_a2_2==0

*outcome for mlogits
gen outcome1=0
replace outcome1=1 if successin==1
replace outcome1=2 if successout==1
gen outcome1_2=0
replace outcome1_2=1 if successin2==1
replace outcome1_2=2 if successout2==1

gen outcome2=0
replace outcome2=1 if retained==1
replace outcome2=2 if movein==1
replace outcome2=3 if moveout==1
gen outcome2_2=0
replace outcome2_2=1 if retained2==1
replace outcome2_2=2 if movein2==1
replace outcome2_2=3 if moveout2==1

gen outcome3=0
replace outcome3=1 if retained==1
replace outcome3=2 if othersucc==1
gen outcome3_2=0
replace outcome3_2=1 if retained2==1
replace outcome3_2=2 if othersucc2==1

gen outcome4=0
replace outcome4=1 if retained==1 /*retained*/
replace outcome4=2 if outcome2==2 /*success move in*/
replace outcome4=3 if success_a2==0 & district_1yr==district & (role_1yr!=4 | role_1yr!=27 | role_1yr!=40 | role_1yr!=20) /*unsuccesful demotion in*/
replace outcome4=4 if success_a2==0 & district_1yr==district & role_1yr==role & retained!=1 /*other unsuccessful in*/
replace outcome4=5 if outcome2==3 /*success move out*/
replace outcome4=6 if success_a2==0 & district_1yr!=district & (role_1yr!=4 | role_1yr!=27 | role_1yr!=40 | role_1yr!=20) /*unsuccesful demotion out*/
replace outcome4=7 if success_a2==0 & district_1yr!=district & role_1yr==role & retained!=1 /*other unsuccessful out*/
replace outcome4=8 if leave==1

gen outcome4_2=0
replace outcome4_2=1 if retained2==1 /*retained*/
replace outcome4_2=2 if outcome2_2==2 /*success move in*/
replace outcome4_2=3 if success_a2_2==0 & district_2yr==district & (role_2yr!=4 | role_2yr!=27 | role_2yr!=40 | role_2yr!=20) /*unsuccesful demotion in*/
replace outcome4_2=4 if success_a2_2==0 & district_2yr==district & role_2yr==role & retained!=1 /*other unsuccessful in*/
replace outcome4_2=5 if outcome2_2==3 /*success move out*/
replace outcome4_2=6 if success_a2_2==0 & district_2yr!=district & (role_2yr!=4 | role_2yr!=27 | role_2yr!=40 | role_2yr!=20) /*unsuccesful demotion out*/
replace outcome4_2=7 if success_a2_2==0 & district_2yr!=district & role_2yr==role & retained2!=1 /*other unsuccessful out*/
replace outcome4_2=8 if leave2==1

gen     outcome5=0 if outcome4==8 /*leave TPS*/
replace outcome5=1 if outcome4==1 | outcome4==2 /*successful in district*/
replace outcome5=2 if outcome4==3 | outcome4==4 /*unsuccessful move in district*/
replace outcome5=3 if outcome4==5 /*successful move out*/
replace outcome5=4 if outcome4==6 | outcome4==7 /*unsuccessful move out*/

gen     outcome5_2=0 if outcome4_2==8 /*leave TPS*/
replace outcome5_2=1 if outcome4_2==1 | outcome4_2==2 /*successful in district*/
replace outcome5_2=2 if outcome4_2==3 | outcome4_2==4 /*unsuccessful move in district*/
replace outcome5_2=3 if outcome4_2==5 /*successful move out*/
replace outcome5_2=4 if outcome4_2==6 | outcome4_2==7 /*unsuccessful move out*/

keep if dpassrate!=.

replace st_pgrowth_total=. if st_pgrowth_adj_total==.
replace pgrowth_total=. if pgrowth_adj_total==.
replace st_pgrowth_total2=. if st_pgrowth_adj_total2==.
replace pgrowth_total2=. if pgrowth_adj_total2==.



*make outcomes for different types of transitions
	*1 retention
	gen ret2=(role_2yr==role & campus_2yr==campus)
	*2 principal same district
	gen psame2=(role_2yr==20 & district_2yr==district & campus_2yr!=campus)
	*3 Central office same district
	gen coffsame2=(district_2yr==district & inddist_2yr==1)
	*4 Teacher or other campus job below principal same district
	gen campsame2=(district_2yr==district & role_2yr!=20 & inddist_2yr==0)
	*5 Principal New District
	gen pnewd2=(role_2yr==20 & district_2yr!=district)
	*6 Central office new district
	gen coffnew2=(district_2yr!=district & inddist_2yr==1)
	*7 Teacher or other campus below principal new district
	gen campnew2=(district_2yr!=district & role_2yr!=20 & inddist_2yr==0)
	*8 Exit data
	gen exit2=(role_2yr==.)


*merge in the future achievment data for all the campuses
merge 1:1 campus year using ${account_dir}passratepanel, nogen keep(match)

*save data set that is consistent between lpm mlogit and rd analyses
saveold ${working_dir}consistent_sample_gp1, replace

*Run LPM regressions for various measures of success and leaving the sample 


if `kdensfigs'==1 {

use ${working_dir}consistent_sample_gp1, clear

keep if tenure2>=3
keep if meansby!=.

*kdens bw(0.10)
	*school by year FE densities
	kdensity meansby, nograph generate(x fx)
	kdensity meansby if c_rating2==100, nograph generate(fx100) at(x) bw(.07)
	kdensity meansby if c_rating2==101, nograph generate(fx101) at(x) bw(.07)
	kdensity meansby if c_rating2==102, nograph generate(fx102) at(x) bw(.07)
	kdensity meansby if c_rating2==103, nograph generate(fx103) at(x) bw(.07)
	label var fx100 "Unacceptable"
	label var fx101 "Acceptable"
	label var fx102 "Recognized"
	label var fx103 "Exemplary"

	line fx100 fx101 fx102 fx103 x, sort ytitle("Density") xtitle("Spell Mean School-by-Year FE") title("") ///
		clcolor(black black black black) ///
		clpattern(solid shortdash dash_dot longdash ) ///
		xlabel(-1(0.5)1) ///
		legend(on) graphregion(color(white))

	graph export ${LPM_success}/Kdens_msby_new_bw07.png, width(4800) replace
	
	line fx100 fx101 fx102 fx103 x, sort ytitle("Density") xtitle("Spell Mean School-by-Year FE") title("") ///
		clcolor(black black black black) ///
		clpattern(solid shortdash dash_dot longdash ) ///
		xlabel(-1(0.5)1) ///
		legend(on) graphregion(color(white))

	graph save ${LPM_success}/Kdens_msby_new_bw07, replace

	drop fx100 fx101 fx102 fx103 fx x
	
	
	*Pass Rate
	kdensity passrate, nograph generate(x fx)
	kdensity passrate if c_rating2==100, nograph generate(fx100) at(x)
	kdensity passrate if c_rating2==101, nograph generate(fx101) at(x)
	kdensity passrate if c_rating2==102, nograph generate(fx102) at(x)
	kdensity passrate if c_rating2==103, nograph generate(fx103) at(x)
	label var fx100 "Unacceptable"
	label var fx101 "Acceptable"
	label var fx102 "Recognized"
	label var fx103 "Exemplary"

	line fx100 fx101 fx102 fx103 x, sort ytitle("Density") xtitle("Pass Rate") title("") ///
		clcolor(black black black black) ///
		clpattern(solid shortdash dash_dot longdash ) ///
		xlabel(50(25)100) ///
		legend(on) graphregion(color(white))

	graph export ${LPM_success}/Kdens_passrate_new.png, width(4800) replace
	
	line fx100 fx101 fx102 fx103 x, sort ytitle("Density") xtitle("Pass Rate") title("") ///
		clcolor(black black black black) ///
		clpattern(solid shortdash dash_dot longdash ) ///
		xlabel(50(25)100) ///
		legend(on) graphregion(color(white))

	graph save ${LPM_success}/Kdens_passrate_new, replace

	drop fx100 fx101 fx102 fx103 fx x
	
}


if `shareouts'==1 {

	log using ${working_dir}transitiondeets, replace text

	tab ret2 success_a2_2
	
	tab psame2 success_a2_2
	
	tab coffsame2 success_a2_2
	
	tab campsame2 success_a2_2
	
	tab pnewd2 success_a2_2
	
	tab coffnew2 success_a2_2
	
	tab campnew2 success_a2_2
	
	tab exit2 success_a2_2
	
	log close

}


if `summarytab'==1 {

use ${working_dir}consistent_sample_gp1, replace

****** Make variables for pct change salary to use in RD reg loops ******
	gen sal=st_pgrowth_total
	gen sal_2=st_pgrowth_total2
	gen adjsal=st_pgrowth_adj_total
	gen adjsal_2=st_pgrowth_adj_total2
	
	gen l_total_2yr=log(total_2yr)
	gen l_adj_total_pay=log(adj_total_pay)
	gen l_adj_total_2yr=log(adj_total_2yr)
	
	*changes in log salary measures
	gen dl_total_2yr=l_total_2yr-l_total_pay
	gen dl_adj_total_2yr=l_adj_total_2yr-l_adj_total_pay
	
	*change in acheivement/working conditions
	gen d_predict_pass_2yr=l2_st_predict_pass-st_predict_pass
	*replace d_predict_pass_2yr=. if dl_adj_total_2yr==.
	
	*who is a successful move within district from salary growth
	gen movinsal2=(movein2==1 & success2_2==1)
	*who is a successful move to new district from salary growth
	gen movoutsal2=(moveout2==1 & success2_2==1)
	
	*who is an unsuccessful move within district
	gen nomovin2=(district==district_2yr & transition2>=2 & transition2<=3 & district_2yr!=. & success2_2==0 & success4_2==0)
	*who is an unsuccessful move to new district
	gen nomovout2=(district!=district_2yr & transition2>=2 & transition2<=3 & district_2yr!=. & success2_2==0 & success4_2==0)
	
	*who left their district
	gen leavedist2=(district!=district_2yr & district_2yr!=.)
	
	
	*I can make a table of labor market outcome summaries here
	order retained2 movein2 movinsal2 nomovin2 moveout2 movoutsal2 nomovout2 leavedist2 leave2 total_pay dl_total_2yr d_predict_pass_2yr
	outreg2 using ${working_dir}laboroutcomesummary_new.xls, sum(log) eqkeep(N mean sd) dec(3) keep(retained2 movein2 movinsal2 nomovin2 moveout2 movoutsal2 nomovout2 leavedist2 leave2 total_pay dl_total_2yr d_predict_pass_2yr) replace
	keep if tenure2>=3
	keep if meansby!=.
	outreg2 using ${working_dir}laboroutcomesummary_new.xls, sum(log) eqkeep(N mean sd) dec(3) keep(retained2 movein2 movinsal2 nomovin2 moveout2 movoutsal2 nomovout2 leavedist2 leave2 total_pay dl_total_2yr d_predict_pass_2yr) append

	
}


if `mlogit'==1 {
log using ${LPM_success}mlogitlog_new.txt, replace text

use ${working_dir}consistent_sample_gp1, replace

keep if tenure2>=3
keep if meansby!=.


*table 8
qui mlogit outcome1_2 meansby `PRs' `ratingdum' `tendum' `ethndum' `degreedum' `studshare' i.district i.year, vce(cl district) base(0) iter(100)  dif
outreg2 using ${LPM_success}mlogits/avmlogit1_2yr_dfe_new.xls, replace keep(meansby `PRs' unacceptable recognized exemplary) dec(3)
margins, dydx(meansby passrate) 
margins, dydx(unacceptable) at(recognized=0 exemplary=0) 
margins, dydx(recognized) at(unacceptable=0 exemplary=0)
margins, dydx(exemplary) at(unacceptable=0 recognized=0)

log close _all

}


if `pfeshares'==1 {

use ${working_dir}consistent_sample_gp1, replace

keep if tenure2>=3
keep if meansby!=.


	*make quartiles of PFE by year
	bys year: egen y_qtpfe_25=pctile(meansby), p(25)
	bys year: egen y_qtpfe_50=pctile(meansby), p(50)
	bys year: egen y_qtpfe_75=pctile(meansby), p(75)
	gen q4_y_pfe=(meansby>y_qtpfe_75)
	gen q3_y_pfe=(meansby>y_qtpfe_50 & meansby<=y_qtpfe_75)
	gen q2_y_pfe=(meansby>y_qtpfe_25 & meansby<=y_qtpfe_50)
	gen q1_y_pfe=(meansby<=y_qtpfe_25)
	
	
	*make quartiles of PFE with years pooled
	egen p_qtpfe_25=pctile(meansby), p(25)
	egen p_qtpfe_50=pctile(meansby), p(50)
	egen p_qtpfe_75=pctile(meansby), p(75)
	gen q4_p_pfe=(meansby>p_qtpfe_75)
	gen q3_p_pfe=(meansby>p_qtpfe_50 & meansby<=p_qtpfe_75)
	gen q2_p_pfe=(meansby>p_qtpfe_25 & meansby<=p_qtpfe_50)
	gen q1_p_pfe=(meansby<=p_qtpfe_25)
	
	*look at statistics for principals within acceptable bandwidth
	gen tvar2=(acc_bind>=-10 & acc_bind<=10)
	gen tvar3=(acc_bind>=-5 & acc_bind<=5)
	gen tvar4=(acc_bind>=-3.82 & acc_bind<=3.82)
	
	log using ${LPM_success}julie_pfe_qrtiles_new.txt, replace text
	
	*Bandwidth of 10
	sum q*_y_pfe if tvar2==1
	sum q*_p_pfe if tvar2==1
	
	*Bandwidth of 5
	sum q*_y_pfe if tvar3==1
	sum q*_p_pfe if tvar3==1
	
	*Bandwidth of 3.82
	sum q*_y_pfe if tvar4==1
	sum q*_p_pfe if tvar4==1
	
	*average PFE for -10<=acc_bind<0
	sum meansby if tvar2==1 & acc_bind<0
	*average PFE for 0<=acc_bind<=10
	sum meansby if tvar2==1 & acc_bind>=0
	
	*average PFE for -5<=acc_bind<0
	sum meansby if tvar3==1 & acc_bind<0
	*average PFE for 0<=acc_bind<=5
	sum meansby if tvar3==1 & acc_bind>=0
	
	*average PFE for -3.85<=acc_bind<0
	sum meansby if tvar4==1 & acc_bind<0
	*average PFE for 0<=acc_bind<=3.85
	sum meansby if tvar4==1 & acc_bind>=0
	
	log close _all


}

