capture log close
clear all

**************************************************************************************
*Name: principal_data_assembly.do
*Description: Assembles principal level data with running variables, and other campus level info
*Author: Gregory Phelan
**************************************************************************************

set more off
clear
set matsize 11000

global working_dir	${Projectfolder}/work_files/
global account_dir	${Projectfolder}/account_rating/
global staff_dir	${project_data}/tea/peims/staff/
global stud_path	${project_data}/tea/peims/student/
global taks_path	${project_data}/tea/assess/taks/
global taas_path	${project_data}/tea/assess/taas/
global camp_path	${project_data}/peims/organization/campus/
global dist_path	${project_data}/tea/peims/organization/district/


*Start with staff data

forvalues i=1995(1)2011 {
	use ${staff_dir}nonclass/nonclass`i'f, clear
	keep if role==3|role==20
	tab role
	keep ssnrep
	drop if ssnrep==.
	*recast long campus
	*recast long district
	saveold ${working_dir}principals`i', replace
}


*now append all the principalsYYYY files
use ${working_dir}principals1995, clear
forvalues i=1995(1)2011 {
	append using ${working_dir}principals`i'
}

*only need one of each ssnrep
duplicates drop ssnrep, force

*now this file is a list of all individuals who were a principal or assistant principals between 1995 and 2011
saveold ${working_dir}principals1995_2011, replace


*Now we can merge principal characteristics onto the principal list

*start with nonclassYYYY files
forvalues i=1995(1)2011 {
	use ${staff_dir}nonclass/nonclass`i'f, clear
	merge m:1 ssnrep using ${working_dir}principals1995_2011, keep(match) nogen
	keep ssnrep role campus district pfte pbas assigrp
	drop if ssnrep==.
	recast long campus
	recast long district
	saveold ${working_dir}principal_role`i', replace
}


*pick up teacher roles from classYYYY files
forvalues i=1995(1)2011 {
	use ${staff_dir}class/class`i'f, clear
	merge m:1 ssnrep using ${working_dir}principals1995_2011, keep(match) nogen
	keep ssnrep role campus district pfte pbas assigrp
	drop if ssnrep==.
	*just need to keep one observation for each person and role
	bysort ssnrep campus role: keep if _n==1
	recast long campus
	recast long district
	saveold ${working_dir}teacher_role`i', replace
}


*pick up variables from employYYYY files
forvalues i=1995(1)1995 {
	use ${staff_dir}employ/employ`i'f, clear
	merge m:1 ssnrep using ${working_dir}principals1995_2011, keep(match) nogen
	keep ssnrep basepay totalpay tenure daysemp district fte 
	drop if ssnrep==.
	recast long district
	saveold ${working_dir}employ`i', replace
}


forvalues i=1996(1)2011 {
	use ${staff_dir}employ/employ`i'f, clear
	merge m:1 ssnrep using ${working_dir}principals1995_2011, keep(match) nogen
	keep ssnrep basepay totalpay degree tenure experyrs daysemp district fte 
	drop if ssnrep==.
	recast long district
	saveold ${working_dir}employ`i', replace
}


*Pick up demographic variables 
forvalues i=1995(1)2010 {
	use ${staff_dir}demog_employ/demog_employ`i'f, clear
	merge m:1 ssnrep using ${working_dir}principals1995_2011, keep(match) nogen
	
	*Only need to pick up sex and ethnicity; These won't change if individuals move districts
	keep ssnrep sex ethnic 
	drop if ssnrep==.
	
	*It should be fine to drop duplicates here because sex and ethnicity shouldn't change
	duplicates drop ssnrep, force	
	saveold ${working_dir}demog_employ`i', replace
}


*merge principal_role, employ, and demog_employ files together
forvalues i=1995(1)2010 {
	*start by picking up role, campus, district from principal_role and teacher_role files...
	use ${working_dir}principal_role`i', clear
	append using ${working_dir}teacher_role`i'
	
	*merge with employ to get tenure, experience, degree, base pay, total pay...
	merge m:1 ssnrep district using ${working_dir}employ`i', keep(match) nogen
	
	*merge with demog_employ to get sex, and ethnic variables
	merge m:1 ssnrep using ${working_dir}demog_employ`i', keep(match) nogen
	
	gen year=`i'
	order ssnrep district campus year
	sort ssnrep district
	saveold ${working_dir}principals_`i', replace
}

forvalues i=2011(1)2011 {
	*start by picking up role, campus, district from principal_role and teacher_role files...
	use ${working_dir}principal_role`i', clear
	append using ${working_dir}teacher_role`i'
	
	*merge with employ to get tenure, experience, degree, base pay, total pay...
	merge m:1 ssnrep district using ${working_dir}employ`i', keep(match) nogen
	
	*merge with demog_employ to get sex, and ethnic variables
	merge m:1 ssnrep using ${working_dir}demog_employ2010, keep(match) nogen
	
	gen year=`i'
	order ssnrep district campus year
	sort ssnrep district
	saveold ${working_dir}principals_`i', replace
}

*append all the principals_YYYY files into one panel
use ${working_dir}principals_1995, clear

forvalues i=1996(1)2011 {
	append using ${working_dir}principals_`i'
}

sort ssnrep year district campus

*teacher role changed values over time
recode role (25 29 87 =100)
label define role 100 "TEACHER", modify
saveold ${working_dir}principals_panel, replace


*create variable for the ratio of elementary school principals to superintendants
*merge in the camps01_08 data that was made in the medianecon_elem.do file
merge m:1 campus year using ${account_dir}camps01_08, nogen keepusing(camptype p_hgrade)
*number of superindentants for each district year
gen super=1 if role==27 | role==4
bys district year: egen nsuper=total(super)

*number of elem principals in district
gen eprincipal=1 if role==20 & p_hgrade<=6 & camptype==1
bys district year: egen neprinc=total(eprincipal)

*ratio of principals to superintendants
gen supr_ratio=neprinc/nsuper
saveold ${working_dir}principals_panel, replace

*MERGE THE adj_salary_data BY SSNREP CAMPUS YEAR ROLE 
clear all 
do adjusted_salary.do
use  ${working_dir}principals_panel, clear
sort ssnrep campus year role
merge m:1 ssnrep campus year role using ${working_dir}adj_salary_data, nogen

saveold ${working_dir}principals_panel2, replace

*Run marginal groups code and open marginal group data
clear all
do pub_marginalgroups.do
use ${working_dir}marginal_groups_all, clear

*merge in principal panel 
merge 1:m campus year using ${working_dir}principals_panel2
*we want to keep the using only and matched observations so we can correctly observe 
*principal tenure and outcomes
drop if _m==1
drop _m

*duplicates drop ssnrep campus year role, force

*we still have duplicate ssnreps in many years
*This means we can't attribute changes in outcomes to a particular campus rating

duplicates tag ssnrep year, gen(dup1)
tab dup1

drop if dup1>0
sort ssnrep year

*create dummies for each ethnicity
gen natamer=0
replace natamer=1 if ethnic==1
gen asian=0
replace asian=1 if ethnic==2
gen black=0
replace black=1 if ethnic==3
gen hispanic=0
replace hispanic=1 if ethnic==4
gen white=0
replace white=1 if ethnic==5
gen other=0 
replace other=1 if ethnic!=3 & ethnic!=4 & ethnic!=5

*create dummies for degree type
gen nodegree=0
replace nodegree=1 if degree==0
gen bachelor=0
replace bachelor=1 if degree==1
gen master=0
replace master=1 if degree==2
gen doctorate=0
replace doctorate=1 if degree==3
gen degree_missing=0
replace degree_missing=1 if degree==.
gen belowmaster=0
replace belowmaster=1 if master==0 & doctorate==0

*create dummies for principal and assistant principal roles
gen principal=0
replace principal=1 if role==20
gen assistant=0
replace assistant=1 if role==3

*PRINCIPAL OUTCOME VARIABLES
{
*calculate pay increases
*need to xtset the data

*CPI information
*CPI-U from BLS: Series ID   CUUR0000SA0
*		 Area        US City Average

*	1995=152.4
*	1996=156.9 
*	1997=160.5 
*	1998=163.0 
*	1999=166.6 
*	2000=172.2 
*	2001=177.1 
*	2002=179.9 
*	2003=184.0 
*	2004=188.9 
*	2005=195.3 
*	2006=201.6 
*	2007=207.342 
*	2008=215.303 
*	2009=214.537 
*	2010=218.056 
*	2011=224.939 


xtset ssnrep year

gen cpi=.
replace cpi=152.4 if year==1995
replace cpi=156.9 if year==1996
replace cpi=160.5 if year==1997
replace cpi=163.0 if year==1998
replace cpi=166.6 if year==1999
replace cpi=172.2 if year==2000
replace cpi=177.1 if year==2001
replace cpi=179.9 if year==2002
replace cpi=184.0 if year==2003
replace cpi=188.9 if year==2004
replace cpi=195.3 if year==2005
replace cpi=201.6 if year==2006
replace cpi=207.342 if year==2007
replace cpi=215.303 if year==2008
replace cpi=214.537 if year==2009
replace cpi=218.056 if year==2010
replace cpi=224.939 if year==2011

*calculate real wages in 2003 dollars using cpi
gen base_pay =(basepay/fte)*(184.0/cpi)
	label variable base_pay "Base Pay 2003 dollars"
gen total_pay=(totalpay/fte)*(184.0/cpi)
	label variable total_pay "Total Pay 2003 dollars"
gen l_base_pay=log(base_pay)
	label variable l_base_pay "Log Base Pay 2003 dollars"
gen l_total_pay=log(total_pay)
	label variable l_total_pay "Log Total Pay 2003 dollars"
gen supp_pay =total_pay-base_pay
	label variable supp_pay "Supplemental Pay 2003 dollars"
gen l_supp_pay=log(supp_pay)
	label variable l_supp_pay "Log Supplemental Pay 2003 dollars"
	
gen pct_grth_tot2=F2.l_total_pay-l_total_pay
	

*gen ratings variables for each tier
gen unacceptable=0
replace unacceptable=1 if c_rating==100

gen acceptable=0
replace acceptable=1 if c_rating2==101

gen recognized=0
replace recognized=1 if c_rating2==102

gen exemplary=0 
replace exemplary=1 if c_rating==103

*generate above/below indicators and polynomials
*acceptable
gen acc_above=acc_bind>=0 & acc_bind!=.
gen acc_below=acc_bind<0 & acc_bind!=.
gen acc_da1=acc_above*acc_bind
gen acc_db1=acc_below*acc_bind
gen acc_da2=acc_da1^2
gen acc_db2=acc_db1^2
gen acc_da3=acc_da1^3
gen acc_db3=acc_db1^3

*recognized
gen rec_above=rec_bind>=0 & rec_bind!=.
gen rec_below=rec_bind<0 & rec_bind!=.
gen rec_da1=rec_above*rec_bind
gen rec_db1=rec_below*rec_bind
gen rec_da2=rec_da1^2
gen rec_db2=rec_db1^2
gen rec_da3=rec_da1^3
gen rec_db3=rec_db1^3

*exemplary
gen exe_above=exe_bind>=0 & exe_bind!=.
gen exe_below=exe_bind<0 & exe_bind!=.
gen exe_da1=exe_above*exe_bind
gen exe_db1=exe_below*exe_bind
gen exe_da2=exe_da1^2
gen exe_db2=exe_db1^2
gen exe_da3=exe_da1^3
gen exe_db3=exe_db1^3

	
saveold ${working_dir}principals_ratings_panel_05_2016, replace
}

use ${working_dir}principals_ratings_panel_05_2016, clear
xtset ssnrep year

*determine pay difference between years
forvalues i=1(1)5 {
	
	by ssnrep: gen d_basepay`i'=F`i'.base_pay-base_pay
	by ssnrep: gen d_totalpay`i'=F`i'.total_pay-total_pay
	label variable d_basepay`i' "Difference in Base Pay over `i' years"
	label variable d_totalpay`i' "Difference in Total Pay over `i' years"
}

saveold ${working_dir}principal_turnover_data_05_2016, replace

set more off
use ${working_dir}principal_turnover_data_05_2016, clear


*get following year role, campus, district
xtset ssnrep year
tsfill

*Create consistent tenure by campusXrole 
by ssnrep: gen tenure1=cond(role==role[_n-1] & campus==campus[_n-1], 1, 0)
gen tenure2=0
by ssnrep: replace tenure2=cond(tenure1==0 , tenure1+1 , tenure2[_n-1]+1)
label variable tenure2 "Tenure in RoleXCampus combination"

gen tendum2=(tenure2<=2)
gen tendum3=(tenure2==3)
gen tendum4=(tenure2>=4)

*create indicators for campus and district employees
gen indcamp=(assigrp==1)
gen inddist=1-indcamp

*Get 1 and 2 year ahead variables
by ssnrep: gen long role_1yr=F1.role
by ssnrep: gen long campus_1yr=F1.campus
by ssnrep: gen long district_1yr=F1.district
by ssnrep: gen long total_1yr=F1.total_pay
by ssnrep: gen long adj_total_1yr=F1.adj_total_pay
by ssnrep: gen long rating_1yr=F1.c_rating2
by ssnrep: gen byte inddist_1yr=F1.inddist
by ssnrep: gen byte indcamp_1yr=F1.indcamp

by ssnrep: gen long role_2yr=F2.role
by ssnrep: gen long campus_2yr=F2.campus
by ssnrep: gen long district_2yr=F2.district
by ssnrep: gen long total_2yr=F2.total_pay
by ssnrep: gen long adj_total_2yr=F2.adj_total_pay
by ssnrep: gen long rating_2yr=F2.c_rating2
by ssnrep: gen byte inddist_2yr=F2.inddist
by ssnrep: gen byte indcamp_2yr=F2.indcamp

*experyrs not in 1995 data -> Panel runs from 1996-2011 now
drop if year==1995
*only keep full time principals
keep if fte==1

*Add in campus demographic variables
sort campus year
merge m:1 campus year using ${account_dir}campdemogs, keep(master match) nogen

*Add in campus value added variables
sort campus year
merge m:1 campus year using ${Projecfolder}/student_panel/working_data/principal_va3.dta , keep(master match) nogen // changed to principal_va3 on 6/8 so it now has both types of principal va
save ${working_dir}principal_turnover_data_05_2016, replace

*Add in connected networks data
clear all
do connected_networks.do
merge m:1 campus using ${working_dir}connected_networks, nogen
drop if ssnrep==.

*only need years >=2001
*keep if year>=2001

cd ${working_dir}/
preserve

do predicted_achievment_new.do
*Merge to get predicted reading achievment
	*merge for campus level positions
	keep if indcamp==1
	merge m:1 campus year using ${account_dir}pred_achievement_newc, keep(master match) nogen keepusing(st_predict_pass)
	
	tempfile a_match1
	saveold `a_match1'
	
	*merge for district level positions
	restore, preserve
	keep if inddist==1
	merge m:1 district year using ${account_dir}pred_achievement_newd, keep(master match) nogen keepusing(st_predict_pass)
	
	tempfile a_match2
	saveold `a_match2'

*Merge to get New campus prior year predicted reading achievment, 1 year
	restore, preserve
	keep if indcamp_1yr==1
	merge m:1 campus_1yr year using ${account_dir}pred_achievement_newc, keep(master match) nogen keepusing(l_st_predict_pass update_wc1)
	
	
	tempfile a_match3
	saveold `a_match3'
	
	*merge for district level positions
	restore, preserve
	keep if inddist_1yr==1
	merge m:1 district_1yr year using ${account_dir}pred_achievement_newd, keep(master match) nogen keepusing(l_st_predict_pass update_wc1)
	
	tempfile a_match4
	saveold `a_match4'
	
*Merge to get New campus prior year predicted reading achievment, 2 year
	restore, preserve
	keep if indcamp_2yr==1
	merge m:1 campus_2yr year using ${account_dir}pred_achievement_newc, keep(master match) nogen keepusing(l2_st_predict_pass update_wc2)
	
	tempfile a_match5
	saveold `a_match5'
	
	*merge for district level positions
	restore
	keep if inddist_2yr==1
	merge m:1 district_2yr year using ${account_dir}pred_achievement_newd, keep(master match) nogen keepusing(l2_st_predict_pass update_wc2)
	
	tempfile a_match6
	saveold `a_match6'
	
	*Now merge all the a_match files
	use `a_match1', clear
	merge 1:1 ssnrep year using `a_match2', update nogen
	
	merge 1:1 ssnrep year using `a_match3', update nogen
	
	merge 1:1 ssnrep year using `a_match4', update nogen
	
	merge 1:1 ssnrep year using `a_match5', update nogen
	
	merge 1:1 ssnrep year using `a_match6', update nogen

	saveold ${working_dir}/test_merge_a, replace
	use ${working_dir}/test_merge_a, clear


*calculate 1 year change in pay
xtset ssnrep year
gen change_base=F1.base_pay-base_pay
gen change_total=total_1yr-total_pay
gen change_adj_total=adj_total_1yr-adj_total_pay
gen change_supp=F1.supp_pay-supp_pay

*calculate 2 year percentage growth
xtset ssnrep year
gen change_base2=F2.base_pay-base_pay
gen change_total2=total_2yr-total_pay
gen change_adj_total2=adj_total_2yr-adj_total_pay
gen change_supp2=F2.supp_pay-supp_pay

*calculate 1 year percentage growth
xtset ssnrep year
gen pgrowth_base=((F1.base_pay - base_pay)/base_pay)
gen pgrowth_total=((total_1yr - total_pay)/total_pay)
gen pgrowth_adj_total=((adj_total_1yr - adj_total_pay)/adj_total_pay)
gen pgrowth_supp=((F1.supp_pay - supp_pay)/supp_pay)

*calculate 2 year percentage growth
xtset ssnrep year
gen pgrowth_base2=((F2.base_pay - base_pay)/base_pay)
gen pgrowth_total2=((total_2yr - total_pay)/total_pay)
gen pgrowth_adj_total2=((adj_total_2yr - adj_total_pay)/adj_total_pay)
gen pgrowth_supp2=((F2.supp_pay - supp_pay)/supp_pay)


saveold ${working_dir}staffinfo, replace

/*make sure 2003 schools are classified correctly
xtset ssnrep year
replace elementary=1 if year==2003 & L1.elementary==1
replace middle=1 if year==2003 & L1.middle==1
replace secondary=1 if year==2003 & L1.secondary==1

*keep elementary and middle schools
keep if middle==1|elementary==1 */
*Keep only the Principals
keep if role==20

duplicates tag campus year, gen(dup)
drop if dup>0
drop dup

drop if msyfe==. & rsyfe==. & asyfe==.

*only keep principals from rated campuses
keep if c_rating2!=.

*keep sample consistent
*xtset ssnrep year
*merge 1:1 ssnrep year using ${working_dir}principal_elem_mid, keep(match) nogen

/*determine principal transitions: Base line : Stay
				   Principal or higher admin job within district
				   Principal or higher admin job at another district
				   Teacher or Asst. Principal anywhere
				   */
				   
*who kept their job?
gen stay=0
replace stay=1 if role_1yr==role & campus_1yr==campus & year!=2011
gen stay2=0 
replace stay2=1 if role_2yr==role & campus_2yr==campus & year!=2011
					   
*who leaves TPS?
gen leave_samp=0
replace leave_samp=1 if role_1yr==. & year!=2011
gen leave_samp2=0
replace leave_samp2=1 if role_2yr==. & year!=2011

*There are 151 principals that moved campuses, but their new campus doesn't serve tested grades yet.
*I double, and tripple checked this and it only happens for people moving to campus level positions.
	tab indcamp_2yr if district_2yr!=. & l2_st_predict_pass==.
	tab inddist_2yr if district_2yr!=. & l2_st_predict_pass==.
		*See, told you!
*This means we can't calculate predicted achievment as a proxy for working conditions in these campuses.
*In for these guys I'm going to use the district predicted achievment. 
	*lets mark the 151 principals that this happens to and separate them so we can merge in the district predicted achievement 
		gen nopredach=(district_2yr!=. & l2_st_predict_pass==.)
		preserve
			keep if nopredach==1
			sort district_2yr year
			merge m:1 district_2yr year using ${account_dir}pred_achievement_newd, keepusing(l2_st_predict_pass update_wc2) update replace
			keep if _merge>2
				*there is still one guy that moved to a district (UT Elementary Charter) that had no students in a tested grade
				*I'm going to give this person the average predicted achievment of all campuses in the state
				*This is zero because we standardized the distribution of prediction achievment
				replace l2_st_predict_pass=0 if l2_st_predict_pass==.
			sort ssnrep year
			drop _merge
			tempfile nopredachsamp
			saveold `nopredachsamp'
		restore
		*now merge with the nopredachsamp
		sort ssnrep year
		merge 1:1 ssnrep year using `nopredachsamp', nogen update replace
	*Now no one who didn't leave texas public schools should have missing predited achievement values 
	count if district_2yr!=. & l2_st_predict_pass==.
	
	
*who transfers... period?
gen newpos=0
replace newpos=1 if (role!=role_1yr | campus!=campus_1yr) & leave_samp!=1	
gen newpos2=0
replace newpos2=1 if (role!=role_2yr | campus!=campus_2yr) & leave_samp2!=1

*who ends up in new principalship?
gen newship=0
replace newship=1 if role_1yr==20 & campus!=campus_1yr	
gen newship2=0
replace newship2=1 if role_2yr==20 & campus!=campus_2yr	

*Create and label transition variable
gen     transition=1 if stay==1
replace transition=2 if newpos==1
replace transition=3 if newship==1
replace transition=4 if leave_samp==1

label variable transition "Subsequent Year Role"
label de transition 1 "Stay", modify
label de transition 2 "Any New Position", modify
label de transition 3 "New Principalship", modify
label de transition 4 "Leave Sample", modify
label values transition transition		

*Create and label transition2 variable
gen     transition2=1 if stay2==1
replace transition2=2 if newpos2==1
replace transition2=3 if newship2==1
replace transition2=4 if leave_samp2==1

label variable transition2 "Subsequent Year Role"
label de transition2 1 "Stay", modify
label de transition2 2 "Any New Position", modify
label de transition2 3 "New Principalship", modify
label de transition2 4 "Leave Sample", modify
label values transition2 transition2	   

*De-mean 1 year salary change
bysort year: egen m_change_total=mean(change_total)
gen st_change_total=change_total-m_change_total

*Median and 75th pctile 1 year salary change 
bysort year: egen med_change_total=median(change_total)
bysort year: egen p75_change_total=pctile(change_total), p(75)

*De-mean 2 year salary change
bysort year: egen m_change_total2=mean(change_total2)
gen st_change_total2=change_total2-m_change_total2

*Median and 75th pctile 2 year salary change 
bysort year: egen med_change_total2=median(change_total2)
bysort year: egen p75_change_total2=pctile(change_total2), p(75)

*De-mean 1 year percentage growth
bysort year: egen m_pgrowth_total=mean(pgrowth_total)
gen st_pgrowth_total=pgrowth_total-m_pgrowth_total
bysort year: egen m_pgrowth_adj_total=mean(pgrowth_adj_total)
gen st_pgrowth_adj_total=pgrowth_adj_total-m_pgrowth_adj_total

*De-mean 2 year percentage growth
bysort year: egen m_pgrowth_total2=mean(pgrowth_total2)
gen st_pgrowth_total2=pgrowth_total2-m_pgrowth_total2
bysort year: egen m_pgrowth_adj_total2=mean(pgrowth_adj_total2)
gen st_pgrowth_adj_total2=pgrowth_adj_total2-m_pgrowth_adj_total2

*De-mean value added
	*syfe is the schoolXyear fixed effect
	*demean by year
bysort year: egen mean_msyfe=mean(msyfe)
gen st_msyfe=msyfe-mean_msyfe
bysort year: egen mean_rsyfe=mean(rsyfe)
gen st_rsyfe=rsyfe-mean_rsyfe
bysort year: egen mean_asyfe=mean(asyfe)
gen st_asyfe=asyfe-mean_asyfe
	*syfe2 is the principal fixed effect after controlling for campus fixed effects
	*demean by connected network
bysort comp: egen mean_msyfe2=mean(msyfe2)
gen st_msyfe2=msyfe2-mean_msyfe2
bysort comp: egen mean_rsyfe2=mean(rsyfe2)
gen st_rsyfe2=rsyfe2-mean_rsyfe2	
bysort comp: egen mean_asyfe2=mean(asyfe2)
gen st_asyfe2=asyfe2-mean_asyfe2			

bys year: egen mean_m_msyfe=mean(m_msyfe)
gen st_m_msyfe=m_msyfe-mean_m_msyfe
bys year: egen mean_m_rsyfe=mean(m_rsyfe)
gen st_m_rsyfe=m_rsyfe-mean_m_rsyfe
bys year: egen mean_m_asyfe=mean(m_asyfe)
gen st_m_asyfe=m_asyfe-mean_m_asyfe   

*calculate value added quartiles
*Create Value added quartiles
bysort year: egen p25_msyfe=pctile(st_msyfe), p(25)
bysort year: egen p50_msyfe=pctile(st_msyfe), p(50)
bysort year: egen p75_msyfe=pctile(st_msyfe), p(75)
bysort year: gen     q_msyfe=1 if st_msyfe<=p25_msyfe
bysort year: replace q_msyfe=2 if st_msyfe> p25_msyfe
bysort year: replace q_msyfe=3 if st_msyfe> p50_msyfe
bysort year: replace q_msyfe=4 if st_msyfe> p75_msyfe

bysort year: egen p25_rsyfe=pctile(st_rsyfe), p(25)
bysort year: egen p50_rsyfe=pctile(st_rsyfe), p(50)
bysort year: egen p75_rsyfe=pctile(st_rsyfe), p(75)
bysort year: gen     q_rsyfe=1 if st_rsyfe<=p25_rsyfe
bysort year: replace q_rsyfe=2 if st_rsyfe> p25_rsyfe
bysort year: replace q_rsyfe=3 if st_rsyfe> p50_rsyfe
bysort year: replace q_rsyfe=4 if st_rsyfe> p75_rsyfe

bysort year: egen p25_asyfe=pctile(st_asyfe), p(25)
bysort year: egen p50_asyfe=pctile(st_asyfe), p(50)
bysort year: egen p75_asyfe=pctile(st_asyfe), p(75)
bysort year: gen     q_asyfe=1 if st_asyfe<=p25_asyfe
bysort year: replace q_asyfe=2 if st_asyfe> p25_asyfe
bysort year: replace q_asyfe=3 if st_asyfe> p50_asyfe
bysort year: replace q_asyfe=4 if st_asyfe> p75_asyfe

*label percentile varialbes
label variable q_msyfe "Value Added Quartile"
label de q_msyfe 1 "V1", modify
label de q_msyfe 2 "V2", modify
label de q_msyfe 3 "V3", modify
label de q_msyfe 4 "V4", modify
label values q_msyfe q_msyfe 
label variable q_rsyfe "Value Added Quartile"
label de q_rsyfe 1 "V1", modify
label de q_rsyfe 2 "V2", modify
label de q_rsyfe 3 "V3", modify
label de q_rsyfe 4 "V4", modify
label values q_rsyfe q_rsyfe
label variable q_asyfe "Value Added Quartile"
label de q_asyfe 1 "V1", modify
label de q_asyfe 2 "V2", modify
label de q_asyfe 3 "V3", modify
label de q_asyfe 4 "V4", modify
label values q_asyfe q_asyfe 

sort ssnrep year
saveold ${working_dir}/principals_sample_05_2016, replace

*Drop Texas Projection measure years from the sample. 
use ${working_dir}/principals_sample_05_2016, clear
drop if year>=2009


********************************************************************************
*Now the principals panel runs from 1996 to 2008 
*We want the distribution of schools by the number of principals who have also served as principals in another school
*In other words: Within each school, how many principals also served at another school?
	*start by counting the number of schools each principal served attribute
		preserve
			bys ssnrep campus: keep if _n==1
			bys ssnrep: gen p_c_count=_N
			keep ssnrep p_c_count
			by ssnrep: keep if _n==1
			tempfile temp1
			save `temp1'
		restore
		merge m:1 ssnrep using `temp1', nogen
		*now p_c_count counts the number of schools each principal has served
		
		sort campus year
		by campus: egen c_pc_count=mean(p_c_count)
		
		
		*make an indicator for principals that served at more than one campus/
			gen multi_c_p=(p_c_count>1)
		preserve
			bys campus ssnrep: keep if _n==1
			by campus: egen tot_mcp=total(multi_c_p)
			by campus: keep if _n==1
			tempfile temp2
			save `temp2'
		restore
		merge m:1 campus using `temp2', nogen
		
		
	*now make a log file that finds the distribution of schools by the number of principals who have also served as principals in another school
	preserve
	log using ${LPM_success}uncond_school_mcp_dist.txt, replace text
	*We want the distribution of schools by the number of principals who have also served as principals in another school
	*the data is a panel of principals by year and we only need one observation per campus to get the distribution
	bys campus: keep if _n==1
	* Within each school, how many principals also served at another school?
		sum tot_mcp, detail
		
	log close
	restore
*Now I should be able to do get this distribution again once we have the analysis sample
********************************************************************************

*Define New Variable For "Success"

	*Success from stay
	gen success1=0
	replace success1=1 if transition==1 

	*Success from transition with pay increase above median mover pay increase
	gen success2=0
	replace success2=1 if change_total>=med_change_total & change_total!=.
	
	*Success from transition with better student achievment
	gen success3=0 
	replace success3=1 if transition==3 & l_st_predict_pass>=st_predict_pass & st_predict_pass!=. & l_st_predict_pass!=.
	
	*Success from transition to a campus with change in student achievment above median for movers to new principalship
	gen success4=0
	gen d_l_st_predict_pass=l_st_predict_pass-st_predict_pass if transition==3  & st_predict_pass!=. & l_st_predict_pass!=.
	replace d_l_st_predict_pass=0 if transition==1
	bys year: egen med_d_l_st_predict_pass=median(d_l_st_predict_pass) 
	replace success4=1 if transition==3 & d_l_st_predict_pass>=med_d_l_st_predict_pass & d_l_st_predict_pass!=. & med_d_l_st_predict_pass!=.
	
	*Success from transition to a campus with change in student achievment above 75 percentile of all movers to new principalship
	gen success5=0
	bys year: egen p75_d_l_st_predict_pass=pctile(d_l_st_predict_pass), p(75) 
	replace success5=1 if transition==3 & d_l_st_predict_pass>=p75_d_l_st_predict_pass  & d_l_st_predict_pass!=. & p75_d_l_st_predict_pass!=.
	
	*success from transtioning with a pay increase above the 75th percentile of all movers
	gen success6=0
	replace success6=1 if change_total>=p75_change_total

	*Big Success (differ by campus achievment)
	gen success_a1=0
	replace success_a1=1 if success1==1 | success2==1 | success3==1
	
	gen success_a2=0
	replace success_a2=1 if success1==1 | success2==1 | success4==1
	
	gen success_a3=0
	replace success_a3=1 if success1==1 | success6==1 | success5==1
	
*Define 2 year "Success"

	*Success from stay
	gen success1_2=0
	replace success1_2=1 if transition2==1 

	*Success from transition with pay increase above median mover pay increase
	gen success2_2=0
	replace success2_2=1 if change_total2>=med_change_total2 & change_total2!=.
	
	*Success from transition with better student achievment
	gen success3_2=0 
	replace success3_2=1 if transition2==3 & l2_st_predict_pass>=st_predict_pass & l2_st_predict_pass!=. & st_predict_pass!=.
		*make zero for the campus to district moves that didn't involve a change in district
		replace success3_2=0 if inddist_2yr==1 & district==district_2yr
	
	*Success from transition to a campus with change in student achievment above median for movers to new principalship
		*as of Feb 2018 we want to make sure that if a principal transfers to a district position in the same district they served as principal their change in predicted achievment will be zero
		*Thus, for campus to district movers, the change will be zero if the move does not involve change in districts
	gen success4_2=0
	gen d_l2_st_predict_pass=l2_st_predict_pass-st_predict_pass if transition2==3 & l2_st_predict_pass!=. & st_predict_pass!=.
		*make zero for the campus to district moves that didn't involve a change in district
		replace d_l2_st_predict_pass=0 if inddist_2yr==1 & district==district_2yr
	replace d_l2_st_predict_pass=0 if transition2==1
	bys year: egen med_d_l2_st_predict_pass=median(d_l2_st_predict_pass)
	replace success4_2=1 if transition2==3 & d_l2_st_predict_pass>=med_d_l2_st_predict_pass & d_l2_st_predict_pass!=. & med_d_l2_st_predict_pass!=.
	
	*Success from transition to a campus with change in student achievment above 75 percentile of all movers to new principalship
	gen success5_2=0
	bys year: egen p75_d_l2_st_predict_pass=pctile(d_l2_st_predict_pass), p(75)
	replace success5_2=1 if transition2==3 & d_l2_st_predict_pass>=p75_d_l2_st_predict_pass & d_l2_st_predict_pass!=. & p75_d_l2_st_predict_pass!=.
	
	*success from transtioning with a pay increase above the 75th percentile of all movers
	gen success6_2=0
	replace success6_2=1 if change_total2>=p75_change_total2

	*Big Success (differ by campus achievment)
	gen success_a1_2=0
	replace success_a1_2=1 if success1_2==1 | success2_2==1 | success3_2==1
	
	gen success_a2_2=0
	replace success_a2_2=1 if success1_2==1 | success2_2==1 | success4_2==1
	
	gen success_a3_2=0
	replace success_a3_2=1 if success1_2==1 | success6_2==1 | success5_2==1	
	

***************We need to get the number of campuses in each district***********************
saveold ${working_dir}/principals_sample_05_2016, replace
clear all
do pub_enrollment.do
use ${working_dir}/principals_sample_05_2016, clear 

*merge in district campus number data
merge 1:1 campus year using ${account_dir}dist_ncamps, keep(master match) nogen

*drop if passmath & passread are missing 
drop if passmath==. & passread==.

*Track campuses that are not in a connected network
preserve
xtset campus year
by campus: gen counter=_n
xtset campus counter
by campus: gen tmp1=(L1.ssnrep!=ssnrep)
by campus: egen NPs=total(tmp1)
bys campus: keep if _n==1
bys comp: gen N_network=_N

keep campus NPs N_network tmp1

saveold ${working_dir}track_networks, replace

restore
merge m:1 campus using ${working_dir}track_networks, nogen

saveold ${working_dir}RDD_sample_05_2016, replace

*keep with less than 25 years of experience and tenure of 2 or more years from 2001 and on
use ${working_dir}RDD_sample_05_2016, clear

*merge in the lagged math and reading pass rates
merge 1:1 campus year using ${account_dir}lagged_math_read, keep(match) nogen

*merge in the enrollment by year
merge m:1 campus year using ${account_dir}enrollcamp, keep(match) keepusing(enrlcount) nogen

*merge in share_mover by campus and year
merge m:1 campus year using ${account_dir}sharemovers, nogen keep(match)

*merge in the AYP2004_2008 data
merge 1:1 campus year using ${Projectfolder}/AYPdata/AYP2004_2008, keep(master match) nogen

*gen passrate
	egen passrate=rowmean(passread passmath)
	*replace passrate=passrate/100
	*replace passmath=passmath/100
	*replace passread=passread/100
*make sure we can calculate a change in passrate
	keep if cschmthrate_1!=. | cschredrate_1!=.
	
*now we want to make variables to divide the sample 
	*drop old median variables.
	*drop medecon medcamps grmedecon grmedcamps
	
	*make new median district size variable
	egen medsize=median(ncamps)
	
	*make bottom, middle, and top third variables
	egen botsize=pctile(ncamps), p(33.3)
	egen midsize=pctile(ncamps), p(66.6)
	
	*mark samples
	gen lowhalf=(ncamps<medsize)
	gen tophalf=(ncamps>=medsize)
	
	gen lowthird=(ncamps<botsize)
	gen midthird=(ncamps>=botsize & ncamps<midsize)
	gen topthird=(ncamps>=midsize)
	

*Make summary table 1
keep if year>=2001
order sex black hispanic white other belowmaster master doctorate tendum2 tendum3 tendum4 experyrs passrate total_pay passmath passread unacceptable acceptable recognized exemplary share_male share_black share_hisp share_white share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover
outreg2 using ${working_dir}summarytable1.xls, sum(log) eqkeep(N mean) dec(3) keep(sex black hispanic white other belowmaster master doctorate tendum2 tendum3 tendum4 experyrs total_pay passrate passmath passread unacceptable acceptable recognized exemplary share_male share_black share_hisp share_white share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) replace
keep if experyrs<=25
outreg2 using ${working_dir}summarytable1.xls, sum(log) eqkeep(N mean) dec(3) keep(sex black hispanic white other belowmaster master doctorate tendum2 tendum3 tendum4 experyrs total_pay passrate passmath passread unacceptable acceptable recognized exemplary share_male share_black share_hisp share_white share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) append
saveold ${working_dir}RDD_sample_05_2016_taks_w1styr, replace
keep if tenure2>=2
outreg2 using ${working_dir}summarytable1.xls, sum(log) eqkeep(N mean) dec(3) keep(sex black hispanic white other belowmaster master doctorate tendum2 tendum3 tendum4 experyrs total_pay passrate passmath passread unacceptable acceptable recognized exemplary share_male share_black share_hisp share_white share_other share_disadv share_title1 share_lep share_speced share_gifted share_mover) append

saveold ${working_dir}RDD_sample_05_2016_taks_Jan2020, replace


*******************************************************************************
*Now the principals panel runs from 1996 to 2008 
*We want the distribution of schools by the number of principals who have also served as principals in another school
*We did this before but it wasn't for conditioned analysis sample 

	*now make a log file that finds the distribution of schools by the number of principals who have also served as principals in another school
	preserve
	log using ${LPM_success}condit_school_mcp_dist.txt, replace text
	*We want the distribution of schools by the number of principals who have also served as principals in another school
	*the data is a panel of principals by year and we only need one observation per campus to get the distribution
	bys campus: keep if _n==1
	* Within each school, how many principals also served at another school?
		sum tot_mcp, detail
		
	log close
	restore
*Now I should be able to do get this distribution again once we have the analysis sample
********************************************************************************


