capture log close
clear all

**************************************************************************************
*Name: pub_accountability.do
*Description: Creates an accountability panel using public AEIS and accountabiliy data
*Author: Gregory Phelan
**************************************************************************************

set more off
clear

global working_dir	${Projectfolder}/account_rating/
global stud_path	${project_data}/tea/peims/student/
global taks_path	${project_data}/tea/assess/taks/
global camp_path	${project_data}/tea/peims/organization/campus/


*****************************
*ON/OFF switches
local aeis       0
local msr_aeis   0
local trackcamps 0
local trimsamp   0
local minsize    0
local reqimpr    0
local exceptions 0
local shapeitup  0
local JHR_rates  0
*****************************




**********************************AEIS DATA*************************************

*we got to get this stuff into shape (be careful it varies by testing regime
if `aeis'==1 {


**********************TAAS************************
forvalues i=1(1)2 {
use ${erc_data}/non_erc/public/AEIS/campus/aeiscamp200`i', clear

local cur=`i'
local lag=`i'-1


*No required improvement in 2001 or 2002 so I don't need any of the lagged rates
*Elementary subjects are Math, Reading, and Writing
*keep relevant pass rates and other variables 
keep campus ca0tm0`cur'r ce0tm0`cur'r cb0tm0`cur'r ch0tm0`cur'r cw0tm0`cur'r ca0tm0`lag'r /// math
	    ca0tr0`cur'r ce0tr0`cur'r cb0tr0`cur'r ch0tr0`cur'r cw0tr0`cur'r ca0tr0`lag'r /// reading
	    ca0tw0`cur'r ce0tw0`cur'r cb0tw0`cur'r ch0tw0`cur'r cw0tw0`cur'r /// writing
	    c_rating district cflchart cname paircamp pairname

*create c_rating2 variable
gen long c_rating2=.
replace c_rating2=100 if c_rating=="L"	
replace c_rating2=101 if c_rating=="A"	
replace c_rating2=102 if c_rating=="R"	
replace c_rating2=103 if c_rating=="E"	
label variable c_rating2 "Campus Accountability Rating"	
drop if c_rating2==.

*rename variables so they make sense and will be consistent across years
rename ca0tm*r schmthrate*
rename ca0tr*r schredrate*
rename ca0tw*r schwrtrate*
rename ce0tm*r dismthrate*
rename ce0tr*r disredrate*
rename ce0tw*r diswrtrate*
rename cb0tm*r blk_ethnmthrate*
rename cb0tr*r blk_ethnredrate*
rename cb0tw*r blk_ethnwrtrate*
rename ch0tm*r his_ethnmthrate*
rename ch0tr*r his_ethnredrate*
rename ch0tw*r his_ethnwrtrate*
rename cw0tm*r wht_ethnmthrate*
rename cw0tr*r wht_ethnredrate*
rename cw0tw*r wht_ethnwrtrate*

rename *0`cur' *
rename *0`lag' *_1

*round to the nearest integer
replace schmthrate		=schmthrate	
replace schredrate		=schredrate	
replace schwrtrate		=schwrtrate
replace dismthrate		=dismthrate
replace disredrate		=disredrate
replace diswrtrate		=diswrtrate
replace blk_ethnmthrate	=blk_ethnmthrate
replace blk_ethnredrate	=blk_ethnredrate
replace blk_ethnwrtrate	=blk_ethnwrtrate
replace his_ethnmthrate	=his_ethnmthrate
replace his_ethnredrate	=his_ethnredrate
replace his_ethnwrtrate	=his_ethnwrtrate
replace wht_ethnmthrate	=wht_ethnmthrate
replace wht_ethnredrate	=wht_ethnredrate
replace wht_ethnwrtrate	=wht_ethnwrtrate

*create year variable
gen long year=200`i'

recast long campus
format %12.0g paircamp

saveold ${working_dir}aeis_`i', replace
}

**********************TAKS************************
forvalues i=4(1)4 {

*create current and lagged year locals
local cur=`i'
local lag=`i'-1

*get aeis data 
use ${erc_data}/non_erc/public/AEIS/campus/aeiscamp200`i', clear

*keep relevant pass rates and other variables 
keep campus ca311tm0`cur'r ce311tm0`cur'r cb311tm0`cur'r ch311tm0`cur'r cw311tm0`cur'r /// math
			ca311tr0`cur'r ce311tr0`cur'r cb311tr0`cur'r ch311tr0`cur'r cw311tr0`cur'r /// reading
			ca311tw0`cur'r ce311tw0`cur'r cb311tw0`cur'r ch311tw0`cur'r cw311tw0`cur'r /// writing
			ca311tc0`cur'r ce311tc0`cur'r cb311tc0`cur'r ch311tc0`cur'r cw311tc0`cur'r /// science
			ca311ts0`cur'r ce311ts0`cur'r cb311ts0`cur'r ch311ts0`cur'r cw311ts0`cur'r /// soc studies
			ca311tm0`lag'r ce311tm0`lag'r cb311tm0`lag'r ch311tm0`lag'r cw311tm0`lag'r /// math
			ca311tr0`lag'r ce311tr0`lag'r cb311tr0`lag'r ch311tr0`lag'r cw311tr0`lag'r /// reading
			ca311tw0`lag'r ce311tw0`lag'r cb311tw0`lag'r ch311tw0`lag'r cw311tw0`lag'r /// writing
			ca311tc0`lag'r ce311tc0`lag'r cb311tc0`lag'r ch311tc0`lag'r cw311tc0`lag'r /// science
			ca311ts0`lag'r ce311ts0`lag'r cb311ts0`lag'r ch311ts0`lag'r cw311ts0`lag'r /// soc studies
			ca0su0`cur'r ca0su0`lag'r /// sdaa
			c_rating district cflchart cname paircamp pairname 
			
*create c_rating2 variable
gen long c_rating2=.
replace c_rating2=100 if c_rating=="L"	
replace c_rating2=101 if c_rating=="A"	
replace c_rating2=102 if c_rating=="R"	
replace c_rating2=103 if c_rating=="E"	
label variable c_rating2 "Campus Accountability Rating"	
drop if c_rating2==.	
					

*rename variables so they make sense and will be consistent across years
rename ca311tm*r schmthrate*
rename ca311tr*r schredrate*
rename ca311tw*r schwrtrate*
rename ca311tc*r schscirate*
rename ca311ts*r schsocrate*
rename ce311tm*r dismthrate*
rename ce311tr*r disredrate*
rename ce311tw*r diswrtrate*
rename ce311tc*r disscirate*
rename ce311ts*r dissocrate*
rename cb311tm*r blk_ethnmthrate*
rename cb311tr*r blk_ethnredrate*
rename cb311tw*r blk_ethnwrtrate*
rename cb311tc*r blk_ethnscirate*
rename cb311ts*r blk_ethnsocrate*
rename ch311tm*r his_ethnmthrate*
rename ch311tr*r his_ethnredrate*
rename ch311tw*r his_ethnwrtrate*
rename ch311tc*r his_ethnscirate*
rename ch311ts*r his_ethnsocrate*
rename cw311tm*r wht_ethnmthrate*
rename cw311tr*r wht_ethnredrate*
rename cw311tw*r wht_ethnwrtrate*
rename cw311tc*r wht_ethnscirate*
rename cw311ts*r wht_ethnsocrate*
rename ca0su*r sdaarate*

rename *0`cur' *
rename *0`lag' *_1

*round to the nearest integer
replace schmthrate		=round(schmthrate		,1)
replace schredrate		=round(schredrate		,1)
replace schwrtrate		=round(schwrtrate		,1)
replace schscirate		=round(schscirate		,1)
replace schsocrate		=round(schsocrate		,1)
replace dismthrate		=round(dismthrate		,1)
replace disredrate		=round(disredrate		,1)
replace diswrtrate		=round(diswrtrate		,1)
replace disscirate		=round(disscirate		,1)
replace dissocrate		=round(dissocrate		,1)
replace blk_ethnmthrate	=round(blk_ethnmthrate	,1)
replace blk_ethnredrate	=round(blk_ethnredrate	,1)
replace blk_ethnwrtrate	=round(blk_ethnwrtrate	,1)
replace blk_ethnscirate	=round(blk_ethnscirate	,1)
replace blk_ethnsocrate	=round(blk_ethnsocrate	,1)
replace his_ethnmthrate	=round(his_ethnmthrate	,1)
replace his_ethnredrate	=round(his_ethnredrate	,1)
replace his_ethnwrtrate	=round(his_ethnwrtrate	,1)
replace his_ethnscirate	=round(his_ethnscirate	,1)
replace his_ethnsocrate	=round(his_ethnsocrate	,1)
replace wht_ethnmthrate	=round(wht_ethnmthrate	,1)
replace wht_ethnredrate	=round(wht_ethnredrate	,1)
replace wht_ethnwrtrate	=round(wht_ethnwrtrate	,1)
replace wht_ethnscirate	=round(wht_ethnscirate	,1)
replace wht_ethnsocrate	=round(wht_ethnsocrate	,1)
replace sdaarate        =round(sdaarate         ,1)
replace schmthrate_1		=round(schmthrate_1		,1)
replace schredrate_1		=round(schredrate_1		,1)
replace schwrtrate_1		=round(schwrtrate_1		,1)
replace schscirate_1		=round(schscirate_1		,1)
replace schsocrate_1		=round(schsocrate_1		,1)
replace dismthrate_1		=round(dismthrate_1		,1)
replace disredrate_1		=round(disredrate_1		,1)
replace diswrtrate_1		=round(diswrtrate_1		,1)
replace disscirate_1		=round(disscirate_1		,1)
replace dissocrate_1		=round(dissocrate_1		,1)
replace blk_ethnmthrate_1	=round(blk_ethnmthrate_1	,1)
replace blk_ethnredrate_1	=round(blk_ethnredrate_1	,1)
replace blk_ethnwrtrate_1	=round(blk_ethnwrtrate_1	,1)
replace blk_ethnscirate_1	=round(blk_ethnscirate_1	,1)
replace blk_ethnsocrate_1	=round(blk_ethnsocrate_1	,1)
replace his_ethnmthrate_1	=round(his_ethnmthrate_1	,1)
replace his_ethnredrate_1	=round(his_ethnredrate_1	,1)
replace his_ethnwrtrate_1	=round(his_ethnwrtrate_1	,1)
replace his_ethnscirate_1	=round(his_ethnscirate_1	,1)
replace his_ethnsocrate_1	=round(his_ethnsocrate_1	,1)
replace wht_ethnmthrate_1	=round(wht_ethnmthrate_1	,1)
replace wht_ethnredrate_1	=round(wht_ethnredrate_1	,1)
replace wht_ethnwrtrate_1	=round(wht_ethnwrtrate_1	,1)
replace wht_ethnscirate_1	=round(wht_ethnscirate_1	,1)
replace wht_ethnsocrate_1	=round(wht_ethnsocrate_1	,1)
replace sdaarate_1          =round(sdaarate_1           ,1)

*create year variable
gen long year=200`i'

recast long campus
format %12.0g paircamp

saveold ${working_dir}aeis_`i', replace
}

forvalues i=5(1)5 {

*create current and lagged year locals
local cur=`i'
local lag=`i'-1

*get aeis data 
use ${erc_data}/non_erc/public/AEIS/campus/aeiscamp200`i', clear

*keep relevant pass rates and other variables 
keep campus ca311tm0`cur'r ce311tm0`cur'r cb311tm0`cur'r ch311tm0`cur'r cw311tm0`cur'r /// math
			ca311tr0`cur'r ce311tr0`cur'r cb311tr0`cur'r ch311tr0`cur'r cw311tr0`cur'r /// reading
			ca311tw0`cur'r ce311tw0`cur'r cb311tw0`cur'r ch311tw0`cur'r cw311tw0`cur'r /// writing
			ca311tc0`cur'r ce311tc0`cur'r cb311tc0`cur'r ch311tc0`cur'r cw311tc0`cur'r /// science
			ca311ts0`cur'r ce311ts0`cur'r cb311ts0`cur'r ch311ts0`cur'r cw311ts0`cur'r /// soc studies
			ca311tm0`lag'r ce311tm0`lag'r cb311tm0`lag'r ch311tm0`lag'r cw311tm0`lag'r /// math
			ca311tr0`lag'r ce311tr0`lag'r cb311tr0`lag'r ch311tr0`lag'r cw311tr0`lag'r /// reading
			ca311tw0`lag'r ce311tw0`lag'r cb311tw0`lag'r ch311tw0`lag'r cw311tw0`lag'r /// writing
			ca311tc0`lag'r ce311tc0`lag'r cb311tc0`lag'r ch311tc0`lag'r cw311tc0`lag'r /// science
			ca311ts0`lag'r ce311ts0`lag'r cb311ts0`lag'r ch311ts0`lag'r cw311ts0`lag'r /// soc studies
			ca0su0`cur'r /*ca0su0`lag'r*/ /// sdaa
			c_rating district cflchart cname paircamp pairname 
			
*create c_rating2 variable
gen long c_rating2=.
replace c_rating2=100 if c_rating=="L"	
replace c_rating2=101 if c_rating=="A"	
replace c_rating2=102 if c_rating=="R"	
replace c_rating2=103 if c_rating=="E"	
label variable c_rating2 "Campus Accountability Rating"	
drop if c_rating2==.	
					

*rename variables so they make sense and will be consistent across years
rename ca311tm*r schmthrate*
rename ca311tr*r schredrate*
rename ca311tw*r schwrtrate*
rename ca311tc*r schscirate*
rename ca311ts*r schsocrate*
rename ce311tm*r dismthrate*
rename ce311tr*r disredrate*
rename ce311tw*r diswrtrate*
rename ce311tc*r disscirate*
rename ce311ts*r dissocrate*
rename cb311tm*r blk_ethnmthrate*
rename cb311tr*r blk_ethnredrate*
rename cb311tw*r blk_ethnwrtrate*
rename cb311tc*r blk_ethnscirate*
rename cb311ts*r blk_ethnsocrate*
rename ch311tm*r his_ethnmthrate*
rename ch311tr*r his_ethnredrate*
rename ch311tw*r his_ethnwrtrate*
rename ch311tc*r his_ethnscirate*
rename ch311ts*r his_ethnsocrate*
rename cw311tm*r wht_ethnmthrate*
rename cw311tr*r wht_ethnredrate*
rename cw311tw*r wht_ethnwrtrate*
rename cw311tc*r wht_ethnscirate*
rename cw311ts*r wht_ethnsocrate*
rename ca0su*r sdaarate*

rename *0`cur' *
rename *0`lag' *_1

*round to the nearest integer
replace schmthrate		=round(schmthrate		,1)
replace schredrate		=round(schredrate		,1)
replace schwrtrate		=round(schwrtrate		,1)
replace schscirate		=round(schscirate		,1)
replace schsocrate		=round(schsocrate		,1)
replace dismthrate		=round(dismthrate		,1)
replace disredrate		=round(disredrate		,1)
replace diswrtrate		=round(diswrtrate		,1)
replace disscirate		=round(disscirate		,1)
replace dissocrate		=round(dissocrate		,1)
replace blk_ethnmthrate	=round(blk_ethnmthrate	,1)
replace blk_ethnredrate	=round(blk_ethnredrate	,1)
replace blk_ethnwrtrate	=round(blk_ethnwrtrate	,1)
replace blk_ethnscirate	=round(blk_ethnscirate	,1)
replace blk_ethnsocrate	=round(blk_ethnsocrate	,1)
replace his_ethnmthrate	=round(his_ethnmthrate	,1)
replace his_ethnredrate	=round(his_ethnredrate	,1)
replace his_ethnwrtrate	=round(his_ethnwrtrate	,1)
replace his_ethnscirate	=round(his_ethnscirate	,1)
replace his_ethnsocrate	=round(his_ethnsocrate	,1)
replace wht_ethnmthrate	=round(wht_ethnmthrate	,1)
replace wht_ethnredrate	=round(wht_ethnredrate	,1)
replace wht_ethnwrtrate	=round(wht_ethnwrtrate	,1)
replace wht_ethnscirate	=round(wht_ethnscirate	,1)
replace wht_ethnsocrate	=round(wht_ethnsocrate	,1)
replace sdaarate        =round(sdaarate         ,1)
replace schmthrate_1		=round(schmthrate_1		,1)
replace schredrate_1		=round(schredrate_1		,1)
replace schwrtrate_1		=round(schwrtrate_1		,1)
replace schscirate_1		=round(schscirate_1		,1)
replace schsocrate_1		=round(schsocrate_1		,1)
replace dismthrate_1		=round(dismthrate_1		,1)
replace disredrate_1		=round(disredrate_1		,1)
replace diswrtrate_1		=round(diswrtrate_1		,1)
replace disscirate_1		=round(disscirate_1		,1)
replace dissocrate_1		=round(dissocrate_1		,1)
replace blk_ethnmthrate_1	=round(blk_ethnmthrate_1	,1)
replace blk_ethnredrate_1	=round(blk_ethnredrate_1	,1)
replace blk_ethnwrtrate_1	=round(blk_ethnwrtrate_1	,1)
replace blk_ethnscirate_1	=round(blk_ethnscirate_1	,1)
replace blk_ethnsocrate_1	=round(blk_ethnsocrate_1	,1)
replace his_ethnmthrate_1	=round(his_ethnmthrate_1	,1)
replace his_ethnredrate_1	=round(his_ethnredrate_1	,1)
replace his_ethnwrtrate_1	=round(his_ethnwrtrate_1	,1)
replace his_ethnscirate_1	=round(his_ethnscirate_1	,1)
replace his_ethnsocrate_1	=round(his_ethnsocrate_1	,1)
replace wht_ethnmthrate_1	=round(wht_ethnmthrate_1	,1)
replace wht_ethnredrate_1	=round(wht_ethnredrate_1	,1)
replace wht_ethnwrtrate_1	=round(wht_ethnwrtrate_1	,1)
replace wht_ethnscirate_1	=round(wht_ethnscirate_1	,1)
replace wht_ethnsocrate_1	=round(wht_ethnsocrate_1	,1)
*replace sdaarate_1          =round(sdaarate_1           ,1)

*create year variable
gen long year=200`i'

recast long campus
format %12.0g paircamp

saveold ${working_dir}aeis_`i', replace
}

forvalues i=6(1)7 {

*create current and lagged year locals
local cur=`i'
local lag=`i'-1

*get aeis data 
use ${erc_data}/non_erc/public/AEIS/campus/aeiscamp200`i', clear

*keep relevant pass rates and other variables 
keep campus ca311tm0`cur'r ce311tm0`cur'r cb311tm0`cur'r ch311tm0`cur'r cw311tm0`cur'r /// math
			ca311tr0`cur'r ce311tr0`cur'r cb311tr0`cur'r ch311tr0`cur'r cw311tr0`cur'r /// reading
			ca311tw0`cur'r ce311tw0`cur'r cb311tw0`cur'r ch311tw0`cur'r cw311tw0`cur'r /// writing
			ca311tc0`cur'r ce311tc0`cur'r cb311tc0`cur'r ch311tc0`cur'r cw311tc0`cur'r /// science
			ca311ts0`cur'r ce311ts0`cur'r cb311ts0`cur'r ch311ts0`cur'r cw311ts0`cur'r /// soc studies
			ca311tm0`lag'r ce311tm0`lag'r cb311tm0`lag'r ch311tm0`lag'r cw311tm0`lag'r /// math
			ca311tr0`lag'r ce311tr0`lag'r cb311tr0`lag'r ch311tr0`lag'r cw311tr0`lag'r /// reading
			ca311tw0`lag'r ce311tw0`lag'r cb311tw0`lag'r ch311tw0`lag'r cw311tw0`lag'r /// writing
			ca311tc0`lag'r ce311tc0`lag'r cb311tc0`lag'r ch311tc0`lag'r cw311tc0`lag'r /// science
			ca311ts0`lag'r ce311ts0`lag'r cb311ts0`lag'r ch311ts0`lag'r cw311ts0`lag'r /// soc studies
			ca0su0`cur'r ca0su0`lag'r /// sdaa
			c_rating district cflchart cname paircamp pairname 
			
*create c_rating2 variable
gen long c_rating2=.
replace c_rating2=100 if c_rating=="L"	
replace c_rating2=101 if c_rating=="A"	
replace c_rating2=102 if c_rating=="R"	
replace c_rating2=103 if c_rating=="E"	
label variable c_rating2 "Campus Accountability Rating"	
drop if c_rating2==.	
					

*rename variables so they make sense and will be consistent across years
rename ca311tm*r schmthrate*
rename ca311tr*r schredrate*
rename ca311tw*r schwrtrate*
rename ca311tc*r schscirate*
rename ca311ts*r schsocrate*
rename ce311tm*r dismthrate*
rename ce311tr*r disredrate*
rename ce311tw*r diswrtrate*
rename ce311tc*r disscirate*
rename ce311ts*r dissocrate*
rename cb311tm*r blk_ethnmthrate*
rename cb311tr*r blk_ethnredrate*
rename cb311tw*r blk_ethnwrtrate*
rename cb311tc*r blk_ethnscirate*
rename cb311ts*r blk_ethnsocrate*
rename ch311tm*r his_ethnmthrate*
rename ch311tr*r his_ethnredrate*
rename ch311tw*r his_ethnwrtrate*
rename ch311tc*r his_ethnscirate*
rename ch311ts*r his_ethnsocrate*
rename cw311tm*r wht_ethnmthrate*
rename cw311tr*r wht_ethnredrate*
rename cw311tw*r wht_ethnwrtrate*
rename cw311tc*r wht_ethnscirate*
rename cw311ts*r wht_ethnsocrate*
rename ca0su*r sdaarate*

rename *0`cur' *
rename *0`lag' *_1

*round to the nearest integer
replace schmthrate		=round(schmthrate		,1)
replace schredrate		=round(schredrate		,1)
replace schwrtrate		=round(schwrtrate		,1)
replace schscirate		=round(schscirate		,1)
replace schsocrate		=round(schsocrate		,1)
replace dismthrate		=round(dismthrate		,1)
replace disredrate		=round(disredrate		,1)
replace diswrtrate		=round(diswrtrate		,1)
replace disscirate		=round(disscirate		,1)
replace dissocrate		=round(dissocrate		,1)
replace blk_ethnmthrate	=round(blk_ethnmthrate	,1)
replace blk_ethnredrate	=round(blk_ethnredrate	,1)
replace blk_ethnwrtrate	=round(blk_ethnwrtrate	,1)
replace blk_ethnscirate	=round(blk_ethnscirate	,1)
replace blk_ethnsocrate	=round(blk_ethnsocrate	,1)
replace his_ethnmthrate	=round(his_ethnmthrate	,1)
replace his_ethnredrate	=round(his_ethnredrate	,1)
replace his_ethnwrtrate	=round(his_ethnwrtrate	,1)
replace his_ethnscirate	=round(his_ethnscirate	,1)
replace his_ethnsocrate	=round(his_ethnsocrate	,1)
replace wht_ethnmthrate	=round(wht_ethnmthrate	,1)
replace wht_ethnredrate	=round(wht_ethnredrate	,1)
replace wht_ethnwrtrate	=round(wht_ethnwrtrate	,1)
replace wht_ethnscirate	=round(wht_ethnscirate	,1)
replace wht_ethnsocrate	=round(wht_ethnsocrate	,1)
replace sdaarate        =round(sdaarate         ,1)
replace schmthrate_1		=round(schmthrate_1		,1)
replace schredrate_1		=round(schredrate_1		,1)
replace schwrtrate_1		=round(schwrtrate_1		,1)
replace schscirate_1		=round(schscirate_1		,1)
replace schsocrate_1		=round(schsocrate_1		,1)
replace dismthrate_1		=round(dismthrate_1		,1)
replace disredrate_1		=round(disredrate_1		,1)
replace diswrtrate_1		=round(diswrtrate_1		,1)
replace disscirate_1		=round(disscirate_1		,1)
replace dissocrate_1		=round(dissocrate_1		,1)
replace blk_ethnmthrate_1	=round(blk_ethnmthrate_1	,1)
replace blk_ethnredrate_1	=round(blk_ethnredrate_1	,1)
replace blk_ethnwrtrate_1	=round(blk_ethnwrtrate_1	,1)
replace blk_ethnscirate_1	=round(blk_ethnscirate_1	,1)
replace blk_ethnsocrate_1	=round(blk_ethnsocrate_1	,1)
replace his_ethnmthrate_1	=round(his_ethnmthrate_1	,1)
replace his_ethnredrate_1	=round(his_ethnredrate_1	,1)
replace his_ethnwrtrate_1	=round(his_ethnwrtrate_1	,1)
replace his_ethnscirate_1	=round(his_ethnscirate_1	,1)
replace his_ethnsocrate_1	=round(his_ethnsocrate_1	,1)
replace wht_ethnmthrate_1	=round(wht_ethnmthrate_1	,1)
replace wht_ethnredrate_1	=round(wht_ethnredrate_1	,1)
replace wht_ethnwrtrate_1	=round(wht_ethnwrtrate_1	,1)
replace wht_ethnscirate_1	=round(wht_ethnscirate_1	,1)
replace wht_ethnsocrate_1	=round(wht_ethnsocrate_1	,1)
replace sdaarate_1          =round(sdaarate_1           ,1)

*create year variable
gen long year=200`i'

recast long campus
format %12.0g paircamp

saveold ${working_dir}aeis_`i', replace
}

forvalues i=4(1)4 {

*create current and lagged year locals
local cur=`i'
local lag=`i'-1

*get aeis data 
use ${erc_data}/non_erc/public/AEIS/campus/aeiscamp200`i', clear

*keep relevant pass rates and other variables 
keep campus ca311tm0`cur'r ce311tm0`cur'r cb311tm0`cur'r ch311tm0`cur'r cw311tm0`cur'r /// math
			ca311tr0`cur'r ce311tr0`cur'r cb311tr0`cur'r ch311tr0`cur'r cw311tr0`cur'r /// reading
			ca311tw0`cur'r ce311tw0`cur'r cb311tw0`cur'r ch311tw0`cur'r cw311tw0`cur'r /// writing
			ca311tc0`cur'r ce311tc0`cur'r cb311tc0`cur'r ch311tc0`cur'r cw311tc0`cur'r /// science
			ca311ts0`cur'r ce311ts0`cur'r cb311ts0`cur'r ch311ts0`cur'r cw311ts0`cur'r /// soc studies
			ca311tm0`lag'r ce311tm0`lag'r cb311tm0`lag'r ch311tm0`lag'r cw311tm0`lag'r /// math
			ca311tr0`lag'r ce311tr0`lag'r cb311tr0`lag'r ch311tr0`lag'r cw311tr0`lag'r /// reading
			ca311tw0`lag'r ce311tw0`lag'r cb311tw0`lag'r ch311tw0`lag'r cw311tw0`lag'r /// writing
			ca311tc0`lag'r ce311tc0`lag'r cb311tc0`lag'r ch311tc0`lag'r cw311tc0`lag'r /// science
			ca311ts0`lag'r ce311ts0`lag'r cb311ts0`lag'r ch311ts0`lag'r cw311ts0`lag'r /// soc studies
			c_rating district cflchart cname paircamp pairname 
			
*create c_rating2 variable
gen long c_rating2=.
replace c_rating2=100 if c_rating=="L"	
replace c_rating2=101 if c_rating=="A"	
replace c_rating2=102 if c_rating=="R"	
replace c_rating2=103 if c_rating=="E"	
label variable c_rating2 "Campus Accountability Rating"	
drop if c_rating2==.	
					

*rename variables so they make sense and will be consistent across years
rename ca311tm*r schmthrate*
rename ca311tr*r schredrate*
rename ca311tw*r schwrtrate*
rename ca311tc*r schscirate*
rename ca311ts*r schsocrate*
rename ce311tm*r dismthrate*
rename ce311tr*r disredrate*
rename ce311tw*r diswrtrate*
rename ce311tc*r disscirate*
rename ce311ts*r dissocrate*
rename cb311tm*r blk_ethnmthrate*
rename cb311tr*r blk_ethnredrate*
rename cb311tw*r blk_ethnwrtrate*
rename cb311tc*r blk_ethnscirate*
rename cb311ts*r blk_ethnsocrate*
rename ch311tm*r his_ethnmthrate*
rename ch311tr*r his_ethnredrate*
rename ch311tw*r his_ethnwrtrate*
rename ch311tc*r his_ethnscirate*
rename ch311ts*r his_ethnsocrate*
rename cw311tm*r wht_ethnmthrate*
rename cw311tr*r wht_ethnredrate*
rename cw311tw*r wht_ethnwrtrate*
rename cw311tc*r wht_ethnscirate*
rename cw311ts*r wht_ethnsocrate*

rename *0`cur' *
rename *0`lag' *_1

*round to the nearest integer
replace schmthrate		=round(schmthrate		,1)
replace schredrate		=round(schredrate		,1)
replace schwrtrate		=round(schwrtrate		,1)
replace schscirate		=round(schscirate		,1)
replace schsocrate		=round(schsocrate		,1)
replace dismthrate		=round(dismthrate		,1)
replace disredrate		=round(disredrate		,1)
replace diswrtrate		=round(diswrtrate		,1)
replace disscirate		=round(disscirate		,1)
replace dissocrate		=round(dissocrate		,1)
replace blk_ethnmthrate	=round(blk_ethnmthrate	,1)
replace blk_ethnredrate	=round(blk_ethnredrate	,1)
replace blk_ethnwrtrate	=round(blk_ethnwrtrate	,1)
replace blk_ethnscirate	=round(blk_ethnscirate	,1)
replace blk_ethnsocrate	=round(blk_ethnsocrate	,1)
replace his_ethnmthrate	=round(his_ethnmthrate	,1)
replace his_ethnredrate	=round(his_ethnredrate	,1)
replace his_ethnwrtrate	=round(his_ethnwrtrate	,1)
replace his_ethnscirate	=round(his_ethnscirate	,1)
replace his_ethnsocrate	=round(his_ethnsocrate	,1)
replace wht_ethnmthrate	=round(wht_ethnmthrate	,1)
replace wht_ethnredrate	=round(wht_ethnredrate	,1)
replace wht_ethnwrtrate	=round(wht_ethnwrtrate	,1)
replace wht_ethnscirate	=round(wht_ethnscirate	,1)
replace wht_ethnsocrate	=round(wht_ethnsocrate	,1)
replace schmthrate_1		=round(schmthrate_1		,1)
replace schredrate_1		=round(schredrate_1		,1)
replace schwrtrate_1		=round(schwrtrate_1		,1)
replace schscirate_1		=round(schscirate_1		,1)
replace schsocrate_1		=round(schsocrate_1		,1)
replace dismthrate_1		=round(dismthrate_1		,1)
replace disredrate_1		=round(disredrate_1		,1)
replace diswrtrate_1		=round(diswrtrate_1		,1)
replace disscirate_1		=round(disscirate_1		,1)
replace dissocrate_1		=round(dissocrate_1		,1)
replace blk_ethnmthrate_1	=round(blk_ethnmthrate_1	,1)
replace blk_ethnredrate_1	=round(blk_ethnredrate_1	,1)
replace blk_ethnwrtrate_1	=round(blk_ethnwrtrate_1	,1)
replace blk_ethnscirate_1	=round(blk_ethnscirate_1	,1)
replace blk_ethnsocrate_1	=round(blk_ethnsocrate_1	,1)
replace his_ethnmthrate_1	=round(his_ethnmthrate_1	,1)
replace his_ethnredrate_1	=round(his_ethnredrate_1	,1)
replace his_ethnwrtrate_1	=round(his_ethnwrtrate_1	,1)
replace his_ethnscirate_1	=round(his_ethnscirate_1	,1)
replace his_ethnsocrate_1	=round(his_ethnsocrate_1	,1)
replace wht_ethnmthrate_1	=round(wht_ethnmthrate_1	,1)
replace wht_ethnredrate_1	=round(wht_ethnredrate_1	,1)
replace wht_ethnwrtrate_1	=round(wht_ethnwrtrate_1	,1)
replace wht_ethnscirate_1	=round(wht_ethnscirate_1	,1)
replace wht_ethnsocrate_1	=round(wht_ethnsocrate_1	,1)

*create year variable
gen long year=200`i'

recast long campus
format %12.0g paircamp

saveold ${working_dir}aeis_`i', replace
}

}

***************************Merge AEIS and MSR data******************************

if `msr_aeis'==1 {

*append all the aeis files
use using ${working_dir}aeis_1, clear
append using ${working_dir}aeis_2
append using ${working_dir}aeis_4
append using ${working_dir}aeis_5
append using ${working_dir}aeis_6
append using ${working_dir}aeis_7
append using ${working_dir}aeis_8
saveold ${working_dir}aeis_all, replace

*merge this with the public accountabilty data file (this is file of publicly available test taker and passer counts by year, campus, subject, and group)

	*first we need to put together the public accountability data
	use ${working_dir}pubacct04, clear
	append using ${working_dir}pubacct05
	append using ${working_dir}pubacct06
	append using ${working_dir}pubacct07
	append using ${working_dir}pubacct08
	saveold ${working_dir}pubacct, replace
	*get data from 2001 & 2002
	use ${working_dir}msr, clear
	keep if year>=2001 & year<=2002
	append using ${working_dir}pubacct
	sort campus year
	saveold ${working_dir}pubacct_0108, replace
	
*now pubacct_0108 with aeis_all
use ${working_dir}aeis_all, clear
merge 1:1 campus year using ${working_dir}pubacct_0108, keep(match) nogen
*merge with sdaa_all.dta to get sdaa rates and group sizes
*merge 1:1 campus year using ${working_dir}sdaa_all, keep(master match) nogen  COMMENTED OUT BECAUSE I GET THIS FROM PUBACCT_0108 NOW

saveold ${working_dir}msr_aeis_all, replace

}



**************************Track First Year of Campus****************************

if `trackcamps'==1 {

*start by mergeing fall campus file with spring file for every year from 1993 up to 2008

forvalues i=1993(1)2008 {
	use ${camp_path}campus`i', clear
	gen year=`i'
	saveold ${working_dir}camp`i', replace	
}

*append all the campYYYY files 
use ${working_dir}camp1993, clear
forvalues i=1994(1)2008 {
	append using ${working_dir}camp`i'
}
recast long campus
recast long year
saveold ${working_dir}camp1993_2008, replace

*xtset campus year, and track first year of a campus
xtset campus year
sort campus year
gen fyear=0
by campus: replace fyear=1 if _n==1
keep campus year fyear p_hgrade o_hgrade camptype
saveold ${working_dir}camp1993_2008, replace

keep if year>=2001 & year<=2008

saveold ${working_dir}camps01_08, replace

}


*********Drop campuses in first year or that teach grades higher than 6*********

if `trimsamp'==1 {

use ${working_dir}msr_aeis_all, clear
merge 1:1 campus year using ${working_dir}camp1993_2008, keep(match) nogen

*drop campuses in their first year of operation
drop if fyear==1
*drop campuses that serve higher than grade 6
drop if p_hgrade>6
*dropout alternaltive instruction campuses
drop if camptype!=1
*drop paired campuses
drop if paircamp!=campus & paircamp!=.


saveold ${working_dir}pub_accountability_samp, replace

}


*****************************Minimum group size********************8************

if `minsize'==1 {

use ${working_dir}pub_accountability_samp, clear

*all MSR data codes start with a "c"
*MSR data group codes: a=all, e=disadvantaged, b=black, h=hispanic, w=white
*MSR data subject codes: m=math, r=reading, w=writing, c=science
*MSR variables codes (last letter): n=# of passers, d=# of test takers, f=flag for meeting size requirement
*cemf is disadvantaged math flag for having enough students to count towards accountability

*Don't need to keep social studies pass rates for elementary campuses
drop *socrate

*dropout passrates where student group size is not large enough to be counted
	*economic disadvantaged
	replace dismthrate=. if cemf==0
	replace disredrate=. if cerf==0
	replace diswrtrate=. if cewf==0
	replace disscirate=. if cecf==0
	*black students
	replace blk_ethnmthrate=. if cbmf==0
	replace blk_ethnredrate=. if cbrf==0
	replace blk_ethnwrtrate=. if cbwf==0
	replace blk_ethnscirate=. if cbcf==0
	*hispanic students
	replace his_ethnmthrate=. if chmf==0
	replace his_ethnredrate=. if chrf==0
	replace his_ethnwrtrate=. if chwf==0
	replace his_ethnscirate=. if chcf==0
	*white students
	replace wht_ethnmthrate=. if cwmf==0
	replace wht_ethnredrate=. if cwrf==0
	replace wht_ethnwrtrate=. if cwwf==0
	replace wht_ethnscirate=. if cwcf==0
	*sdaa
	replace sdaarate=. if csdf==0
	
*dropout invalid passrates (these are either -1 or -4 in aeis data)
	*all students
	replace schmthrate=. if schmthrate<0
	replace schredrate=. if schredrate<0
	replace schwrtrate=. if schwrtrate<0
	replace schscirate=. if schscirate<0	
	*economic disadvantaged
	replace dismthrate=. if dismthrate<0
	replace disredrate=. if disredrate<0
	replace diswrtrate=. if diswrtrate<0
	replace disscirate=. if disscirate<0
	*black students
	replace blk_ethnmthrate=. if blk_ethnmthrate<0
	replace blk_ethnredrate=. if blk_ethnredrate<0
	replace blk_ethnwrtrate=. if blk_ethnwrtrate<0
	replace blk_ethnscirate=. if blk_ethnscirate<0
	*hispanic students
	replace his_ethnmthrate=. if his_ethnmthrate<0
	replace his_ethnredrate=. if his_ethnredrate<0
	replace his_ethnwrtrate=. if his_ethnwrtrate<0
	replace his_ethnscirate=. if his_ethnscirate<0
	*white students
	replace wht_ethnmthrate=. if wht_ethnmthrate<0
	replace wht_ethnredrate=. if wht_ethnredrate<0
	replace wht_ethnwrtrate=. if wht_ethnwrtrate<0
	replace wht_ethnscirate=. if wht_ethnscirate<0
	*sdaa
	replace sdaarate=. if sdaarate<0
	
	*all students
	replace schmthrate_1=. if schmthrate_1<0
	replace schredrate_1=. if schredrate_1<0
	replace schwrtrate_1=. if schwrtrate_1<0
	replace schscirate_1=. if schscirate_1<0	
	*economic disadvantaged
	replace dismthrate_1=. if dismthrate_1<0
	replace disredrate_1=. if disredrate_1<0
	replace diswrtrate_1=. if diswrtrate_1<0
	replace disscirate_1=. if disscirate_1<0
	*black students
	replace blk_ethnmthrate_1=. if blk_ethnmthrate_1<0
	replace blk_ethnredrate_1=. if blk_ethnredrate_1<0
	replace blk_ethnwrtrate_1=. if blk_ethnwrtrate_1<0
	replace blk_ethnscirate_1=. if blk_ethnscirate_1<0
	*hispanic students
	replace his_ethnmthrate_1=. if his_ethnmthrate_1<0
	replace his_ethnredrate_1=. if his_ethnredrate_1<0
	replace his_ethnwrtrate_1=. if his_ethnwrtrate_1<0
	replace his_ethnscirate_1=. if his_ethnscirate_1<0
	*white students
	replace wht_ethnmthrate_1=. if wht_ethnmthrate_1<0
	replace wht_ethnredrate_1=. if wht_ethnredrate_1<0
	replace wht_ethnwrtrate_1=. if wht_ethnwrtrate_1<0
	replace wht_ethnscirate_1=. if wht_ethnscirate_1<0
	*sdaa
	replace sdaarate_1=. if sdaarate_1<0

	
*Create continuous pass rate variables 
	*sdaa
	gen csdaarate=(csdn/csdd)*100 if csdn>=0 & csdd>=0 & csdn!=. & csdd!=.
	gen csdaarate_1=(csdn_1/csdd_1)*100 if csdn_1>=0 & csdd_1>=0 & csdn_1!=. & csdd_1!=.
	*math
	gen      cschmthrate=(camn/camd)*100 if camn>=0 & camd>=0 & camn!=. & camd!=.
	gen      cdismthrate=(cemn/cemd)*100 if cemn>=0 & cemd>=0 & cemn!=. & cemd!=.
	gen cblk_ethnmthrate=(cbmn/cbmd)*100 if cbmn>=0 & cbmd>=0 & cbmn!=. & cbmd!=.
	gen chis_ethnmthrate=(chmn/chmd)*100 if chmn>=0 & chmd>=0 & chmn!=. & chmd!=.
	gen cwht_ethnmthrate=(cwmn/cwmd)*100 if cwmn>=0 & cwmd>=0 & cwmn!=. & cwmd!=.
	gen      cschmthrate_1=(camn_1/camd_1)*100 if camn_1>=0 & camd_1>=0 & camn_1!=. & camd_1!=.
	gen      cdismthrate_1=(cemn_1/cemd_1)*100 if cemn_1>=0 & cemd_1>=0 & cemn_1!=. & cemd_1!=.
	gen cblk_ethnmthrate_1=(cbmn_1/cbmd_1)*100 if cbmn_1>=0 & cbmd_1>=0 & cbmn_1!=. & cbmd_1!=.
	gen chis_ethnmthrate_1=(chmn_1/chmd_1)*100 if chmn_1>=0 & chmd_1>=0 & chmn_1!=. & chmd_1!=.
	gen cwht_ethnmthrate_1=(cwmn_1/cwmd_1)*100 if cwmn_1>=0 & cwmd_1>=0 & cwmn_1!=. & cwmd_1!=.
	*reading
	gen      cschredrate=(carn/card)*100 if carn>=0 & card>=0 & carn!=. & card!=.
	gen      cdisredrate=(cern/cerd)*100 if cern>=0 & cerd>=0 & cern!=. & cerd!=.
	gen cblk_ethnredrate=(cbrn/cbrd)*100 if cbrn>=0 & cbrd>=0 & cbrn!=. & cbrd!=.
	gen chis_ethnredrate=(chrn/chrd)*100 if chrn>=0 & chrd>=0 & chrn!=. & chrd!=.
	gen cwht_ethnredrate=(cwrn/cwrd)*100 if cwrn>=0 & cwrd>=0 & cwrn!=. & cwrd!=.
	gen      cschredrate_1=(carn_1/card_1)*100 if carn_1>=0 & card_1>=0 & carn_1!=. & card_1!=.
	gen      cdisredrate_1=(cern_1/cerd_1)*100 if cern_1>=0 & cerd_1>=0 & cern_1!=. & cerd_1!=.
	gen cblk_ethnredrate_1=(cbrn_1/cbrd_1)*100 if cbrn_1>=0 & cbrd_1>=0 & cbrn_1!=. & cbrd_1!=.
	gen chis_ethnredrate_1=(chrn_1/chrd_1)*100 if chrn_1>=0 & chrd_1>=0 & chrn_1!=. & chrd_1!=.
	gen cwht_ethnredrate_1=(cwrn_1/cwrd_1)*100 if cwrn_1>=0 & cwrd_1>=0 & cwrn_1!=. & cwrd_1!=.
	*writing
	gen      cschwrtrate=(cawn/cawd)*100 if cawn>=0 & cawd>=0 & cawn!=. & cawd!=.
	gen      cdiswrtrate=(cewn/cewd)*100 if cewn>=0 & cewd>=0 & cewn!=. & cewd!=.
	gen cblk_ethnwrtrate=(cbwn/cbwd)*100 if cbwn>=0 & cbwd>=0 & cbwn!=. & cbwd!=.
	gen chis_ethnwrtrate=(chwn/chwd)*100 if chwn>=0 & chwd>=0 & chwn!=. & chwd!=.
	gen cwht_ethnwrtrate=(cwwn/cwwd)*100 if cwwn>=0 & cwwd>=0 & cwwn!=. & cwwd!=.
	gen      cschwrtrate_1=(cawn_1/cawd_1)*100 if cawn_1>=0 & cawd_1>=0 & cawn_1!=. & cawd_1!=.
	gen      cdiswrtrate_1=(cewn_1/cewd_1)*100 if cewn_1>=0 & cewd_1>=0 & cewn_1!=. & cewd_1!=.
	gen cblk_ethnwrtrate_1=(cbwn_1/cbwd_1)*100 if cbwn_1>=0 & cbwd_1>=0 & cbwn_1!=. & cbwd_1!=.
	gen chis_ethnwrtrate_1=(chwn_1/chwd_1)*100 if chwn_1>=0 & chwd_1>=0 & chwn_1!=. & chwd_1!=.
	gen cwht_ethnwrtrate_1=(cwwn_1/cwwd_1)*100 if cwwn_1>=0 & cwwd_1>=0 & cwwn_1!=. & cwwd_1!=.
	*science
	gen      cschscirate=(cacn/cacd)*100 if cacn>=0 & cacd>=0 & cacn!=. & cacd!=.
	gen      cdisscirate=(cecn/cecd)*100 if cecn>=0 & cecd>=0 & cecn!=. & cecd!=.
	gen cblk_ethnscirate=(cbcn/cbcd)*100 if cbcn>=0 & cbcd>=0 & cbcn!=. & cbcd!=.
	gen chis_ethnscirate=(chcn/chcd)*100 if chcn>=0 & chcd>=0 & chcn!=. & chcd!=.
	gen cwht_ethnscirate=(cwcn/cwcd)*100 if cwcn>=0 & cwcd>=0 & cwcn!=. & cwcd!=.
	gen      cschscirate_1=(cacn_1/cacd_1)*100 if cacn_1>=0 & cacd_1>=0 & cacn_1!=. & cacd_1!=.
	gen      cdisscirate_1=(cecn_1/cecd_1)*100 if cecn_1>=0 & cecd_1>=0 & cecn_1!=. & cecd_1!=.
	gen cblk_ethnscirate_1=(cbcn_1/cbcd_1)*100 if cbcn_1>=0 & cbcd_1>=0 & cbcn_1!=. & cbcd_1!=.
	gen chis_ethnscirate_1=(chcn_1/chcd_1)*100 if chcn_1>=0 & chcd_1>=0 & chcn_1!=. & chcd_1!=.
	gen cwht_ethnscirate_1=(cwcn_1/cwcd_1)*100 if cwcn_1>=0 & cwcd_1>=0 & cwcn_1!=. & cwcd_1!=.
	
*some continuous rates don't match the aeis rates bc cXXn and cXXd had values of -1(done for masking) even though cXXf==1
*replace these values with the rates from aeis
	*sdaa
	replace csdaarate=sdaarate if csdaarate==. & csdf==1
	replace csdaarate_1=sdaarate_1 if csdaarate_1==.
	*math
	replace      cschmthrate=     schmthrate if      cschmthrate==. & camf==1
	replace      cdismthrate=     dismthrate if      cdismthrate==. & cemf==1
	replace cblk_ethnmthrate=blk_ethnmthrate if cblk_ethnmthrate==. & cbmf==1
	replace chis_ethnmthrate=his_ethnmthrate if chis_ethnmthrate==. & chmf==1
	replace cwht_ethnmthrate=wht_ethnmthrate if cwht_ethnmthrate==. & cwmf==1
	replace      cschmthrate_1=     schmthrate_1 if      cschmthrate_1==.
	replace      cdismthrate_1=     dismthrate_1 if      cdismthrate_1==.
	replace cblk_ethnmthrate_1=blk_ethnmthrate_1 if cblk_ethnmthrate_1==.
	replace chis_ethnmthrate_1=his_ethnmthrate_1 if chis_ethnmthrate_1==.
	replace cwht_ethnmthrate_1=wht_ethnmthrate_1 if cwht_ethnmthrate_1==.
	*reading
	replace      cschredrate=     schredrate if      cschredrate==. & carf==1
	replace      cdisredrate=     disredrate if      cdisredrate==. & cerf==1
	replace cblk_ethnredrate=blk_ethnredrate if cblk_ethnredrate==. & cbrf==1
	replace chis_ethnredrate=his_ethnredrate if chis_ethnredrate==. & chrf==1
	replace cwht_ethnredrate=wht_ethnredrate if cwht_ethnredrate==. & cwrf==1
	replace      cschredrate_1=     schredrate_1 if      cschredrate_1==.
	replace      cdisredrate_1=     disredrate_1 if      cdisredrate_1==.
	replace cblk_ethnredrate_1=blk_ethnredrate_1 if cblk_ethnredrate_1==.
	replace chis_ethnredrate_1=his_ethnredrate_1 if chis_ethnredrate_1==.
	replace cwht_ethnredrate_1=wht_ethnredrate_1 if cwht_ethnredrate_1==.
	*writing
	replace      cschwrtrate=     schwrtrate if      cschwrtrate==. & cawf==1
	replace      cdiswrtrate=     diswrtrate if      cdiswrtrate==. & cewf==1
	replace cblk_ethnwrtrate=blk_ethnwrtrate if cblk_ethnwrtrate==. & cbwf==1
	replace chis_ethnwrtrate=his_ethnwrtrate if chis_ethnwrtrate==. & chwf==1
	replace cwht_ethnwrtrate=wht_ethnwrtrate if cwht_ethnwrtrate==. & cwwf==1
	replace      cschwrtrate_1=     schwrtrate_1 if      cschwrtrate_1==.
	replace      cdiswrtrate_1=     diswrtrate_1 if      cdiswrtrate_1==.
	replace cblk_ethnwrtrate_1=blk_ethnwrtrate_1 if cblk_ethnwrtrate_1==.
	replace chis_ethnwrtrate_1=his_ethnwrtrate_1 if chis_ethnwrtrate_1==.
	replace cwht_ethnwrtrate_1=wht_ethnwrtrate_1 if cwht_ethnwrtrate_1==.
	*science
	replace      cschscirate=     schscirate if      cschscirate==. & cacf==1
	replace      cdisscirate=     disscirate if      cdisscirate==. & cecf==1
	replace cblk_ethnscirate=blk_ethnscirate if cblk_ethnscirate==. & cbcf==1
	replace chis_ethnscirate=his_ethnscirate if chis_ethnscirate==. & chcf==1
	replace cwht_ethnscirate=wht_ethnscirate if cwht_ethnscirate==. & cwcf==1
	replace      cschscirate_1=     schscirate_1 if      cschscirate_1==.
	replace      cdisscirate_1=     disscirate_1 if      cdisscirate_1==.
	replace cblk_ethnscirate_1=blk_ethnscirate_1 if cblk_ethnscirate_1==.
	replace chis_ethnscirate_1=his_ethnscirate_1 if chis_ethnscirate_1==.
	replace cwht_ethnscirate_1=wht_ethnscirate_1 if cwht_ethnscirate_1==.

saveold ${working_dir}pub_accountability_samp_msr, replace

*save a sample of lagged reading and math pass rates to merge back to analysis sample
replace cschmthrate_1=schmthrate_1 if cschmthrate_1==.
replace cschredrate_1=schredrate_1 if cschredrate_1==.
keep campus year cschmthrate_1 cschredrate_1

saveold ${working_dir}lagged_math_read, replace

}


***********Figure out who gets required improvement in the TAKS years***********

if `reqimpr'==1 {

use ${working_dir}pub_accountability_samp_msr, clear

*required improvement is used in 2004-2008
*thresholds vary by rating, threshold, and year
	*I don't try to be fancy, I just use a bunch of "&" conditions

local recgrps 	schmth dismth blk_ethnmth his_ethnmth wht_ethnmth ///
				schred disred blk_ethnred his_ethnred wht_ethnred ///
				schwrt diswrt blk_ethnwrt his_ethnwrt wht_ethnwrt ///
				schsci dissci blk_ethnsci his_ethnsci wht_ethnsci
				
local accmth	schmth dismth blk_ethnmth his_ethnmth wht_ethnmth
local accred	schred disred blk_ethnred his_ethnred wht_ethnred
local accwrt	schwrt diswrt blk_ethnwrt his_ethnwrt wht_ethnwrt
local accsci	schsci dissci blk_ethnsci his_ethnsci wht_ethnsci

*2004
	*recognized (need to take into account performance floor)
		foreach i in `recgrps' {
			gen rrimp_`i'=1 if `i'rate<=69 & `i'rate>=65 & (`i'rate_1+70)/2<=`i'rate & year==2004 & `i'rate!=. & `i'rate_1!=. 
		}
		gen rrimp_sdaa=1 if sdaarate<=69 & sdaarate>=65 & (sdaarate_1+70)/2<=sdaarate & year==2004 & sdaarate!=. & sdaarate_1!=.
	*acceptable (varies by subject, but no performance floor requirement)
		*math
		foreach i in `accmth' {
			gen arimp_`i'=1 if `i'rate<35 & (`i'rate_1+35)/2<=`i'rate & year==2004 & `i'rate!=. & `i'rate_1!=.
		}
		*reading
		foreach i in `accred' {
			gen arimp_`i'=1 if `i'rate<50 & (`i'rate_1+50)/2<=`i'rate & year==2004 & `i'rate!=. & `i'rate_1!=.
		}		
		*writing
		foreach i in `accwrt' {
			gen arimp_`i'=1 if `i'rate<50 & (`i'rate_1+50)/2<=`i'rate & year==2004 & `i'rate!=. & `i'rate_1!=.
		}
		*science
		foreach i in `accsci' {
			gen arimp_`i'=1 if `i'rate<25 & (`i'rate_1+25)/2<=`i'rate & year==2004 & `i'rate!=. & `i'rate_1!=.
		}
		*sdaa
		gen arimp_sdaa=1 if sdaarate<50 & (sdaarate_1+50)/2<=sdaarate & year==2004 & sdaarate!=. & sdaarate_1!=.

*2005
	*recognized (need to take into account performance floor)
		foreach i in `recgrps' {
			replace rrimp_`i'=1 if `i'rate<=69 &`i'rate>=65 & (`i'rate_1+70)/2<=`i'rate & year==2005 & `i'rate!=. & `i'rate_1!=.
		}
	*acceptable (varies by subject, but no performance floor requirement)
		*math
		foreach i in `accmth' {
			replace arimp_`i'=1 if `i'rate<35 & (`i'rate_1+35)/2<=`i'rate & year==2005 & `i'rate!=. & `i'rate_1!=.
		}
		*reading
		foreach i in `accred' {
			replace arimp_`i'=1 if `i'rate<50 & (`i'rate_1+50)/2<=`i'rate & year==2005 & `i'rate!=. & `i'rate_1!=.
		}		
		*writing
		foreach i in `accwrt' {
			replace arimp_`i'=1 if `i'rate<50 & (`i'rate_1+50)/2<=`i'rate & year==2005 & `i'rate!=. & `i'rate_1!=.
		}
		*science
		foreach i in `accsci' {
			replace arimp_`i'=1 if `i'rate<25 & (`i'rate_1+25)/2<=`i'rate & year==2005 & `i'rate!=. & `i'rate_1!=.
		}	
		
*2006
	*recognized (need to take into account performance floor)
		foreach i in `recgrps' {
			replace rrimp_`i'=1 if `i'rate<=69 & `i'rate>=65 & (`i'rate_1+70)/2<=`i'rate & year==2006 & `i'rate!=. & `i'rate_1!=.
		}
		replace rrimp_sdaa=1 if sdaarate<=69 & sdaarate>=65 & (sdaarate_1+70)/2<=sdaarate & year==2006 & sdaarate!=. & sdaarate_1!=.
	*acceptable (varies by subject, but no performance floor requirement)
		*math
		foreach i in `accmth' {
			replace arimp_`i'=1 if `i'rate<40 & (`i'rate_1+40)/2<=`i'rate & year==2006 & `i'rate!=. & `i'rate_1!=.
		}
		*reading
		foreach i in `accred' {
			replace arimp_`i'=1 if `i'rate<60 & (`i'rate_1+60)/2<=`i'rate & year==2006 & `i'rate!=. & `i'rate_1!=.
		}		
		*writing
		foreach i in `accwrt' {
			replace arimp_`i'=1 if `i'rate<60 & (`i'rate_1+60)/2<=`i'rate & year==2006 & `i'rate!=. & `i'rate_1!=.
		}
		*science
		foreach i in `accsci' {
			replace arimp_`i'=1 if `i'rate<35 & (`i'rate_1+35)/2<=`i'rate & year==2006 & `i'rate!=. & `i'rate_1!=.
		}
		*sdaa
		replace arimp_sdaa=1 if sdaarate<50 & (sdaarate_1+50)/2<=sdaarate & year==2006 & sdaarate!=. & sdaarate_1!=.		

*2007
	*recognized (need to take into account performance floor)
		foreach i in `recgrps' {
			replace rrimp_`i'=1 if `i'rate<=74 & `i'rate>=70 & (`i'rate_1+75)/2<=`i'rate & year==2007 & `i'rate!=. & `i'rate_1!=.
		}
		replace rrimp_sdaa=1 if sdaarate<=69 & sdaarate>=65 & (sdaarate_1+70)/2<=sdaarate & year==2007 & sdaarate!=. & sdaarate_1!=.
	*acceptable (varies by subject, but no performance floor requirement)
		*math
		foreach i in `accmth' {
			replace arimp_`i'=1 if `i'rate<45 & (`i'rate_1+45)/2<=`i'rate & year==2007 & `i'rate!=. & `i'rate_1!=.
		}
		*reading
		foreach i in `accred' {
			replace arimp_`i'=1 if `i'rate<65 & (`i'rate_1+65)/2<=`i'rate & year==2007 & `i'rate!=. & `i'rate_1!=.
		}		
		*writing
		foreach i in `accwrt' {
			replace arimp_`i'=1 if `i'rate<65 & (`i'rate_1+65)/2<=`i'rate & year==2007 & `i'rate!=. & `i'rate_1!=.
		}
		*science
		foreach i in `accsci' {
			replace arimp_`i'=1 if `i'rate<40 & (`i'rate_1+40)/2<=`i'rate & year==2007 & `i'rate!=. & `i'rate_1!=.
		}	
		*sdaa
		replace arimp_sdaa=1 if sdaarate<50 & (sdaarate_1+50)/2<=sdaarate & year==2006 & sdaarate!=. & sdaarate_1!=.

*2008
	*recognized (need to take into account performance floor)
		foreach i in `recgrps' {
			replace rrimp_`i'=1 if `i'rate<=74 & `i'rate>=70 & (`i'rate_1+75)/2<=`i'rate & year==2008 & `i'rate!=. & `i'rate_1!=.
		}
	*acceptable (varies by subject, but no performance floor requirement)
		*math
		foreach i in `accmth' {
			replace arimp_`i'=1 if `i'rate<50 & (`i'rate_1+50)/2<=`i'rate & year==2008 & `i'rate!=. & `i'rate_1!=.
		}
		*reading
		foreach i in `accred' {
			replace arimp_`i'=1 if `i'rate<70 & (`i'rate_1+70)/2<=`i'rate & year==2008 & `i'rate!=. & `i'rate_1!=.
		}		
		*writing
		foreach i in `accwrt' {
			replace arimp_`i'=1 if `i'rate<65 & (`i'rate_1+65)/2<=`i'rate & year==2008 & `i'rate!=. & `i'rate_1!=.
		}
		*science
		foreach i in `accsci' {
			replace arimp_`i'=1 if `i'rate<45 & (`i'rate_1+45)/2<=`i'rate & year==2008 & `i'rate!=. & `i'rate_1!=.
		}	
		
saveold ${working_dir}pub_accountability_samp_msr_ri, replace
		
}
***************Figure out who gets an exception in the TAKS years***************

if `exceptions'==1 {

use ${working_dir}pub_accountability_samp_msr_ri, clear

*exceptions are granted for the years 2004-2008
*need to track them bc we should not grant exceptions to the same groupXsubject 2 years in a row
*number exceptions and performance floors can vary by year

local studgrps 	schmth dismth blk_ethnmth his_ethnmth wht_ethnmth ///
				schred disred blk_ethnred his_ethnred wht_ethnred ///
				schwrt diswrt blk_ethnwrt his_ethnwrt wht_ethnwrt ///
				schsci dissci blk_ethnsci his_ethnsci wht_ethnsci

local accmth	schmth dismth blk_ethnmth his_ethnmth wht_ethnmth
local accred	schred disred blk_ethnred his_ethnred wht_ethnred
local accwrt	schwrt diswrt blk_ethnwrt his_ethnwrt wht_ethnwrt
local accsci	schsci dissci blk_ethnsci his_ethnsci wht_ethnsci
				
*its going to be easier to pass out exceptions if we go ahead and define statatory thesholds
	*2001
	*All groups math, reading, and writing
		foreach i in `accmth' `accred' `accwrt'{
		gen `i'exesta=90.0 if year==2001
		gen `i'recsta=80.0 if year==2001
		gen `i'accsta=50.0 if year==2001
		gen c`i'exesta=89.95 if year==2001
		gen c`i'recsta=79.95 if year==2001
		gen c`i'accsta=49.95 if year==2001
		}
	*2002
	*All groups math, reading, and writing
		foreach i in `accmth' `accred' `accwrt'{
		replace `i'exesta=90.0 if year==2002
		replace `i'recsta=80.0 if year==2002
		replace `i'accsta=55.0 if year==2002
		replace c`i'exesta=89.95 if year==2002
		replace c`i'recsta=79.95 if year==2002
		replace c`i'accsta=54.95 if year==2002
		}
	*2004
	*Exemplary and Recognized
		*All groups 
		foreach i in `accmth' `accred' `accwrt' {
		replace `i'exesta=90 if year==2004
		replace `i'recsta=70 if year==2004
		replace c`i'exesta=89.5 if year==2004
		replace c`i'recsta=69.5 if year==2004
		}
		foreach i in `accsci' {
		gen `i'exesta=90 if year==2004
		gen `i'recsta=70 if year==2004
		gen c`i'exesta=89.5 if year==2004
		gen c`i'recsta=69.5 if year==2004
		}
		gen sdaaexesta=90 if year==2004
		gen sdaarecsta=70 if year==2004
		gen sdaaaccsta=50 if year==2004
		gen csdaaexesta=89.5 if year==2004
		gen csdaarecsta=69.5 if year==2004
		gen csdaaaccsta=49.5 if year==2004
	*Acceptable
		*Math
		foreach i in `accmth' {
		replace `i'accsta=35 if year==2004
		replace c`i'accsta=34.5 if year==2004
		}
		*Reading
		foreach i in `accred' {
		replace `i'accsta=50 if year==2004
		replace c`i'accsta=49.5 if year==2004
		}
		*Writing
		foreach i in `accwrt' {
		replace `i'accsta=50 if year==2004
		replace c`i'accsta=49.5 if year==2004
		}	
		*Science
		foreach i in `accsci' {
		gen `i'accsta=25 if year==2004
		gen c`i'accsta=24.5 if year==2004
		}	
	*2005
	*Exemplary and Recognized
		*All groups 
		foreach i in `studgrps' {
		replace `i'exesta=90 if year==2005
		replace `i'recsta=70 if year==2005
		replace c`i'exesta=89.5 if year==2005
		replace c`i'recsta=69.5 if year==2005		
		}
		replace sdaaexesta=90 if year==2005
		replace sdaarecsta=70 if year==2005
		replace sdaaaccsta=50 if year==2005
		replace csdaaexesta=89.5 if year==2005
		replace csdaarecsta=69.5 if year==2005
		replace csdaaaccsta=49.5 if year==2005
	*Acceptable
		*Math
		foreach i in `accmth' {
		replace `i'accsta=35 if year==2005
		replace c`i'accsta=34.5 if year==2005
		}
		*Reading
		foreach i in `accred' {
		replace `i'accsta=50 if year==2005
		replace c`i'accsta=49.5 if year==2005
		}
		*Writing
		foreach i in `accwrt' {
		replace `i'accsta=50 if year==2005
		replace c`i'accsta=49.5 if year==2005
		}	
		*Science
		foreach i in `accsci' {
		replace `i'accsta=25 if year==2005
		replace c`i'accsta=24.5 if year==2005
		}	
	*2006
	*Exemplary and Recognized
		*All groups 
		foreach i in `studgrps' {
		replace `i'exesta=90 if year==2006
		replace `i'recsta=70 if year==2006
		replace c`i'exesta=89.5 if year==2006
		replace c`i'recsta=69.5 if year==2006
		}
		replace sdaaexesta=90 if year==2006
		replace sdaarecsta=70 if year==2006
		replace sdaaaccsta=50 if year==2006
		replace csdaaexesta=89.5 if year==2006
		replace csdaarecsta=69.5 if year==2006
		replace csdaaaccsta=49.5 if year==2006
	*Acceptable
		*Math
		foreach i in `accmth' {
		replace `i'accsta=40 if year==2006
		replace c`i'accsta=39.5 if year==2006
		}
		*Reading
		foreach i in `accred' {
		replace `i'accsta=60 if year==2006
		replace c`i'accsta=59.5 if year==2006
		}
		*Writing
		foreach i in `accwrt' {
		replace `i'accsta=60 if year==2006
		replace c`i'accsta=59.5 if year==2006
		}	
		*Science
		foreach i in `accsci' {
		replace `i'accsta=35 if year==2006
		replace c`i'accsta=34.5 if year==2006
		}	
	*2007
	*Exemplary and Recognized
		*All groups 
		foreach i in `studgrps' {
		replace `i'exesta=90 if year==2007
		replace `i'recsta=75 if year==2007
		replace c`i'exesta=89.5 if year==2007
		replace c`i'recsta=74.5 if year==2007
		}
		replace sdaaexesta=90 if year==2007
		replace sdaarecsta=70 if year==2007
		replace sdaaaccsta=50 if year==2007
		replace csdaaexesta=89.5 if year==2007
		replace csdaarecsta=69.5 if year==2007
		replace csdaaaccsta=49.5 if year==2007
	*Acceptable
		*Math
		foreach i in `accmth' {
		replace `i'accsta=45 if year==2007
		replace c`i'accsta=44.5 if year==2007
		}
		*Reading
		foreach i in `accred' {
		replace `i'accsta=65 if year==2007
		replace c`i'accsta=64.5 if year==2007
		}
		*Writing
		foreach i in `accwrt' {
		replace `i'accsta=65 if year==2007
		replace c`i'accsta=64.5 if year==2007
		}	
		*Science
		foreach i in `accsci' {
		replace `i'accsta=40 if year==2007
		replace c`i'accsta=69.5 if year==2007
		}	
	*2008
	*Exemplary and Recognized
		*All groups 
		foreach i in `studgrps' {
		replace `i'exesta=90 if year==2008
		replace `i'recsta=75 if year==2008
		replace c`i'exesta=89.5 if year==2008
		replace c`i'recsta=74.5 if year==2008
		}
	*Acceptable
		*Math
		foreach i in `accmth' {
		replace `i'accsta=50 if year==2008
		replace c`i'accsta=49.5 if year==2008
		}
		*Reading
		foreach i in `accred' {
		replace `i'accsta=70 if year==2008
		replace c`i'accsta=69.5 if year==2008
		}
		*Writing
		foreach i in `accwrt' {
		replace `i'accsta=65 if year==2008
		replace c`i'accsta=64.5 if year==2008
		}	
		*Science
		foreach i in `accsci' {
		replace `i'accsta=45 if year==2008
		replace `i'accsta=44.5 if year==2008
		}				
			
				
*Start by counting the number of assessments in each campusXyear in 2004-2008
	*we already dropped out any assessments that don't count towards a rating in the minsize section on line 305
	*so we just need to count up the groups with non-missing pass rates
	foreach i in `studgrps' sdaa {
		gen `i'assess=0 if year>=2004 & year<=2008
		replace `i'assess=1 if `i'rate!=. & year>=2004 & year<=2008
	}
	
local grpassess 	schmthassess dismthassess blk_ethnmthassess his_ethnmthassess wht_ethnmthassess ///
					schredassess disredassess blk_ethnredassess his_ethnredassess wht_ethnredassess ///
					schwrtassess diswrtassess blk_ethnwrtassess his_ethnwrtassess wht_ethnwrtassess ///
					schsciassess dissciassess blk_ethnsciassess his_ethnsciassess wht_ethnsciassess ///
					sdaaassess
	
	*now make a total assessments variable
	egen assessments=rowtotal(`grpassess') if year>=2004 & year<=2008

*Now count the number of passrates that are below the statutory threshold and don't make required improvement threshold
	*thresholds will vary across years and subjects
	
	*2004
		*math
		foreach i in `accmth' {
			gen `i'zero=0 if year==2004
			replace `i'zero=1 if `i'rate<35 & arimp_`i'!=1 & `i'rate!=. & year==2004
		}
		*reading
		foreach i in `accred' {
			gen `i'zero=0 if year==2004
			replace `i'zero=1 if `i'rate<50 & arimp_`i'!=1 & `i'rate!=. & year==2004
		}
		*writing
		foreach i in `accwrt' {
			gen `i'zero=0 if year==2004 
			replace `i'zero=1 if `i'rate<50 & arimp_`i'!=1 & `i'rate!=. & year==2004
		}
		*science
		foreach i in `accsci' {
			gen `i'zero=0 if year==2004 
			replace `i'zero=1 if `i'rate<25 & arimp_`i'!=1 & `i'rate!=. & year==2004
		}
		*sdaa
			gen sdaazero=0 if year==2004
			replace sdaazero=1 if sdaarate<50 & arimp_sdaa!=1 & sdaarate!=. & year==2004
	*2005
		*math
		foreach i in `accmth' {
			replace `i'zero=0 if year==2005 
			replace `i'zero=1 if `i'rate<35 & arimp_`i'!=1 & `i'rate!=. & year==2005
		}
		*reading
		foreach i in `accred' {
			replace `i'zero=0 if year==2005
			replace `i'zero=1 if `i'rate<50 & arimp_`i'!=1 & `i'rate!=. & year==2005
		}
		*writing
		foreach i in `accwrt' {
			replace `i'zero=0 if year==2005 
			replace `i'zero=1 if `i'rate<50 & arimp_`i'!=1 & `i'rate!=. & year==2005
		}
		*science
		foreach i in `accsci' {
			replace `i'zero=0 if year==2005 
			replace `i'zero=1 if `i'rate<25 & arimp_`i'!=1 & `i'rate!=. & year==2005
		}
		*sdaa
			replace sdaazero=0 if year==2005
			replace sdaazero=1 if sdaarate<50 & arimp_sdaa!=1 & sdaarate!=. & year==2005	
	*2006
		*math
		foreach i in `accmth' {
			replace `i'zero=0 if year==2006 
			replace `i'zero=1 if `i'rate<40 & arimp_`i'!=1 & `i'rate!=. & year==2006
		}
		*reading
		foreach i in `accred' {
			replace `i'zero=0 if year==2006 
			replace `i'zero=1 if `i'rate<60 & arimp_`i'!=1 & `i'rate!=. & year==2006
		}
		*writing
		foreach i in `accwrt' {
			replace `i'zero=0 if year==2006
			replace `i'zero=1 if `i'rate<60 & arimp_`i'!=1 & `i'rate!=. & year==2006
		}
		*science
		foreach i in `accsci' {
			replace `i'zero=0 if year==2006 
			replace `i'zero=1 if `i'rate<35 & arimp_`i'!=1 & `i'rate!=. & year==2006
		}
		*sdaa
			replace sdaazero=0 if year==2006
			replace sdaazero=1 if sdaarate<50 & arimp_sdaa!=1 & sdaarate!=. & year==2006		
	*2007
		*math
		foreach i in `accmth' {
			replace `i'zero=0 if year==2007 
			replace `i'zero=1 if `i'rate<45 & arimp_`i'!=1 & `i'rate!=. & year==2007
		}
		*reading
		foreach i in `accred' {
			replace `i'zero=0 if year==2007 
			replace `i'zero=1 if `i'rate<65 & arimp_`i'!=1 & `i'rate!=. & year==2007
		}
		*writing
		foreach i in `accwrt' {
			replace `i'zero=0 if year==2007 
			replace `i'zero=1 if `i'rate<65 & arimp_`i'!=1 & `i'rate!=. & year==2007
		}
		*science
		foreach i in `accsci' {
			replace `i'zero=0 if year==2007 
			replace `i'zero=1 if `i'rate<40 & arimp_`i'!=1 & `i'rate!=. & year==2007
		}
		*sdaa
			replace sdaazero=0 if year==2007
			replace sdaazero=1 if sdaarate<50 & arimp_sdaa!=1 & sdaarate!=. & year==2007
	*2008
	*unacceptable -> acceptable
		*math
		foreach i in `accmth' {
			replace `i'zero=0 if year==2008
			replace `i'zero=1 if `i'rate<50 & arimp_`i'!=1 & `i'rate!=. & year==2008
		}
		*reading
		foreach i in `accred' {
			replace `i'zero=0 if year==2008
			replace `i'zero=1 if `i'rate<70 & arimp_`i'!=1 & `i'rate!=. & year==2008
		}
		*writing
		foreach i in `accwrt' {
			replace `i'zero=0 if year==2008 
			replace `i'zero=1 if `i'rate<65 & arimp_`i'!=1 & `i'rate!=. & year==2008
		}
		*science
		foreach i in `accsci' {
			replace `i'zero=0 if year==2008 
			replace `i'zero=1 if `i'rate<45 & arimp_`i'!=1 & `i'rate!=. & year==2008
		}
	*acceptable -> recognized 
		*all subjects
		foreach i in `studgrps' {
			gen `i'one=0 if year==2008
			replace `i'one=1 if `i'rate<75 & rrimp_`i'!=1 & `i'rate!=. & year==2008
		}
	*recognized -> exemplary
		*all subjects
		foreach i in `studgrps' {
			gen `i'two=0 if year==2008
			replace `i'two=1 if `i'rate<90 & `i'rate!=. & year==2008
		}
		
	*calculate total failing assessments
	local grpzero	 	schmthzero dismthzero blk_ethnmthzero his_ethnmthzero wht_ethnmthzero ///
						schredzero disredzero blk_ethnredzero his_ethnredzero wht_ethnredzero ///
						schwrtzero diswrtzero blk_ethnwrtzero his_ethnwrtzero wht_ethnwrtzero ///
						schscizero disscizero blk_ethnscizero his_ethnscizero wht_ethnscizero sdaazero
	
	local grpone	 	schmthone dismthone blk_ethnmthone his_ethnmthone wht_ethnmthone ///
						schredone disredone blk_ethnredone his_ethnredone wht_ethnredone ///
						schwrtone diswrtone blk_ethnwrtone his_ethnwrtone wht_ethnwrtone ///
						schscione disscione blk_ethnscione his_ethnscione wht_ethnscione 
						
	local grptwo	 	schmthtwo dismthtwo blk_ethnmthtwo his_ethnmthtwo wht_ethnmthtwo ///
						schredtwo disredtwo blk_ethnredtwo his_ethnredtwo wht_ethnredtwo ///
						schwrttwo diswrttwo blk_ethnwrttwo his_ethnwrttwo wht_ethnwrttwo ///
						schscitwo disscitwo blk_ethnscitwo his_ethnscitwo wht_ethnscitwo 
						
	egen nzero=rowtotal(`grpzero') if year>=2004 & year<=2008
	egen none =rowtotal(`grpone')  if year>=2004 & year<=2008
	egen ntwo =rowtotal(`grptwo')  if year>=2004 & year<=2008

*from 2004-2007 the number of allowed exceptions is the same
/*
Exemptions for campuses rated Unacceptable in 2004-2007
01-05 Assessments -> 0 exceptions
06-10 Assessments -> 1 exceptions 
11-15 Assessments -> 2 exceptions
16+   Assessments -> 3 exceptions 


Exemptions for campuses rated Unacceptable in 2008
Also allowed for campuses rated Acceptable
01-04 Assessments -> 0 exceptions
05-08 Assessments -> 1 exceptions 
09-11 Assessments -> 2 exceptions
12-15 Assessments -> 3 exceptions 
16+   Assessments -> 4 exceptions

Exemptions for campuses rated Exemplary in 2008
01-09 Assessments -> 0 exceptions
10+   Assessments -> 1 exceptions
*/

*track number of allowed exceptions
	gen nexceptacc=0
	gen nexceptrec=0
	gen nexceptexe=0
	*start with 2008
		replace nexceptacc=1 if assessments>=5  & assessments<=8  & assessments!=. & year==2008
		replace nexceptacc=2 if assessments>=9  & assessments<=11 & assessments!=. & year==2008
		replace nexceptacc=3 if assessments>=12 & assessments<=15 & assessments!=. & year==2008
		replace nexceptacc=4 if assessments>=16 & assessments!=. & year==2008
		replace nexceptrec=nexceptacc if year==2008
		replace nexceptexe=1 if assessments>=10 & assessments!=. & year==2008
	*2007
		replace nexceptacc=1 if assessments>=6  & assessments<=10 & assessments!=. & year==2007
		replace nexceptacc=2 if assessments>=11 & assessments<=15 & assessments!=. & year==2007
		replace nexceptacc=3 if assessments>=16 & assessments!=. & year==2007
	*2006
		replace nexceptacc=1 if assessments>=6  & assessments<=10 & assessments!=. & year==2006
		replace nexceptacc=2 if assessments>=11 & assessments<=15 & assessments!=. & year==2006
		replace nexceptacc=3 if assessments>=16 & assessments!=. & year==2006
	*2005
		replace nexceptacc=1 if assessments>=6  & assessments<=10 & assessments!=. & year==2005
		replace nexceptacc=2 if assessments>=11 & assessments<=15 & assessments!=. & year==2005
		replace nexceptacc=3 if assessments>=16 & assessments!=. & year==2005
	*2004
		replace nexceptacc=1 if assessments>=6  & assessments<=10 & assessments!=. & year==2004
		replace nexceptacc=2 if assessments>=11 & assessments<=15 & assessments!=. & year==2004
		replace nexceptacc=3 if assessments>=16 & assessments!=. & year==2004
		
*"predict" campus rating in 2001 & 2002
	foreach i in `studgrps' {
	gen r`i'=.
	}

	foreach i in `accmth' `accred' `accwrt' {
	replace r`i'=0 if (`i'rate< `i'accsta & `i'rate!=.) & year<=2002
	replace r`i'=1 if (`i'rate>=`i'accsta & `i'rate!=.) & year<=2002
	replace r`i'=2 if (`i'rate>=`i'recsta & `i'rate!=.) & year<=2002
	replace r`i'=3 if (`i'rate>=`i'exesta & `i'rate!=.) & year<=2002
	}	
	
*need to figure out campus rating before exceptions were applied
	*all subjects
	foreach i in `studgrps' {
	replace r`i'=0 if (`i'rate< `i'accsta & `i'rate!=.) & year>=2004
	replace r`i'=1 if ((`i'rate>=`i'accsta & `i'rate!=.) | (`i'rate<`i'accsta & arimp_`i'==1 & `i'rate!=.)) & year>=2004
	replace r`i'=2 if ((`i'rate>=`i'recsta & `i'rate!=.) | (`i'rate<`i'recsta & `i'rate>=(`i'recsta-5) & rrimp_`i'==1 & `i'rate!=.)) & year>=2004
	replace r`i'=3 if (`i'rate>=`i'exesta & `i'rate!=.) & year>=2004
	}
	gen rsdaa=. if (year>=2004 & year<=2007)
	replace rsdaa=0 if (sdaarate< sdaaaccsta & sdaarate!=.) & (year>=2004 & year<=2007)
	replace rsdaa=1 if ((sdaarate>=sdaaaccsta & sdaarate!=.) | (sdaarate<sdaaaccsta & arimp_sdaa==1 & sdaarate!=.)) & (year>=2004 & year<=2007)
	replace rsdaa=2 if ((sdaarate>=sdaarecsta & sdaarate!=.) | (sdaarate<sdaarecsta & sdaarate>=(sdaarecsta-5) & rrimp_sdaa==1 & sdaarate!=.)) & (year>=2004 & year<=2007)
	replace rsdaa=3 if (sdaarate>=sdaaexesta & sdaarate!=.) & (year>=2004 & year<=2007)

	local rgrps 	rschmth rdismth rblk_ethnmth rhis_ethnmth rwht_ethnmth ///
					rschred rdisred rblk_ethnred rhis_ethnred rwht_ethnred ///
					rschwrt rdiswrt rblk_ethnwrt rhis_ethnwrt rwht_ethnwrt ///
					rschsci rdissci rblk_ethnsci rhis_ethnsci rwht_ethnsci	
	
	gen byte rating=.
	foreach x in `rgrps' rsdaa {
		replace rating=`x' if rating==. | (`x'<rating & `x'!=.) 
	}	

*Now we have everything to assign exceptions (performance floors vary by year)

local accmth	schmth dismth blk_ethnmth his_ethnmth wht_ethnmth
local accred	schred disred blk_ethnred his_ethnred wht_ethnred
local accwrt	schwrt diswrt blk_ethnwrt his_ethnwrt wht_ethnwrt
local accsci	schsci dissci blk_ethnsci his_ethnsci wht_ethnsci

	*2004
		*math
		foreach i in `accmth' {
			gen `i'exmacc=1 if `i'rate<35 & `i'rate>=30 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2004 & rating==0
		}
		*reading
		foreach i in `accred' {
			gen `i'exmacc=1 if `i'rate<50 & `i'rate>=45 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2004 & rating==0
		}
		*writing
		foreach i in `accwrt' {
			gen `i'exmacc=1 if `i'rate<50 & `i'rate>=45 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2004 & rating==0
		}
		*science
		foreach i in `accsci' {
			gen `i'exmacc=1 if `i'rate<25 & `i'rate>=20 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2004 & rating==0
		}
		*sdaa
			gen sdaaexmacc=1 if sdaarate<50 & sdaarate>=45 & arimp_sdaa!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2004 & rating==0
	*2005
		*math
		foreach i in `accmth' {
			replace `i'exmacc=1 if `i'rate<35 & `i'rate>=30 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2005 & rating==0
		}
		*reading
		foreach i in `accred' {
			replace `i'exmacc=1 if `i'rate<50 & `i'rate>=45 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2005 & rating==0
		}
		*writing
		foreach i in `accwrt' {
			replace `i'exmacc=1 if `i'rate<50 & `i'rate>=45 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2005 & rating==0
		}
		*science
		foreach i in `accsci' {
			replace `i'exmacc=1 if `i'rate<25 & `i'rate>=20 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2005 & rating==0
		}
		*sdaa
			replace sdaaexmacc=1 if sdaarate<50 & sdaarate>=45 & arimp_sdaa!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2005 & rating==0
	*2006
		*math
		foreach i in `accmth' {
			replace `i'exmacc=1 if `i'rate<40 & `i'rate>=35 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2006 & rating==0
		}
		*reading
		foreach i in `accred' {
			replace `i'exmacc=1 if `i'rate<60 & `i'rate>=55 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2006 & rating==0
		}
		*writing
		foreach i in `accwrt' {
			replace `i'exmacc=1 if `i'rate<60 & `i'rate>=55 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2006 & rating==0
		}
		*science
		foreach i in `accsci' {
			replace `i'exmacc=1 if `i'rate<35 & `i'rate>=30 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2006 & rating==0
		}
		*sdaa
			replace sdaaexmacc=1 if sdaarate<50 & sdaarate>=45 & arimp_sdaa!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2006 & rating==0
	*2007
		*math
		foreach i in `accmth' {
			replace `i'exmacc=1 if `i'rate<45 & `i'rate>=40 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2007 & rating==0
		}
		*reading
		foreach i in `accred' {
			replace `i'exmacc=1 if `i'rate<65 & `i'rate>=60 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2007 & rating==0
		}
		*writing
		foreach i in `accwrt' {
			replace `i'exmacc=1 if `i'rate<65 & `i'rate>=60 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2007 & rating==0
		}
		*science
		foreach i in `accsci' {
			replace `i'exmacc=1 if `i'rate<40 & `i'rate>=35 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2007 & rating==0
		}
		*sdaa
			replace sdaaexmacc=1 if sdaarate<50 & sdaarate>=45 & arimp_sdaa!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2007 & rating==0
	*2008
	*unacceptable -> acceptable
		*math
		foreach i in `accmth' {
			replace `i'exmacc=1 if `i'rate<50 & `i'rate>=40 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2008 & rating==0
		}
		*reading
		foreach i in `accred' {
			replace `i'exmacc=1 if `i'rate<70 & `i'rate>=65 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2008 & rating==0
		}
		*writing
		foreach i in `accwrt' {
			replace `i'exmacc=1 if `i'rate<65 & `i'rate>=60 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2008 & rating==0
		}
		*science
		foreach i in `accsci' {
			replace `i'exmacc=1 if `i'rate<45 & `i'rate>=35 & arimp_`i'!=1 & nexceptacc>=nzero & nexceptacc>0 & year==2008 & rating==0
		}
	*acceptable -> recognized
		*all groups
		foreach i in `studgrps' {
			gen `i'exmrec=1 if `i'rate<75 & `i'rate>=70 & rrimp_`i'!=1 & nexceptrec>=none & nexceptrec>0 & year==2008 & rating==1
		}
	*recognized -> exemplary
		*all groups
		foreach i in `studgrps' {
			gen `i'exmexe=1 if `i'rate<90 & `i'rate>=85 & nexceptexe>=ntwo & nexceptexe>0 & year==2008 & rating==2
		}
	
*NEED TO MAKE TOTAL OF exm`rat' VARIABLES. IF THAT TOTAL VARIABLE IS EQUAL TO nzero,none,ntwo AND ITS POSITIVE -> replace rating=rating+1

local acc_exm 	schmthexmacc dismthexmacc blk_ethnmthexmacc his_ethnmthexmacc wht_ethnmthexmacc ///
				schredexmacc disredexmacc blk_ethnredexmacc his_ethnredexmacc wht_ethnredexmacc ///
				schwrtexmacc diswrtexmacc blk_ethnwrtexmacc his_ethnwrtexmacc wht_ethnwrtexmacc ///
				schsciexmacc dissciexmacc blk_ethnsciexmacc his_ethnsciexmacc wht_ethnsciexmacc ///
				sdaaexmacc
				
local rec_exm 	schmthexmrec dismthexmrec blk_ethnmthexmrec his_ethnmthexmrec wht_ethnmthexmrec ///
				schredexmrec disredexmrec blk_ethnredexmrec his_ethnredexmrec wht_ethnredexmrec ///
				schwrtexmrec diswrtexmrec blk_ethnwrtexmrec his_ethnwrtexmrec wht_ethnwrtexmrec ///
				schsciexmrec dissciexmrec blk_ethnsciexmrec his_ethnsciexmrec wht_ethnsciexmrec
				
local exe_exm 	schmthexmexe dismthexmexe blk_ethnmthexmexe his_ethnmthexmexe wht_ethnmthexmexe ///
				schredexmexe disredexmexe blk_ethnredexmexe his_ethnredexmexe wht_ethnredexmexe ///
				schwrtexmexe diswrtexmexe blk_ethnwrtexmexe his_ethnwrtexmexe wht_ethnwrtexmexe ///
				schsciexmexe dissciexmexe blk_ethnsciexmexe his_ethnsciexmexe wht_ethnsciexmexe

*create lagged exception variables and remove exceptions if they were granted in the previous year			
	xtset campus year
	foreach i in `acc_exm' {
		gen `i'_1=L1.`i'
		replace `i'=. if `i'_1==1
	}
	foreach i in `rec_exm' {
		gen `i'_1=L1.`i'
		replace `i'=. if `i'_1==1
	}
	foreach i in `exe_exm' {
		gen `i'_1=L1.`i'
		replace `i'=. if `i'_1==1
	}
	
				
*apply exceptions provision to unacceptable->acceptable rating for 2004-2008
	egen nexmacc=rowtotal(`acc_exm')
	gen rating2=rating
	replace rating2=rating+1 if nexmacc==nzero & nexmacc>0 & year>=2004

*apply exceptions provision to acceptable->recognized rating for 2008
	egen nexmrec=rowtotal(`rec_exm')
	replace rating2=rating+1 if nexmrec==none & nexmrec>0 & year==2008
	
*apply exceptions provision to recognized->exemplary rating for 2008
	egen nexmexe=rowtotal(`exe_exm')
	replace rating2=rating+1 if nexmexe==ntwo & nexmexe>0 & year==2008
	
*drop out all the campuses where no student takes any test and campuses that have rating==.
	drop if camd==. & card==. & cawd==. & cacd==. & csdd==.
	drop if rating==.
	
*replace missing continuous pass rates with discrete pass rates
	replace csdaarate=sdaarate if csdaarate==. & sdaarate!=.
	replace cschmthrate=schmthrate if cschmthrate==. & schmthrate!=.
	replace cschredrate=schredrate if cschredrate==. & schredrate!=.
	replace cschwrtrate=schwrtrate if cschwrtrate==. & schwrtrate!=.
	replace cschscirate=schscirate if cschscirate==. & schscirate!=.
	replace cdismthrate=dismthrate if cdismthrate==. & dismthrate!=.
	replace cdisredrate=disredrate if cdisredrate==. & disredrate!=.
	replace cdiswrtrate=diswrtrate if cdiswrtrate==. & diswrtrate!=.
	replace cdisscirate=disscirate if cdisscirate==. & disscirate!=.
	replace cblk_ethnmthrate=blk_ethnmthrate if cblk_ethnmthrate==. & blk_ethnmthrate!=.
	replace cblk_ethnredrate=blk_ethnredrate if cblk_ethnredrate==. & blk_ethnredrate!=.
	replace cblk_ethnwrtrate=blk_ethnwrtrate if cblk_ethnwrtrate==. & blk_ethnwrtrate!=.
	replace cblk_ethnscirate=blk_ethnscirate if cblk_ethnscirate==. & blk_ethnscirate!=.
	replace chis_ethnmthrate=his_ethnmthrate if chis_ethnmthrate==. & his_ethnmthrate!=.
	replace chis_ethnredrate=his_ethnredrate if chis_ethnredrate==. & his_ethnredrate!=.
	replace chis_ethnwrtrate=his_ethnwrtrate if chis_ethnwrtrate==. & his_ethnwrtrate!=.
	replace chis_ethnscirate=his_ethnscirate if chis_ethnscirate==. & his_ethnscirate!=.	
	replace cwht_ethnmthrate=wht_ethnmthrate if cwht_ethnmthrate==. & wht_ethnmthrate!=.
	replace cwht_ethnredrate=wht_ethnredrate if cwht_ethnredrate==. & wht_ethnredrate!=.
	replace cwht_ethnwrtrate=wht_ethnwrtrate if cwht_ethnwrtrate==. & wht_ethnwrtrate!=.
	replace cwht_ethnscirate=wht_ethnscirate if cwht_ethnscirate==. & wht_ethnscirate!=.	
	

saveold ${working_dir}pub_accountability_samp_msr_ri_ex, replace

}



*****************Reshape file for marginal group determination******************

if `shapeitup'==1 {

*load data
	use ${working_dir}pub_accountability_samp_msr_ri_ex, clear

*just keep the necessary variables 
	keep campus year c_rating2 rating2 *accsta *recsta *exesta *rate *rate_1 assessments *exmacc *exmrec *exmexe *exmacc_1 *exmrec_1 *exmexe_1 cflchart camptype

*rename variables so group is at the end of the variable name
	rename schmth* *schmth
	rename dismth* *dismth
	rename blk_ethnmth* *blk_ethnmth
	rename his_ethnmth* *his_ethnmth
	rename wht_ethnmth* *wht_ethnmth
	rename schred* *schred
	rename disred* *disred
	rename blk_ethnred* *blk_ethnred
	rename his_ethnred* *his_ethnred
	rename wht_ethnred* *wht_ethnred
	rename schwrt* *schwrt
	rename diswrt* *diswrt
	rename blk_ethnwrt* *blk_ethnwrt
	rename his_ethnwrt* *his_ethnwrt
	rename wht_ethnwrt* *wht_ethnwrt
	rename schsci* *schsci
	rename dissci* *dissci
	rename blk_ethnsci* *blk_ethnsci
	rename his_ethnsci* *his_ethnsci
	rename wht_ethnsci* *wht_ethnsci
	rename sdaa* *sdaa
	
	rename cschmth* c*schmth
	rename cdismth* c*dismth
	rename cblk_ethnmth* c*blk_ethnmth
	rename chis_ethnmth* c*his_ethnmth
	rename cwht_ethnmth* c*wht_ethnmth
	rename cschred* c*schred
	rename cdisred* c*disred
	rename cblk_ethnred* c*blk_ethnred
	rename chis_ethnred* c*his_ethnred
	rename cwht_ethnred* c*wht_ethnred
	rename cschwrt* c*schwrt
	rename cdiswrt* c*diswrt
	rename cblk_ethnwrt* c*blk_ethnwrt
	rename chis_ethnwrt* c*his_ethnwrt
	rename cwht_ethnwrt* c*wht_ethnwrt
	rename cschsci* c*schsci
	rename cdissci* c*dissci
	rename cblk_ethnsci* c*blk_ethnsci
	rename chis_ethnsci* c*his_ethnsci
	rename cwht_ethnsci* c*wht_ethnsci
	rename csdaa* c*sdaa	
	
*now make a key for groupXtest combinations for the reshape and loop
	/*
	1	schmth
	2	dismth
	3	blk_ethnmth
	4	his_ethnmth
	5	wht_ethnmth
	6	schred
	7	disred
	8	blk_ethnred
	9	his_ethnred
	10	wht_ethnred
	11	schwrt
	12	diswrt
	13	blk_ethnwrt
	14	his_ethnwrt
	15	wht_ethnwrt
	16	schsci
	17	dissci
	18	blk_ethnsci
	19	his_ethnsci
	20	wht_ethnsci
	21  sdaa
	*/
	rename *schmth *1
	rename *dismth *2
	rename *blk_ethnmth *3
	rename *his_ethnmth *4
	rename *wht_ethnmth *5
	rename *schred *6
	rename *disred *7
	rename *blk_ethnred *8
	rename *his_ethnred *9
	rename *wht_ethnred *10
	rename *schwrt *11
	rename *diswrt *12
	rename *blk_ethnwrt *13
	rename *his_ethnwrt *14
	rename *wht_ethnwrt *15
	rename *schsci *16
	rename *dissci *17
	rename *blk_ethnsci *18
	rename *his_ethnsci *19
	rename *wht_ethnsci *20
	rename *sdaa *21
	
	sum rate* crate*

*make id for reshape long will be a campusXyear group variable 
	egen camp_year=group(campus year)

	reshape long rate rate_1 crate crate_1 accsta recsta exesta caccsta crecsta cexesta exmacc exmrec exmexe exmacc_1 exmrec_1 exmexe_1, i(camp_year) j(sub_group)

	
*saveold data set that we can put through the marginal group machine.	
saveold ${working_dir}shaped_passrates, replace

}


if `JHR_rates'==1 {
*~*~*~*~*~*~*~*~*~*~~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~~*~*~**~~*~*~*~*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~**~*~*~*~*~*
*~*~*~*~*~*~*~*~*~*~~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~~*~*~**~~*~*~*~*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~**~*~*~*~*~*
*~*~*~*~*~*~*~*~*~*~~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~~*~*~**~~*~*~*~*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~**~*~*~*~*~*
*~*~*~*~*~*~*~*~*~*~~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~~*~*~**~~*~*~*~*~*~*~*~*~*~*~*~*~**~*~*~*~*~*~*~*~*~*~*~*~*~*~*~*~**~*~*~*~*~*
*****The following code was added in Jan 2020 for the JHR R&R*****

*I need to save a data set that has school achievment (pass rates) for all the schools in 2003. 
*To do this I need to get the 2004 data and keep the crateschmth_1 and crateschred_1 variables 
*Then I can recode the year to 2004 and save the variables so they are consistent with the other variables I use in
*principal_marginal_data_rnd2.do 
*This is so we can do some RD analysis on student achievement in years t+2 and t+4 

*load data
	use ${working_dir}pub_accountability_samp_msr_ri_ex, clear

*grab just the 2004 data
	keep if year==2004
	
*just keep the necessary variables 
	keep campus year cschmthrate_1 cschredrate_1 

*I'm going to make a panel of all the pass rate data for math and reading, but there is no data for 2003
*So, I'm going to save this year separately and then append it back into the panel that includes all the other years. 
	replace year=2003 
	
*make rename variables and make average passrate variable too
	rename cschmthrate_1 passmath
	rename cschredrate_1 passread
	egen passrate=rowmean(passmath passread) 
	
saveold ${working_dir}passratepanel03, replace

*Now load the data again and get the rest of the panel to 2008
	use ${working_dir}pub_accountability_samp_msr_ri_ex, clear
	
*just keep the necessary variables 
	keep campus year cschmthrate cschredrate 
	
*make rename variables and make average passrate variable too
	rename cschmthrate passmath
	rename cschredrate passread
	egen passrate=rowmean(passmath passread) 
	
saveold ${working_dir}passratepanel0108, replace

*now I can make the panel up to 2008 but I need to see future acheivment at the end of the panel too.
*I'm going to use the AEIS data from 2009 to 2011 for this. 
	

foreach i in 09 10 11 {
	*load data
		use ${erc_data}/non_erc/public/AEIS/campus/aeiscamp20`i', clear	
	*generate year variable
		gen long year=20`i'
	*just keep math and reading passrates
		keep campus year ca311tm`i'r ca311tr`i'r
	*rename varaibles and create average passrate
		rename ca311tm`i'r passmath 
		rename ca311tr`i'r passread 
		*get rid of nonsensical values 
			replace passmath=. if passmath<0
			replace passread=. if passread<0
			
		egen passrate=rowmean(passmath passread) 
	*save intermediate data set 
		saveold ${working_dir}passratepanel`i', replace

}

*Now I can append all the passratepanel data sets together
	use ${working_dir}passratepanel0108, clear
	append using ${working_dir}passratepanel03
	append using ${working_dir}passratepanel09
	append using ${working_dir}passratepanel10
	append using ${working_dir}passratepanel11

	xtset campus year
	
	tab year 
	
*Now I can generate passrate_p2 passrate_p3 and passrate_p4 for every campus in the panel 
	*math rates
	gen passmath_p2=F2.passmath
	gen passmath_p3=F3.passmath
	gen passmath_p4=F4.passmath
	*reading rates
	gen passread_p2=F2.passread
	gen passread_p3=F3.passread
	gen passread_p4=F4.passread
	*average rates
	gen passrate_p2=F2.passrate
	gen passrate_p3=F3.passrate
	gen passrate_p4=F4.passrate
	
*Now I only need to keep the forward looking passrate variables. 
	keep campus year *_p2 *_p3 *_p4 
*Drop years beyond 2008
	keep if year<=2008
	tab year 
	
saveold ${working_dir}passratepanel, replace

}
