capture log close
clear all

**************************************************************************************
*Name: pub_enrollment.do
*Description: creates a data set that contains school enrollment count by campus and year
*Author: Gregory Phelan
**************************************************************************************

set more off
clear

global working_dir	${Projectfolder}/account_rating/
global stud_path	${project_data}/tea/peims/student/
global taks_path	${project_data}/tea/assess/taks/
global camp_path	${project_data}/tea/peims/organization/campus/

forvalues i=1994(1)2008 {
	use ${stud_path}enroll/enroll`i', clear
	gen year=`i'
	drop if pidrep==.
	drop if invpid==1 
	duplicates drop pidrep campus, force
	bys campus: gen enrlcount=_N
	bys campus: keep if _n==1
	saveold ${working_dir}enrollcamp`i', replace	
}

use ${working_dir}enrollcamp1994, clear
forvalues i=1995(1)2008 {
	append using ${working_dir}enrollcamp`i'
}

duplicates report campus year

saveold ${working_dir}enrollcamp, replace


forvalues i=1994(1)2011 {
	use ${stud_path}enroll/enroll`i', clear
	gen year=`i'
	drop if pidrep==.
	drop if invpid==1 
	duplicates drop pidrep campus, force
	bys campus: gen enrlcount=_N
	*make campus demographic shares
	gen econdis=(economic!=0)
	bys campus: egen share_disadv=mean(econdis)
	gen asian=(ethnic==2)
	bys campus: egen share_asian=mean(asian)
	gen black=(ethnic==3)
	bys campus: egen share_black=mean(black)
	gen hisp=(ethnic==4)
	bys campus: egen share_hisp=mean(hisp)
	gen white=(ethnic==5)
	bys campus: egen share_white=mean(white)
	gen other=(ethnic!=3 & ethnic!=4 & ethnic!=5)
	bys campus: egen share_other=mean(other)
	bys campus: egen share_speced=mean(speced)
	bys campus: egen share_gifted=mean(gifted)
	bys campus: egen share_lep=mean(lep)
	bys campus: egen share_male=mean(sex)
	cap gen titleone=(title1!=0 & title1!=8)
	cap bys campus: egen share_title1=mean(titleone)
	
	bys campus: keep if _n==1
	saveold ${working_dir}campdemog`i', replace	
}

use ${working_dir}campdemog1994, clear
forvalues i=1995(1)2011 {
	append using ${working_dir}campdemog`i'
}

duplicates report campus year

keep campus year enrlcount share_*

saveold ${working_dir}campdemogs, replace


forvalues i=1994(1)2011 {
	use ${stud_path}enroll/enroll`i', clear
	gen year=`i'
	drop if pidrep==.
	drop if invpid==1 
	duplicates drop pidrep campus, force
	bys district: gen denrlcount=_N
	
	*make campus demographic shares
	gen econdis=(economic!=0)
	bys district: egen dshare_disadv=mean(econdis)
	gen asian=(ethnic==2)
	bys district: egen dshare_asian=mean(asian)
	gen black=(ethnic==3)
	bys district: egen dshare_black=mean(black)
	gen hisp=(ethnic==4)
	bys district: egen dshare_hisp=mean(hisp)
	gen white=(ethnic==5)
	bys district: egen dshare_white=mean(white)
	gen other=(ethnic!=3 & ethnic!=4 & ethnic!=5)
	bys district: egen dshare_other=mean(other)
	bys district: egen dshare_speced=mean(speced)
	bys district: egen dshare_gifted=mean(gifted)
	bys district: egen dshare_lep=mean(lep)
	
	bys district: keep if _n==1
	saveold ${working_dir}distdemog`i', replace	
}

use ${working_dir}distdemog1994, clear
forvalues i=1995(1)2011 {
	append using ${working_dir}distdemog`i'
}

duplicates report campus year

keep district year denrlcount dshare_*

saveold ${working_dir}distdemogs, replace


forvalues i=1994(1)2008 {
	use ${stud_path}enroll/enroll`i', clear
	gen year=`i'
	drop if pidrep==.
	drop if invpid==1 
	duplicates drop pidrep campus, force
	bys campus: gen enrlcount=_N
	bys campus: keep if _n==1
	
	*count the number of campuses in each district
	bys district: gen ncamps=_N
	
	keep campus year district ncamps
	
	saveold ${working_dir}ncamps`i', replace	
}

use ${working_dir}campdemog1994, clear
forvalues i=1995(1)2008 {
	append using ${working_dir}ncamps`i'
}
duplicates report campus year

saveold ${working_dir}dist_ncamps, replace
