capture log close
clear all

**************************************************************************************
*Name: pub_marginalgroups.do
*Description: Determines marginal groups and relevant group threshold for each campusXyear
*Author: Gregory Phelan
**************************************************************************************

set more off
clear

global account_dir	${Projectfolder}/account_rating/
global working_dir	${Projectfolder}/account_rating/
global stud_path	${project_data}/tea/peims/student/
global taks_path	${project_data}/tea/assess/taks/
global camp_path	${project_data}/tea/peims/organization/campus/

*load data
	use ${account_dir}shaped_passrates, clear	
	
	*create variable for effective threshold (statutory vs. req. improvment)
	gen acceff=accsta
	replace acceff=((accsta+rate_1)/2) if rate_1<accsta & year>=2004 & year<=2008 /*required improvement for acceptable*/
	gen receff=recsta
	replace receff=max((recsta-5),((recsta+rate_1)/2)) if rate_1<recsta & year>=2004 & year<=2008 /*required improvement for recognized*/
	gen exeeff=exesta
	
	gen cacceff=caccsta
	replace cacceff=((caccsta+crate_1)/2) if crate_1<caccsta & year>=2004 & year<=2008 /*required improvement for acceptable*/
	gen creceff=crecsta
	replace creceff=max((crecsta-5),((crecsta+crate_1)/2)) if crate_1<crecsta & year>=2004 & year<=2008 /*required improvement for recognized*/
	gen cexeeff=cexesta

	*round to integers
	replace acceff=round(acceff,1) if year>=2004
	replace receff=round(receff,1) if year>=2004
	replace exeeff=round(exeeff,1) if year>=2004
	
	*track number of allowed exceptions
	gen nexceptacc=0
	gen nexceptrec=0
	gen nexceptexe=0
	*start with 2008
		replace nexceptacc=1 if assessments>=5 & assessments<=8 & assessments!=. & year==2008
		replace nexceptacc=2 if assessments>=9 & assessments<=11 & assessments!=. & year==2008
		replace nexceptacc=3 if assessments>=12 & assessments<=15 & assessments!=. & year==2008
		replace nexceptacc=4 if assessments>=16 & assessments!=. & year==2008
		replace nexceptrec=nexceptacc if year==2008
		replace nexceptexe=1 if assessments>=10 & assessments!=. & year==2008
	*2007
		replace nexceptacc=1 if assessments>=6 & assessments<=10 & assessments!=. & year==2007
		replace nexceptacc=2 if assessments>=11 & assessments<=15 & assessments!=. & year==2007
		replace nexceptacc=3 if assessments>=16 & assessments!=. & year==2007
	*2006
		replace nexceptacc=1 if assessments>=6 & assessments<=10 & assessments!=. & year==2006
		replace nexceptacc=2 if assessments>=11 & assessments<=15 & assessments!=. & year==2006
		replace nexceptacc=3 if assessments>=16 & assessments!=. & year==2006
	*2005
		replace nexceptacc=1 if assessments>=6 & assessments<=10 & assessments!=. & year==2005
		replace nexceptacc=2 if assessments>=11 & assessments<=15 & assessments!=. & year==2005
		replace nexceptacc=3 if assessments>=16 & assessments!=. & year==2005
	*2004
		replace nexceptacc=1 if assessments>=6 & assessments<=10 & assessments!=. & year==2004
		replace nexceptacc=2 if assessments>=11 & assessments<=15 & assessments!=. & year==2004
		replace nexceptacc=3 if assessments>=16 & assessments!=. & year==2004
	
	
	* find threshold for exception to apply (if eligible);
	for any acc rec exe: gen exceptX=.

	*2008
	replace exceptacc=(accsta-10) if sub_group>=1 & sub_group<=5 & year==2008 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=6 & sub_group<=10 & year==2008 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=11 & sub_group<=15 & year==2008 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-10) if sub_group>=16 & sub_group<=20 & year==2008 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptrec=(recsta-5) if year==2008 & exmrec_1!=1 & rate!=. & nexceptrec!=0
	replace exceptexe=(exesta-5) if year==2008 & exmexe_1!=1 & rate!=. & nexceptexe!=0
	
	*2007
	replace exceptacc=(accsta-5) if sub_group>=1 & sub_group<=5 & year==2007 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=6 & sub_group<=10 & year==2007 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=11 & sub_group<=15 & year==2007 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=16 & sub_group<=20 & year==2007 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group==21 & year==2007 & exmacc_1!=1 & rate!=. & nexceptacc!=0

	*2006
	replace exceptacc=(accsta-5) if sub_group>=1 & sub_group<=5 & year==2006 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=6 & sub_group<=10 & year==2006 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=11 & sub_group<=15 & year==2006 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=16 & sub_group<=20 & year==2006 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group==21 & year==2006 & exmacc_1!=1 & rate!=. & nexceptacc!=0	

	*2005
	replace exceptacc=(accsta-5) if sub_group>=1 & sub_group<=5 & year==2005 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=6 & sub_group<=10 & year==2005 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=11 & sub_group<=15 & year==2005 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=16 & sub_group<=20 & year==2005 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group==21 & year==2005 & exmacc_1!=1 & rate!=. & nexceptacc!=0

	*2004
	replace exceptacc=(accsta-5) if sub_group>=1 & sub_group<=5 & year==2004 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=6 & sub_group<=10 & year==2004 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=11 & sub_group<=15 & year==2004 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group>=16 & sub_group<=20 & year==2004 & exmacc_1!=1 & rate!=. & nexceptacc!=0
	replace exceptacc=(accsta-5) if sub_group==21 & year==2004 & exmacc_1!=1 & rate!=. & nexceptacc!=0	
	
	
	** determine whether meets threshold
	* without exception
	gen meetsacc=(rate>=acceff & rate!=.) 
	gen meetsrec=(rate>=receff & rate!=.)
	gen meetsexe=(rate>=exeeff & rate!=.)

	* only with exception	
	gen meetsaccex=(meetsacc==0 & rate>=exceptacc & exceptacc!=. & rate!=.)
	gen meetsrecex=(meetsrec==0 & rate>=exceptrec & exceptrec!=. & rate!=.)
	gen meetsexeex=(meetsexe==0 & rate>=exceptexe & exceptexe!=. & rate!=.)

	
	egen numcateg=count(rate), by(camp_year)
	
	*make place holder for marginal groupXtest indicator and threshold of that groupXtest
	for any acc rec exe: gen margX=0 \ label var margX "marginal for X rating"
	*for any acc rec exe: gen threshX="" \ label var threshX "effective threshold for X rating"
	
	saveold ${working_dir}calcrating, replace
	
	*determine which sub-group gets an exception
	*acceptable
		gen eacc=0
		gen temp1=1 if acceff!=accsta & rate<acceff   /// eligible for req imp but didn't meet the RI threshold
		
		gen temp2=1 if acceff==accsta & rate!=. /// effective threshold is the statutory threshold
		
		gen temp3=1 if temp1==1 | temp2==1	
		gen temp4=rate-acceff if rate!=. /// difference between passrate and pre-exception threshold
		
		*lowest rated sub-groups without req imp or an exception in the previous year get exception
		by camp_year (temp4), sort: replace eacc=cond((sum(eacc)<nexceptacc & temp3==1 & exmacc_1!=1),1,0)
		*for some reason the last line does not stop replacing eacc with 1 after sum(eacc)>nexceptacc: the next line fixes it
		by camp_year (temp4), sort: replace eacc=0 if sum(eacc)>nexceptacc
		drop temp*
	*recognized	
		gen erec=0
		gen temp1=1 if receff!=recsta & rate<receff
		gen temp2=1 if receff==recsta & rate!=.
		gen temp3=1 if temp1==1 | temp2==1
		gen temp4=rate-receff if rate!=.
		*lowest rated sub-groups without req imp or an exception in the previous year get exception
		by camp_year (temp4), sort: replace erec=cond((sum(erec)<nexceptrec & temp3==1 & exmrec_1!=1),1,0)
		*for some reason the last line does not stop replacing erec with 1 after sum(erec)>nexceptrec: the next line fixes it
		by camp_year (temp4), sort: replace erec=0 if sum(erec)>nexceptrec
		drop temp*
	*exemplary	
		gen eexe=0
		gen temp1=1 if exeeff!=exesta & rate<exeeff
		gen temp2=1 if exeeff==exesta & rate!=.
		gen temp3=1 if temp1==1 | temp2==1
		gen temp4=rate-exeeff if rate!=.
		*lowest rated sub-groups without req imp or an exception in the previous year get exception
		by camp_year (temp4), sort: replace eexe=cond((sum(eexe)<nexceptexe & temp3==1 & exmexe_1!=1),1,0)
		*for some reason the last line does not stop replacing eexe with 1 after sum(eexe)>nexceptexe: the next line fixes it
		by camp_year (temp4), sort: replace eexe=0 if sum(eexe)>nexceptexe
		drop temp*
		

	*generate threshold variables 
	*acceptable
		gen acc_thresh=acceff
		replace acc_thresh=exceptacc if eacc==1
	*recognized
		gen rec_thresh=receff
		replace rec_thresh=exceptrec if erec==1
	*exemplary
		gen exe_thresh=exeeff
		replace exe_thresh=exceptexe if eexe==1
		
	*calculate prior year distance for every threshold
	*acceptable
		gen pr_dist_acc=rate_1-acc_thresh if rate_1!=.
		gen cr_dist_acc=rate-acc_thresh if rate!=.
	*recognized
		gen pr_dist_rec=rate_1-rec_thresh if rate_1!=.
		gen cr_dist_rec=rate-rec_thresh if rate!=.
	*exemplary
		gen pr_dist_exe=rate_1-exe_thresh if rate_1!=.
		gen cr_dist_exe=rate-exe_thresh if rate!=.

		
		
		
	****Marginal group selection****
	*acceptable
		bys campus year: egen tmp1=min(pr_dist_acc)
		gen tmp2=1 if tmp1==pr_dist_acc
		bys campus year: gen pr_marg_acc=cond((tmp2==1 & pr_dist_acc!=.), 1, .)
		bys campus year: egen tmp3=min(cr_dist_acc)
		gen tmp4=1 if tmp3==cr_dist_acc
		bys campus year: gen cr_marg_acc=cond((tmp4==1 & cr_dist_acc!=.), 1, .)
		drop tmp*

	*recognized
		bys campus year: egen tmp1=min(pr_dist_rec)
		gen tmp2=1 if tmp1==pr_dist_rec
		bys campus year: gen pr_marg_rec=cond((tmp2==1 & pr_dist_rec!=.), 1, .)
		bys campus year: egen tmp3=min(cr_dist_rec)
		gen tmp4=1 if tmp3==cr_dist_rec
		bys campus year: gen cr_marg_rec=cond((tmp4==1 & cr_dist_rec!=.), 1, .)
		drop tmp*
		
	*exemplary
		bys campus year: egen tmp1=min(pr_dist_exe)
		gen tmp2=1 if tmp1==pr_dist_exe
		bys campus year: gen pr_marg_exe=cond((tmp2==1 & pr_dist_exe!=.), 1, .)
		bys campus year: egen tmp3=min(cr_dist_exe)
		gen tmp4=1 if tmp3==cr_dist_exe
		bys campus year: gen cr_marg_exe=cond((tmp4==1 & cr_dist_exe!=.), 1, .)
		drop tmp*
	
		
	****calculate running variables****
	*acceptable
		*gen pr_acc_bind=rate-acc_thresh if pr_marg_acc==1
		gen acc_bind=crate-acc_thresh+.5 if cr_marg_acc==1
		replace acc_bind=crate-acc_thresh+.05 if cr_marg_acc==1 & year<=2002
	*recognized
		*gen pr_rec_bind=rate-rec_thresh if pr_marg_rec==1
		gen rec_bind=crate-rec_thresh+.5 if cr_marg_rec==1
		replace rec_bind=crate-rec_thresh+.05 if cr_marg_rec==1 & year<=2002
	*exemplary
		*gen pr_exe_bind=rate-exe_thresh if pr_marg_exe==1
		gen exe_bind=crate-exe_thresh+.5 if cr_marg_exe==1	
		replace exe_bind=crate-exe_thresh+.05 if cr_marg_exe==1 & year<=2002

	*get math, reading and marginal group pass rates	
	gen mathrate=crate if sub_group==1
	gen readrate=crate if sub_group==6	
	
	gen accbindrate=rate if cr_marg_acc==1
	gen recbindrate=rate if cr_marg_rec==1
	gen exebindrate=rate if cr_marg_exe==1
	
	bys campus year: egen passmath=max(mathrate)
	bys campus year: egen passread=max(readrate)
	bys campus year: egen passaccb=max(accbindrate)
	bys campus year: egen passrecb=max(recbindrate)
	bys campus year: egen passexeb=max(exebindrate)
	
	*pick up sub_group of binding category
	gen accbind_group=sub_group if cr_marg_acc==1
	gen recbind_group=sub_group if cr_marg_rec==1
	gen exebind_group=sub_group if cr_marg_exe==1
	bys campus year: egen acc_group=max(accbind_group)
	bys campus year: egen rec_group=max(recbind_group)
	bys campus year: egen exe_group=max(exebind_group)
	
	label variable acc_group "acceptable binding group"
	label variable rec_group "recognized binding group"
	label variable exe_group "exemplary binding group"

	*keep one observation for each campus and year
	bys campus year: egen acc_bind2=min(acc_bind)
	bys campus year: egen rec_bind2=min(rec_bind)
	bys campus year: egen exe_bind2=min(exe_bind)

	drop acc_bind rec_bind exe_bind
	
	rename (acc_bind2 rec_bind2 exe_bind2) (acc_bind rec_bind exe_bind)
	
	*figure out the lowest performaning group in each campus-year
	bys campus year: egen mincrate=min(crate)
	gen mctemp1=(mincrate==crate & crate!=.)
	gen lowgroup=sub_group if mctemp1==1
	bys campus year: egen lowest_group=max(lowgroup)
	order camp_year sub_group lowest_group lowgroup mctemp crate campus year
	
	*classify subgroups by subject
	gen subject=.
	replace subject=1 if sub_group>=1 & sub_group<=5
	replace subject=2 if sub_group>=6 & sub_group<=10
	replace subject=3 if sub_group>=11 & sub_group<=15
	replace subject=4 if sub_group>=16 & sub_group<=20
	replace subject=5 if sub_group==21
	gen acc_subject=.
	replace acc_subject=1 if sub_group>=1 & sub_group<=5
	replace acc_subject=2 if sub_group>=6 & sub_group<=10
	replace acc_subject=3 if sub_group>=11 & sub_group<=15
	replace acc_subject=4 if sub_group>=16 & sub_group<=20
	replace acc_subject=5 if sub_group==21
	gen rec_subject=.
	replace rec_subject=1 if sub_group>=1 & sub_group<=5
	replace rec_subject=2 if sub_group>=6 & sub_group<=10
	replace rec_subject=3 if sub_group>=11 & sub_group<=15
	replace rec_subject=4 if sub_group>=16 & sub_group<=20
	replace rec_subject=5 if sub_group==21
	gen exe_subject=.
	replace exe_subject=1 if sub_group>=1 & sub_group<=5
	replace exe_subject=2 if sub_group>=6 & sub_group<=10
	replace exe_subject=3 if sub_group>=11 & sub_group<=15
	replace exe_subject=4 if sub_group>=16 & sub_group<=20
	replace exe_subject=5 if sub_group==21
	label define subject 1 "math", modify
	label define subject 2 "reading", modify
	label define subject 3 "writing", modify
	label define subject 4 "science", modify
	label define subject 5 "sdaa", modify
	label values subject subject
	label values acc_subject subject
	label values rec_subject subject
	label values exe_subject subject
	
	*now figure out lowest performing group in each campus-year-subject
	bys campus year subject: egen mincrate2=min(crate)
	gen mctemp2=(mincrate2==crate & crate!=.)
	gen lowgroup2=sub_group if mctemp2==1
	bys campus year subject: egen lowest_subject=max(lowgroup2)
	order acc_group camp_year sub_group lowest_group lowgroup mctemp1 lowest_subject lowgroup2 mctemp2 crate campus year
	
	*now figure out if the binding group is the lowest performing group in the subject
	gen acc_low_sub=0
	replace acc_low_sub=1 if acc_group==lowest_subject & subject==acc_subject
	gen rec_low_sub=0
	replace rec_low_sub=1 if rec_group==lowest_subject & subject==rec_subject
	gen exe_low_sub=0
	replace exe_low_sub=1 if exe_group==lowest_subject & subject==exe_subject
	
	order camp_year acc_group acc_low_sub rec_group rec_low_sub exe_group exe_low_sub
	
	*indicator for whether the binding group is the lowest performing group of the binding subject
	bys campus year: egen accgrp_accsub=max(acc_low_sub)
	bys campus year: egen recgrp_recsub=max(rec_low_sub)
	bys campus year: egen exegrp_exesub=max(exe_low_sub)
	

	bys campus year: keep if _n==1
	
	*track what threshold was used
		*exemplary
			gen e_statu_thresh=(exe_thresh==exesta)
			gen e_except_thresh=(exe_thresh==exceptexe)
			gen e_reqimp_thresh=(exe_thresh!=exesta & exe_thresh!=exceptexe)
			gen     e_threshold=1 if e_statu_thresh==1
			replace e_threshold=2 if e_except_thresh==1
			replace e_threshold=3 if e_reqimp_thresh==1
		*recognized
			gen r_statu_thresh= (rec_thresh==recsta)
			gen r_except_thresh=(rec_thresh==exceptrec)
			gen r_reqimp_thresh=(rec_thresh!=recsta & rec_thresh!=exceptrec)
			gen     r_threshold=1 if r_statu_thresh==1
			replace r_threshold=2 if r_except_thresh==1
			replace r_threshold=3 if r_reqimp_thresh==1
		*recognized
			gen a_statu_thresh= (acc_thresh==accsta)
			gen a_except_thresh=(acc_thresh==exceptacc)
			gen a_reqimp_thresh=(acc_thresh!=accsta & acc_thresh!=exceptacc)
			gen     a_threshold=1 if a_statu_thresh==1
			replace a_threshold=2 if a_except_thresh==1
			replace a_threshold=3 if a_reqimp_thresh==1
			
		*label threshold indicator variables
			label define threshold 1 "statutory", modify
			label define threshold 2 "exceptions", modify
			label define threshold 3 "required improvement", modify
			
			label values e_threshold threshold
			label values r_threshold threshold
			label values a_threshold threshold
			
			
	
*keep relevant variables 
	keep campus year c_rating2 rating2 acc_bind rec_bind exe_bind passmath passread passaccb passrecb passexeb acc_group rec_group exe_group cflchart camptype e_threshold r_threshold a_threshold lowest_group lowest_subject accgrp_accsub recgrp_recsub exegrp_exesub
	
	*define labels for binding group variables 
	foreach i in acc rec exe lowest{
	label define `i'_group 1	"school math", modify
	label define `i'_group 2	"disadvantaged math", modify
	label define `i'_group 3	"black math", modify
	label define `i'_group 4	"hispanic math", modify
	label define `i'_group 5	"white math", modify
	label define `i'_group 6	"school reading", modify
	label define `i'_group 7	"disadvantaged reading", modify
	label define `i'_group 8	"black reading", modify
	label define `i'_group 9	"hispanic reading", modify
	label define `i'_group 10	"white reading", modify
	label define `i'_group 11	"school writing", modify
	label define `i'_group 12	"disadvantaged writing", modify
	label define `i'_group 13	"black writing", modify
	label define `i'_group 14	"hispanic writing", modify
	label define `i'_group 15	"white writing", modify
	label define `i'_group 16	"school science", modify
	label define `i'_group 17	"disadvantaged science", modify
	label define `i'_group 18	"black science", modify
	label define `i'_group 19	"hispanic science", modify
	label define `i'_group 20	"white science", modify
	label define `i'_group 21	"SDAA or SDAAII", modify	
	label values `i'_group `i'_group
	}
	
	label define lowest_subject 1	"school math", modify
	label define lowest_subject 2	"disadvantaged math", modify
	label define lowest_subject 3	"black math", modify
	label define lowest_subject 4	"hispanic math", modify
	label define lowest_subject 5	"white math", modify
	label define lowest_subject 6	"school reading", modify
	label define lowest_subject 7	"disadvantaged reading", modify
	label define lowest_subject 8	"black reading", modify
	label define lowest_subject 9	"hispanic reading", modify
	label define lowest_subject 10	"white reading", modify
	label define lowest_subject 11	"school writing", modify
	label define lowest_subject 12	"disadvantaged writing", modify
	label define lowest_subject 13	"black writing", modify
	label define lowest_subject 14	"hispanic writing", modify
	label define lowest_subject 15	"white writing", modify
	label define lowest_subject 16	"school science", modify
	label define lowest_subject 17	"disadvantaged science", modify
	label define lowest_subject 18	"black science", modify
	label define lowest_subject 19	"hispanic science", modify
	label define lowest_subject 20	"white science", modify
	label define lowest_subject 21	"SDAA or SDAAII", modify	
	label values lowest_subject lowest_subject
	
saveold ${working_dir}marginal_groups_all, replace	
