clear all
set more off
set maxvar 32767
set matsize 11000
capture log close _all

global working_dir	${Projectfolder}/work_files/
global account_dir	${Projectfolder}/account_rating/
global staff_dir	${project_data}/Projectfolder/tea/peims/staff/
global rdd_output	${working_dir}/rdd_output/
global LPM_success	${working_dir}/LPM_success/
*This script is the visual and iv analysis of the principals RDD




***************On/Off Switch for parts of the analysis On=1 Off=0***************

*Set Bandwidths
local bandwidths 0

*Polynomial Variables
local polyvars 0

*RD analysis at Acceptable Boundary
local acceptable_RDD 0

*RD analysis at Recognized Boundary
local recognized_RDD 0

*RD analysis at Exemplary Boundary
local exemplary_RDD 0

*RD analysis with covarates as additional controls
local covarregs 0

***************Locals for Outcomes***************

*outcomes variables
local outcomes success

*outcomes variables
local outcomes success

*principal covariates
local pcovars sex tenure experyrs asian black hispanic white nodegree bachelor master doctorate st_syfe

*campus level covariates
local ccovars share_disadv share_black share_hisp share_white share_asian share_speced share_gifted share_lep share_esl 


*****************Bandwidths and Polynomial Interactions*****************
if `bandwidths'==1{

*load data for elementary and middle school principals
use ${working_dir}consistent_sample_gp, clear

*restrict sample to years after >=2001
keep if year>=2001

*round binding scores
replace acc_bind=round(acc_bind, 0.01)
replace rec_bind=round(rec_bind, 0.01)
replace exe_bind=round(exe_bind, 0.01)

****** Make variables for pct change salary to use in RD reg loops ******
	gen sal=st_pgrowth_total
	gen sal_2=st_pgrowth_total2
	gen adjsal=st_pgrowth_adj_total
	gen adjsal_2=st_pgrowth_adj_total2
	
	gen l_total_2yr=log(total_2yr)
	gen l_adj_total_pay=log(adj_total_pay)
	gen l_adj_total_2yr=log(adj_total_2yr)
	
	*changes in log salary measures
	rename pct_grth_tot2 dl_total_2yr
	gen dl_adj_total_2yr=l_adj_total_2yr-l_adj_total_pay
	*make the difference in log salary consistent with other samples
		replace dl_total_2yr=. if pgrowth_adj_total2==.
		replace dl_adj_total_2yr=. if pgrowth_adj_total2==.
	
	*change in acheivement/working conditions
	gen d_predict_pass_2yr=l2_st_predict_pass-st_predict_pass
	replace d_predict_pass_2yr=. if dl_adj_total_2yr==.

*Use rdbwselect to determine optimal bandwidths
preserve
*naming convention: `runningvar'_`bandwidthtype'bw_`outcometype'
			* acc2_CCTbw_a1 -> acc_bind2=runningvar; CCTbw= Calonico, Cattaneo, & Titiunik; a1=success_a1
			* adding _2 to the end signifies second year outcomes
			
	*Acceptable boundary
		keep if acc_bind>=-10 & acc_bind<=10
	*we don't want to count ratings higher than acceptable as failures
		replace acceptable=1 if c_rating2>=101
		
		*select for first stage
		
			rdbwselect acceptable acc_bind, c(0) p(1) kernel(tri) bwselect(mserd) vce(cluster acc_bind)
			gen acc_bw_tri=e(h_mserd)
			
			rdbwselect acceptable acc_bind, c(0) p(1) kernel(uni) bwselect(mserd) vce(cluster acc_bind)
			gen acc_bw_uni=e(h_mserd)
			
	saveold ${working_dir}acclin_elem_mid_RDD_sample_bw_taks, replace 

restore, preserve
	*Recognized boundary
		keep if rec_bind>=-10 & rec_bind<=10
	*we don't want to count ratings higher than acceptable as failures
		replace recognized=1 if c_rating2>=102
		
		*select for first stage
		
			rdbwselect recognized rec_bind, c(0) p(1) kernel(tri) bwselect(mserd) vce(cluster rec_bind)
			gen rec_bw_tri=e(h_mserd)
			
			rdbwselect recognized rec_bind, c(0) p(1) kernel(uni) bwselect(mserd) vce(cluster rec_bind)
			gen rec_bw_uni=e(h_mserd)
			
	saveold ${working_dir}reclin_elem_mid_RDD_sample_bw_taks, replace 
				
restore	
	*Exemplary boundary
		keep if exe_bind>=-10 & exe_bind<=10
	*we don't want to count ratings higher than acceptable as failures
		replace exemplary=1 if c_rating2>=103
		
		*select for first stage
		
			rdbwselect exemplary exe_bind, c(0) p(1) kernel(tri) bwselect(mserd) vce(cluster exe_bind)
			gen exe_bw_tri=e(h_mserd)
			
			rdbwselect exemplary exe_bind, c(0) p(1) kernel(uni) bwselect(mserd) vce(cluster exe_bind)
			gen exe_bw_uni=e(h_mserd)
			
	saveold ${working_dir}exelin_elem_mid_RDD_sample_bw_taks, replace 			
			
*Mark samples using band width estimates
*Acceptable
use ${working_dir}acclin_elem_mid_RDD_sample_bw_taks, clear

foreach i in acc {
	foreach j in tri uni {
		gen `i'_`j'=1 if `i'_bind>=(0-`i'_bw_`j') & `i'_bind<=`i'_bw_`j'
	}
}

saveold ${working_dir}acclintri_elem_mid_RDD_sample_bw_taks, replace
*Recognized
use ${working_dir}reclin_elem_mid_RDD_sample_bw_taks, clear

foreach i in rec {
	foreach j in tri uni {
		gen `i'_`j'=1 if `i'_bind>=(0-`i'_bw_`j') & `i'_bind<=`i'_bw_`j'
	}
}

saveold ${working_dir}reclintri_elem_mid_RDD_sample_bw_taks, replace
*exemplary
use ${working_dir}exelin_elem_mid_RDD_sample_bw_taks, clear

foreach i in exe {
	foreach j in tri uni {
		gen `i'_`j'=1 if `i'_bind>=(0-`i'_bw_`j') & `i'_bind<=`i'_bw_`j'
	}
}

saveold ${working_dir}exelintri_elem_mid_RDD_sample_bw_taks, replace


}




if `polyvars'==1{
*Acceptable
use ${working_dir}acclintri_elem_mid_RDD_sample_bw_taks, clear
*create squared running variable and interactions 
drop *_above
drop *_below

gen	acc_above=0
replace acc_above=1 if acc_bind>=0

gen acc_bind_sq=acc_bind^2

gen acc_above_bind=acc_above*acc_bind

gen acc_above_bind_sq=acc_above*acc_bind_sq

saveold ${working_dir}acclintri_elem_mid_RDD_sample_bw_poly_taks, replace

*Recognized
use ${working_dir}reclintri_elem_mid_RDD_sample_bw_taks, clear
*create squared running variable and interactions 
drop *_above
drop *_below

gen	rec_above=0
replace rec_above=1 if rec_bind>=0

gen rec_bind_sq=rec_bind^2

gen rec_above_bind=rec_above*rec_bind

gen rec_above_bind_sq=rec_above*rec_bind_sq

saveold ${working_dir}reclintri_elem_mid_RDD_sample_bw_poly_taks, replace

*Exemplary
use ${working_dir}exelintri_elem_mid_RDD_sample_bw_taks, clear
*create squared running variable and interactions 
drop *_above
drop *_below

gen	exe_above=0
replace exe_above=1 if exe_bind>=0

gen exe_bind_sq=exe_bind^2

gen exe_above_bind=exe_above*exe_bind

gen exe_above_bind_sq=exe_above*exe_bind_sq

saveold ${working_dir}exelintri_elem_mid_RDD_sample_bw_poly_taks, replace
}



*****************Acceptable RDD*****************
if `acceptable_RDD'==1{

use ${working_dir}acclintri_elem_mid_RDD_sample_bw_poly_taks, clear

*save log file of RD results
log using ${working_dir}ACC_RDDlog.txt, replace text

*These are optimal bandwidths calculated for uniform and triangular kernel density estimation
	*acc_bw_uni=3.46
	*acc_bw_tri=3.82


preserve
*keep if NPs>1

********************************************school by year FE balance
eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust st_asyfe acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust st_asyfe acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust st_asyfe acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust st_asyfe acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust st_asyfe acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_sbyfe.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


********************************************princpal FE balance
eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust st_asyfe2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust st_asyfe2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust st_asyfe2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust st_asyfe2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust st_asyfe2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_pfe.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

restore
	
********************************************1st stages
eststo clear
*uniform kernel 1st stage
eststo bw10: rdrobust acceptable acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust acceptable acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust acceptable acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust acceptable acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust acceptable acc_bind, h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_1st.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust acceptable acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust acceptable acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust acceptable acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust acceptable acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust acceptable acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_1st.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel 1st stage low VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2<r(p50)
eststo bw10: rdrobust acceptable acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2<r(p50)
eststo bw75: rdrobust acceptable acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2<r(p50)
eststo bw05: rdrobust acceptable acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2<r(p50)
eststo bw25: rdrobust acceptable acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2<r(p50)
eststo bwIK: rdrobust acceptable acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}lintri_acc_1st_lowVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel 1st stage high VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2>=r(p50)
eststo bw10: rdrobust acceptable acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2>=r(p50)
eststo bw75: rdrobust acceptable acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2>=r(p50)
eststo bw05: rdrobust acceptable acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2>=r(p50)
eststo bw25: rdrobust acceptable acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2>=r(p50)
eststo bwIK: rdrobust acceptable acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}lintri_acc_1st_highVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel 1st stage low VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe<r(p50)
eststo bw10: rdrobust acceptable acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe<r(p50)
eststo bw75: rdrobust acceptable acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe<r(p50)
eststo bw05: rdrobust acceptable acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe<r(p50)
eststo bw25: rdrobust acceptable acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe<r(p50)
eststo bwIK: rdrobust acceptable acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}lintri_acc_1st_lowVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel 1st stage high VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe>=r(p50)
eststo bw10: rdrobust acceptable acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe>=r(p50)
eststo bw75: rdrobust acceptable acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe>=r(p50)
eststo bw05: rdrobust acceptable acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe>=r(p50)
eststo bw25: rdrobust acceptable acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe>=r(p50)
eststo bwIK: rdrobust acceptable acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum acceptable if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}lintri_acc_1st_highVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


********************************************success 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT 
eststo bw10: rdrobust success_a2_2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 acc_bind, h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean) 

esttab using ${rdd_output}ittlinuni_acc_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust success_a2_2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 acc_bind, h(3.82) kernel(tri) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2<r(p50)
eststo bw10: rdrobust success_a2_2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2<r(p50)
eststo bw75: rdrobust success_a2_2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2<r(p50)
eststo bw05: rdrobust success_a2_2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2<r(p50)
eststo bw25: rdrobust success_a2_2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2<r(p50)
eststo bwIK: rdrobust success_a2_2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_suc2_lowVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2>=r(p50)
eststo bw10: rdrobust success_a2_2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2>=r(p50)
eststo bw75: rdrobust success_a2_2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2>=r(p50)
eststo bw05: rdrobust success_a2_2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2>=r(p50)
eststo bw25: rdrobust success_a2_2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2>=r(p50)
eststo bwIK: rdrobust success_a2_2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_suc2_highVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


*school-by-year FEs
eststo clear
*triangle kernel low VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe<r(p50)
eststo bw10: rdrobust success_a2_2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe<r(p50)
eststo bw75: rdrobust success_a2_2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe<r(p50)
eststo bw05: rdrobust success_a2_2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe<r(p50)
eststo bw25: rdrobust success_a2_2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe<r(p50)
eststo bwIK: rdrobust success_a2_2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_suc2_lowVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe>=r(p50)
eststo bw10: rdrobust success_a2_2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe>=r(p50)
eststo bw75: rdrobust success_a2_2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe>=r(p50)
eststo bw05: rdrobust success_a2_2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe>=r(p50)
eststo bw25: rdrobust success_a2_2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe>=r(p50)
eststo bwIK: rdrobust success_a2_2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_suc2_highVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace



********************************************successin 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust successin2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust successin2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust successin2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust successin2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2<r(p50)
eststo bw10: rdrobust successin2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2<r(p50)
eststo bw75: rdrobust successin2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2<r(p50)
eststo bw05: rdrobust successin2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2<r(p50)
eststo bw25: rdrobust successin2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2<r(p50)
eststo bwIK: rdrobust successin2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_in2_lowVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2>=r(p50)
eststo bw10: rdrobust successin2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2>=r(p50)
eststo bw75: rdrobust successin2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2>=r(p50)
eststo bw05: rdrobust successin2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2>=r(p50)
eststo bw25: rdrobust successin2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2>=r(p50)
eststo bwIK: rdrobust successin2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_in2_highVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe<r(p50)
eststo bw10: rdrobust successin2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe<r(p50)
eststo bw75: rdrobust successin2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe<r(p50)
eststo bw05: rdrobust successin2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe<r(p50)
eststo bw25: rdrobust successin2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe<r(p50)
eststo bwIK: rdrobust successin2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_in2_lowVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe>=r(p50)
eststo bw10: rdrobust successin2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe>=r(p50)
eststo bw75: rdrobust successin2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe>=r(p50)
eststo bw05: rdrobust successin2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe>=r(p50)
eststo bw25: rdrobust successin2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe>=r(p50)
eststo bwIK: rdrobust successin2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_in2_highVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


********************************************move in 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust movein2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust movein2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust movein2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust movein2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Successful move out district 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust successout2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust successout2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 acc_bind, h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust successout2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust successout2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2<r(p50)
eststo bw10: rdrobust successout2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2<r(p50)
eststo bw75: rdrobust successout2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2<r(p50)
eststo bw05: rdrobust successout2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2<r(p50)
eststo bw25: rdrobust successout2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2<r(p50)
eststo bwIK: rdrobust successout2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_out2_lowVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2>=r(p50)
eststo bw10: rdrobust successout2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2>=r(p50)
eststo bw75: rdrobust successout2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2>=r(p50)
eststo bw05: rdrobust successout2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2>=r(p50)
eststo bw25: rdrobust successout2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2>=r(p50)
eststo bwIK: rdrobust successout2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_out2_highVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe<r(p50)
eststo bw10: rdrobust successout2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe<r(p50)
eststo bw75: rdrobust successout2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe<r(p50)
eststo bw05: rdrobust successout2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe<r(p50)
eststo bw25: rdrobust successout2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe<r(p50)
eststo bwIK: rdrobust successout2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_out2_lowVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe>=r(p50)
eststo bw10: rdrobust successout2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe>=r(p50)
eststo bw75: rdrobust successout2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe>=r(p50)
eststo bw05: rdrobust successout2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe>=r(p50)
eststo bw25: rdrobust successout2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe>=r(p50)
eststo bwIK: rdrobust successout2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_out2_highVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


********************************************Percent chg salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust sal_2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust sal_2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Percent chg adj salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust adjsal_2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust adjsal_2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Retained 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust retained2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust retained2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2<r(p50)
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2<r(p50)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2<r(p50)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2<r(p50)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2<r(p50)
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ret2_lowVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2>=r(p50)
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2>=r(p50)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2>=r(p50)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2>=r(p50)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2>=r(p50)
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ret2_highVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe<r(p50)
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe<r(p50)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe<r(p50)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe<r(p50)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe<r(p50)
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ret2_lowVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe>=r(p50)
eststo bw10: rdrobust retained2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe>=r(p50)
eststo bw75: rdrobust retained2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe>=r(p50)
eststo bw05: rdrobust retained2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe>=r(p50)
eststo bw25: rdrobust retained2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe>=r(p50)
eststo bwIK: rdrobust retained2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ret2_highVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


********************************************Leave TPS 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust leave2 acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust leave2 acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust leave2 acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust leave2 acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Change in log adj salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust dl_adj_total_2yr acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust dl_adj_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2<r(p50)
eststo bw10: rdrobust dl_adj_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2<r(p50)
eststo bw75: rdrobust dl_adj_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2<r(p50)
eststo bw05: rdrobust dl_adj_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2<r(p50)
eststo bw25: rdrobust dl_adj_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2<r(p50)
eststo bwIK: rdrobust dl_adj_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_a_sal2_lowVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2>=r(p50)
eststo bw10: rdrobust dl_adj_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2>=r(p50)
eststo bw75: rdrobust dl_adj_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2>=r(p50)
eststo bw05: rdrobust dl_adj_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2>=r(p50)
eststo bw25: rdrobust dl_adj_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2>=r(p50)
eststo bwIK: rdrobust dl_adj_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_a_sal2_highVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe<r(p50)
eststo bw10: rdrobust dl_adj_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe<r(p50)
eststo bw75: rdrobust dl_adj_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe<r(p50)
eststo bw05: rdrobust dl_adj_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe<r(p50)
eststo bw25: rdrobust dl_adj_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe<r(p50)
eststo bwIK: rdrobust dl_adj_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_a_sal2_lowVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe>=r(p50)
eststo bw10: rdrobust dl_adj_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe>=r(p50)
eststo bw75: rdrobust dl_adj_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe>=r(p50)
eststo bw05: rdrobust dl_adj_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe>=r(p50)
eststo bw25: rdrobust dl_adj_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe>=r(p50)
eststo bwIK: rdrobust dl_adj_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_a_sal2_highVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace



********************************************Change in log salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust dl_total_2yr acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust dl_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2<r(p50)
eststo bw10: rdrobust dl_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2<r(p50)
eststo bw75: rdrobust dl_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2<r(p50)
eststo bw05: rdrobust dl_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2<r(p50)
eststo bw25: rdrobust dl_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2<r(p50)
eststo bwIK: rdrobust dl_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_sal2_lowVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2>=r(p50)
eststo bw10: rdrobust dl_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2>=r(p50)
eststo bw75: rdrobust dl_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2>=r(p50)
eststo bw05: rdrobust dl_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2>=r(p50)
eststo bw25: rdrobust dl_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2>=r(p50)
eststo bwIK: rdrobust dl_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_sal2_highVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe<r(p50)
eststo bw10: rdrobust dl_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe<r(p50)
eststo bw75: rdrobust dl_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe<r(p50)
eststo bw05: rdrobust dl_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe<r(p50)
eststo bw25: rdrobust dl_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe<r(p50)
eststo bwIK: rdrobust dl_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_sal2_lowVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe>=r(p50)
eststo bw10: rdrobust dl_total_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe>=r(p50)
eststo bw75: rdrobust dl_total_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe>=r(p50)
eststo bw05: rdrobust dl_total_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe>=r(p50)
eststo bw25: rdrobust dl_total_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe>=r(p50)
eststo bwIK: rdrobust dl_total_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_sal2_highVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


********************************************Change in predicted achievement 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(3.46) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_acc_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust d_predict_pass_2yr acc_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr acc_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr acc_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr acc_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr acc_bind, h(3.46) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-3.46 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_acc_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr acc_bind, fuzzy(acceptable) h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_acc_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust d_predict_pass_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_acc_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2<r(p50)
eststo bw10: rdrobust d_predict_pass_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2<r(p50)
eststo bw75: rdrobust d_predict_pass_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2<r(p50)
eststo bw05: rdrobust d_predict_pass_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2<r(p50)
eststo bw25: rdrobust d_predict_pass_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2<r(p50)
eststo bwIK: rdrobust d_predict_pass_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_ach2_lowVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe2 if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe2>=r(p50)
eststo bw10: rdrobust d_predict_pass_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe2>=r(p50)
eststo bw75: rdrobust d_predict_pass_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe2>=r(p50)
eststo bw05: rdrobust d_predict_pass_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe2>=r(p50)
eststo bw25: rdrobust d_predict_pass_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe2 if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe2>=r(p50)
eststo bwIK: rdrobust d_predict_pass_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_ach2_highVA.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


eststo clear
*triangle kernel low VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe<r(p50)
eststo bw10: rdrobust d_predict_pass_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe<r(p50)
eststo bw75: rdrobust d_predict_pass_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe<r(p50)
eststo bw05: rdrobust d_predict_pass_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe<r(p50)
eststo bw25: rdrobust d_predict_pass_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe<r(p50)
eststo bwIK: rdrobust d_predict_pass_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_ach2_lowVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel high VA
preserve
sum st_asyfe if acc_bind>=-10 & acc_bind<=10, d
keep if st_asyfe>=r(p50)
eststo bw10: rdrobust d_predict_pass_2yr acc_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-10 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-7.5 & acc_bind<=7.5, d
keep if st_asyfe>=r(p50)
eststo bw75: rdrobust d_predict_pass_2yr acc_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-7.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-5 & acc_bind<=5, d
keep if st_asyfe>=r(p50)
eststo bw05: rdrobust d_predict_pass_2yr acc_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-2.5 & acc_bind<=2.5, d
keep if st_asyfe>=r(p50)
eststo bw25: rdrobust d_predict_pass_2yr acc_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-2.5 & acc_bind<0
estadd scalar Mean=r(mean)
restore, preserve
sum st_asyfe if acc_bind>=-3.82 & acc_bind<=3.82, d
keep if st_asyfe>=r(p50)
eststo bwIK: rdrobust d_predict_pass_2yr acc_bind, h(3.82) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if acc_bind>=-3.82 & acc_bind<0
estadd scalar Mean=r(mean)
restore

esttab using ${rdd_output}ittlintri_acc_ch_ach2_highVA_sby.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace



****************SUR Acceptable******************

eststo clear
*10 Bandwidth no asian
eststo bw10: sureg	(sex acc_above acc_bind acc_above_bind) ///
		(black acc_above acc_bind acc_above_bind) ///
		(hispanic acc_above acc_bind acc_above_bind) ///
		(master acc_above acc_bind acc_above_bind) ///
		(doctorate acc_above acc_bind acc_above_bind) ///
		(tenure2 acc_above acc_bind acc_above_bind) ///
		(experyrs acc_above acc_bind acc_above_bind) ///
		(l_total_pay acc_above acc_bind acc_above_bind) ///
		(passrate acc_above acc_bind acc_above_bind) ///
		(share_male acc_above acc_bind acc_above_bind) ///
		(share_black acc_above acc_bind acc_above_bind) ///
		(share_hisp acc_above acc_bind acc_above_bind) ///
		(share_white acc_above acc_bind acc_above_bind) ///
		(share_disadv acc_above acc_bind acc_above_bind) ///
		(share_title1 acc_above acc_bind acc_above_bind) ///
		(share_lep acc_above acc_bind acc_above_bind) ///
		(share_speced acc_above acc_bind acc_above_bind) ///
		(share_gifted acc_above acc_bind acc_above_bind) ///
		(share_mover acc_above acc_bind acc_above_bind)
				
		test acc_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)
		
		
*5.0 Bandwidth
eststo bw50: sureg	(sex acc_above acc_bind acc_above_bind) ///
		(black acc_above acc_bind acc_above_bind) ///
		(hispanic acc_above acc_bind acc_above_bind) ///
		(master acc_above acc_bind acc_above_bind) ///
		(doctorate acc_above acc_bind acc_above_bind) ///
		(tenure2 acc_above acc_bind acc_above_bind) ///
		(experyrs acc_above acc_bind acc_above_bind) ///
		(l_total_pay acc_above acc_bind acc_above_bind) ///
		(passrate acc_above acc_bind acc_above_bind) ///
		(share_male acc_above acc_bind acc_above_bind) ///
		(share_black acc_above acc_bind acc_above_bind) ///
		(share_hisp acc_above acc_bind acc_above_bind) ///
		(share_white acc_above acc_bind acc_above_bind) ///
		(share_disadv acc_above acc_bind acc_above_bind) ///
		(share_title1 acc_above acc_bind acc_above_bind) ///
		(share_lep acc_above acc_bind acc_above_bind) ///
		(share_speced acc_above acc_bind acc_above_bind) ///
		(share_gifted acc_above acc_bind acc_above_bind) ///
		(share_mover acc_above acc_bind acc_above_bind) if acc_bind>=-5.0 & acc_bind<0.0
		
		test acc_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)

		
*Optimal BW triangular no asian or natamer
eststo bwtri: sureg	(sex acc_above acc_bind acc_above_bind) ///
		(black acc_above acc_bind acc_above_bind) ///
		(hispanic acc_above acc_bind acc_above_bind) ///
		(master acc_above acc_bind acc_above_bind) ///
		(doctorate acc_above acc_bind acc_above_bind) ///
		(tenure2 acc_above acc_bind acc_above_bind) ///
		(experyrs acc_above acc_bind acc_above_bind) ///
		(l_total_pay acc_above acc_bind acc_above_bind) ///
		(passrate acc_above acc_bind acc_above_bind) ///
		(share_male acc_above acc_bind acc_above_bind) ///
		(share_black acc_above acc_bind acc_above_bind) ///
		(share_hisp acc_above acc_bind acc_above_bind) ///
		(share_white acc_above acc_bind acc_above_bind) ///
		(share_disadv acc_above acc_bind acc_above_bind) ///
		(share_title1 acc_above acc_bind acc_above_bind) ///
		(share_lep acc_above acc_bind acc_above_bind) ///
		(share_speced acc_above acc_bind acc_above_bind) ///
		(share_gifted acc_above acc_bind acc_above_bind) ///
		(share_mover acc_above acc_bind acc_above_bind)  if acc_bind>=-3.82 & acc_bind<=3.82
		
		test acc_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)
		
		
esttab using ${rdd_output}accsur.csv, plain b(3) se(3) sfmt(3) scalars(Chi2 pvalue) keep(acc_above) replace
		


log close

}



*****************Recognized RDD*****************
if `recognized_RDD'==1{

use ${working_dir}reclintri_elem_mid_RDD_sample_bw_poly_taks, clear

*save log file of RD results
log using ${working_dir}REC_RDDlog.txt, replace text

*These are optimal bandwidths calculated for uniform and triangular kernel density estimation
	*rec_bw_uni=1.90
	*rec_bw_tri=2.49


preserve
*keep if NPs>1

********************************************school by year FE balance
eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust st_asyfe rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust st_asyfe rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust st_asyfe rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust st_asyfe rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust st_asyfe rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_sbyfe.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


********************************************princpal FE balance
eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust st_asyfe2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust st_asyfe2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust st_asyfe2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust st_asyfe2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust st_asyfe2 rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_pfe.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

restore	
	
********************************************1st stages
eststo clear
*uniform kernel 1st stage
eststo bw10: rdrobust recognized rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust recognized rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust recognized rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust recognized rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust recognized rec_bind, h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-1.90 & rec_bind<00
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_1st.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust recognized rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust recognized rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust recognized rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust recognized rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust recognized rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum recognized if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_1st.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************success 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT 
eststo bw10: rdrobust success_a2_2 rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust success_a2_2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 rec_bind, h(2.49) kernel(tri) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************successin 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust successin2 rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust successin2 rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust successin2 rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust successin2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************move in 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust movein2 rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust movein2 rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust movein2 rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust movein2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Successful move 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust successout2 rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust successout2 rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 rec_bind, h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust successout2 rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust successout2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-7.5 & rec_bind<=17.5
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Percent chg salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust sal_2 rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust sal_2 rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust sal_2 rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust sal_2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Percent chg adj salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust adjsal_2 rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust adjsal_2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Retained 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust retained2 rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust retained2 rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust retained2 rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust retained2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Leave TPS 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust leave2 rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust leave2 rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust leave2 rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust leave2 rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Change in log adj salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust dl_adj_total_2yr rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust dl_adj_total_2yr rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Change in log salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust dl_total_2yr rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust dl_total_2yr rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Change in predicted achievement 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(1.90) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_rec_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust d_predict_pass_2yr rec_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr rec_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr rec_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr rec_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr rec_bind, h(1.90) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-1.9 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_rec_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr rec_bind, fuzzy(recognized) h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_rec_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust d_predict_pass_2yr rec_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-10 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr rec_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-7.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr rec_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr rec_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-2.5 & rec_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr rec_bind, h(2.49) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if rec_bind>=-2.49 & rec_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_rec_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace
*/

****************SUR recognized******************

eststo clear
*10 Bandwidth
eststo bw10: sureg	(sex rec_above rec_bind rec_above_bind) ///
		(black rec_above rec_bind rec_above_bind) ///
		(hispanic rec_above rec_bind rec_above_bind) ///
		(master rec_above rec_bind rec_above_bind) ///
		(doctorate rec_above rec_bind rec_above_bind) ///
		(tenure2 rec_above rec_bind rec_above_bind) ///
		(experyrs rec_above rec_bind rec_above_bind) ///
		(l_total_pay rec_above rec_bind rec_above_bind) ///
		(passrate rec_above rec_bind rec_above_bind) ///
		(share_male rec_above rec_bind rec_above_bind) ///
		(share_black rec_above rec_bind rec_above_bind) ///
		(share_hisp rec_above rec_bind rec_above_bind) ///
		(share_white rec_above rec_bind rec_above_bind) ///
		(share_disadv rec_above rec_bind rec_above_bind) ///
		(share_title1 rec_above rec_bind rec_above_bind) ///
		(share_lep rec_above rec_bind rec_above_bind) ///
		(share_speced rec_above rec_bind rec_above_bind) ///
		(share_gifted rec_above rec_bind rec_above_bind) ///
		(share_mover rec_above rec_bind rec_above_bind)
		
		test rec_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)
	
		
*5.0 Bandwidth
eststo bw50: sureg	(sex rec_above rec_bind rec_above_bind) ///
		(black rec_above rec_bind rec_above_bind) ///
		(hispanic rec_above rec_bind rec_above_bind) ///
		(master rec_above rec_bind rec_above_bind) ///
		(doctorate rec_above rec_bind rec_above_bind) ///
		(tenure2 rec_above rec_bind rec_above_bind) ///
		(experyrs rec_above rec_bind rec_above_bind) ///
		(l_total_pay rec_above rec_bind rec_above_bind) ///
		(passrate rec_above rec_bind rec_above_bind) ///
		(share_male rec_above rec_bind rec_above_bind) ///
		(share_black rec_above rec_bind rec_above_bind) ///
		(share_hisp rec_above rec_bind rec_above_bind) ///
		(share_white rec_above rec_bind rec_above_bind) ///
		(share_disadv rec_above rec_bind rec_above_bind) ///
		(share_title1 rec_above rec_bind rec_above_bind) ///
		(share_lep rec_above rec_bind rec_above_bind) ///
		(share_speced rec_above rec_bind rec_above_bind) ///
		(share_gifted rec_above rec_bind rec_above_bind) ///
		(share_mover rec_above rec_bind rec_above_bind) if rec_bind>=-5.0 & rec_bind<0.0
		
		test rec_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)
		
		
*Optimal BW triangular
eststo bwtri: sureg	(sex rec_above rec_bind rec_above_bind) ///
		(black rec_above rec_bind rec_above_bind) ///
		(hispanic rec_above rec_bind rec_above_bind) ///
		(master rec_above rec_bind rec_above_bind) ///
		(doctorate rec_above rec_bind rec_above_bind) ///
		(tenure2 rec_above rec_bind rec_above_bind) ///
		(experyrs rec_above rec_bind rec_above_bind) ///
		(l_total_pay rec_above rec_bind rec_above_bind) ///
		(passrate rec_above rec_bind rec_above_bind) ///
		(share_male rec_above rec_bind rec_above_bind) ///
		(share_black rec_above rec_bind rec_above_bind) ///
		(share_hisp rec_above rec_bind rec_above_bind) ///
		(share_white rec_above rec_bind rec_above_bind) ///
		(share_disadv rec_above rec_bind rec_above_bind) ///
		(share_title1 rec_above rec_bind rec_above_bind) ///
		(share_lep rec_above rec_bind rec_above_bind) ///
		(share_speced rec_above rec_bind rec_above_bind) ///
		(share_gifted rec_above rec_bind rec_above_bind) ///
		(share_mover rec_above rec_bind rec_above_bind) if rec_bind>=-2.49 & rec_bind<=2.49
		
		test rec_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)

		
esttab using ${rdd_output}recsur.csv, plain b(3) se(3) sfmt(3) scalars(Chi2 pvalue) keep(rec_above) replace
		


log close

}



*****************Exemplary RDD*****************
if `exemplary_RDD'==1{
use ${working_dir}exelintri_elem_mid_RDD_sample_bw_poly_taks, clear

*save log file of RD results
log using ${working_dir}EXE_RDDlog.txt, replace text


*These are optimal bandwidths calculated for uniform and triangular kernel density estimation
	*exe_bw_uni=2.79
	*exe_bw_tri=3.18

preserve
*keep if NPs>1

********************************************school by year FE balance
eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust st_asyfe exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust st_asyfe exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust st_asyfe exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust st_asyfe exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust st_asyfe exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_sbyfe.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace


********************************************princpal FE balance
eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust st_asyfe2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust st_asyfe2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust st_asyfe2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust st_asyfe2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust st_asyfe2 exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum st_asyfe2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_pfe.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

restore	
	
********************************************1st stages
eststo clear
*uniform kernel 1st stage
eststo bw10: rdrobust exemplary exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust exemplary exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust exemplary exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust exemplary exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust exemplary exe_bind, h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_1st.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*triangle kernel 1st stage
eststo bw10: rdrobust exemplary exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust exemplary exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust exemplary exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust exemplary exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust exemplary exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum exemplary if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_1st.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************success 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT 
eststo bw10: rdrobust success_a2_2 exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust success_a2_2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust success_a2_2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust success_a2_2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust success_a2_2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust success_a2_2 exe_bind, h(3.18) kernel(tri) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum success_a2_2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_suc2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************successin 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust successin2 exe_bind, fuzzy(exemplary) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 exe_bind, fuzzy(exemplary) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 exe_bind, fuzzy(exemplary) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 exe_bind, fuzzy(exemplary) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust successin2 exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust successin2 exe_bind, fuzzy(exemplary) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 exe_bind, fuzzy(exemplary) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 exe_bind, fuzzy(exemplary) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 exe_bind, fuzzy(exemplary) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust successin2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successin2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successin2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successin2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successin2 exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successin2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_in2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************move in 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust movein2 exe_bind, fuzzy(exemplary) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 exe_bind, fuzzy(exemplary) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 exe_bind, fuzzy(exemplary) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 exe_bind, fuzzy(exemplary) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust movein2 exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust movein2 exe_bind, fuzzy(exemplary) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 exe_bind, fuzzy(exemplary) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 exe_bind, fuzzy(exemplary) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 exe_bind, fuzzy(exemplary) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust movein2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust movein2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust movein2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust movein2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust movein2 exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum movein2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_movin2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Successful move 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust successout2 exe_bind, fuzzy(exemplary) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 exe_bind, fuzzy(exemplary) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 exe_bind, fuzzy(exemplary) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 exe_bind, fuzzy(exemplary) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust successout2 exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 exe_bind, h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust successout2 exe_bind, fuzzy(exemplary) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 exe_bind, fuzzy(exemplary) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 exe_bind, fuzzy(exemplary) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 exe_bind, fuzzy(exemplary) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust successout2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust successout2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust successout2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust successout2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust successout2 exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum successout2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_out2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Percent chg salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust sal_2 exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust sal_2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust sal_2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust sal_2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust sal_2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust sal_2 exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum sal_2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Percent chg adj salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust adjsal_2 exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust adjsal_2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust adjsal_2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust adjsal_2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust adjsal_2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust adjsal_2 exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum adjsal_2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_adjsal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Retained 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust retained2 exe_bind, fuzzy(exemplary) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 exe_bind, fuzzy(exemplary) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 exe_bind, fuzzy(exemplary) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 exe_bind, fuzzy(exemplary) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust retained2 exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust retained2 exe_bind, fuzzy(exemplary) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 exe_bind, fuzzy(exemplary) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 exe_bind, fuzzy(exemplary) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 exe_bind, fuzzy(exemplary) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust retained2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust retained2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust retained2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust retained2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust retained2 exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum retained2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_ret2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Leave TPS 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust leave2 exe_bind, fuzzy(exemplary) h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 exe_bind, fuzzy(exemplary) h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 exe_bind, fuzzy(exemplary) h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 exe_bind, fuzzy(exemplary) h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust leave2 exe_bind, h(10 ) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 exe_bind, h(7.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 exe_bind, h(5.0) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 exe_bind, h(2.5) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust leave2 exe_bind, fuzzy(exemplary) h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 exe_bind, fuzzy(exemplary) h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 exe_bind, fuzzy(exemplary) h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 exe_bind, fuzzy(exemplary) h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust leave2 exe_bind, h(10 ) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust leave2 exe_bind, h(7.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust leave2 exe_bind, h(5.0) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust leave2 exe_bind, h(2.5) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust leave2 exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum leave2 if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_leave2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Change in log adj salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(10 )      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(7.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(5.0)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(2.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust dl_adj_total_2yr exe_bind, h(10 )      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr exe_bind, h(7.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr exe_bind, h(5.0)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr exe_bind, h(2.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(10 )      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(7.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(5.0)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(2.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust dl_adj_total_2yr exe_bind, h(10 )      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_adj_total_2yr exe_bind, h(7.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_adj_total_2yr exe_bind, h(5.0)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_adj_total_2yr exe_bind, h(2.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_adj_total_2yr exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_adj_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_ch_a_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Change in log salary 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(10 )      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(7.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(5.0)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(2.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust dl_total_2yr exe_bind, h(10 )      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr exe_bind, h(7.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr exe_bind, h(5.0)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr exe_bind, h(2.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(10 )      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(7.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(5.0)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(2.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust dl_total_2yr exe_bind, h(10 )      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust dl_total_2yr exe_bind, h(7.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust dl_total_2yr exe_bind, h(5.0)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust dl_total_2yr exe_bind, h(2.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust dl_total_2yr exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum dl_total_2yr if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_ch_sal2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

********************************************Change in predicted achievement 2yr
eststo clear
*uniform kernel LATE
eststo bw10: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(10 )      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(7.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(5.0)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(2.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(2.79) kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}linuni_exe_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*uniform kernel ITT
eststo bw10: rdrobust d_predict_pass_2yr exe_bind, h(10 )      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr exe_bind, h(7.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr exe_bind, h(5.0)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr exe_bind, h(2.5)      kernel(uni) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr exe_bind, h(2.79) kernel(uni) vce(cluster district) 
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-2.79 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlinuni_exe_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel LATE
eststo bw10: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(10 )      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(7.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(5.0)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(2.5)      kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr exe_bind, fuzzy(exemplary) h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}lintri_exe_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace

eststo clear
*trianglular kernel ITT
eststo bw10: rdrobust d_predict_pass_2yr exe_bind, h(10 ) kernel(tri)      vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-10 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw75: rdrobust d_predict_pass_2yr exe_bind, h(7.5) kernel(tri)      vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-7.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw05: rdrobust d_predict_pass_2yr exe_bind, h(5.0) kernel(tri)      vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bw25: rdrobust d_predict_pass_2yr exe_bind, h(2.5) kernel(tri)      vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-2.5 & exe_bind<0
estadd scalar Mean=r(mean)
eststo bwIK: rdrobust d_predict_pass_2yr exe_bind, h(3.18) kernel(tri) vce(cluster district)
estadd scalar Obs=e(N_h_l)+e(N_h_r)
sum d_predict_pass_2yr if exe_bind>=-3.18 & exe_bind<0
estadd scalar Mean=r(mean)

esttab using ${rdd_output}ittlintri_exe_ch_ach2.csv, plain b(3) se(3) sfmt(3) scalars(Mean Obs) star(* 0.10 ** 0.05 *** 0.01) replace
*/

****************SUR exemplary******************

eststo clear
*10 Bandwidth
eststo bw10: sureg	(sex exe_above exe_bind exe_above_bind) ///
		(black exe_above exe_bind exe_above_bind) ///
		(hispanic exe_above exe_bind exe_above_bind) ///
		(master exe_above exe_bind exe_above_bind) ///
		(doctorate exe_above exe_bind exe_above_bind) ///
		(tenure2 exe_above exe_bind exe_above_bind) ///
		(experyrs exe_above exe_bind exe_above_bind) ///
		(l_total_pay exe_above exe_bind exe_above_bind) ///
		(passrate exe_above exe_bind exe_above_bind) ///
		(share_male exe_above exe_bind exe_above_bind) ///
		(share_black exe_above exe_bind exe_above_bind) ///
		(share_hisp exe_above exe_bind exe_above_bind) ///
		(share_white exe_above exe_bind exe_above_bind) ///
		(share_disadv exe_above exe_bind exe_above_bind) ///
		(share_title1 exe_above exe_bind exe_above_bind) ///
		(share_lep exe_above exe_bind exe_above_bind) ///
		(share_speced exe_above exe_bind exe_above_bind) ///
		(share_gifted exe_above exe_bind exe_above_bind) ///
		(share_mover exe_above exe_bind exe_above_bind)
		
		test exe_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)
				
		
*5.0 Bandwidth
eststo bw50: sureg	(sex exe_above exe_bind exe_above_bind) ///
		(black exe_above exe_bind exe_above_bind) ///
		(hispanic exe_above exe_bind exe_above_bind) ///
		(master exe_above exe_bind exe_above_bind) ///
		(doctorate exe_above exe_bind exe_above_bind) ///
		(tenure2 exe_above exe_bind exe_above_bind) ///
		(experyrs exe_above exe_bind exe_above_bind) ///
		(l_total_pay exe_above exe_bind exe_above_bind) ///
		(passrate exe_above exe_bind exe_above_bind) ///
		(share_male exe_above exe_bind exe_above_bind) ///
		(share_black exe_above exe_bind exe_above_bind) ///
		(share_hisp exe_above exe_bind exe_above_bind) ///
		(share_white exe_above exe_bind exe_above_bind) ///
		(share_disadv exe_above exe_bind exe_above_bind) ///
		(share_title1 exe_above exe_bind exe_above_bind) ///
		(share_lep exe_above exe_bind exe_above_bind) ///
		(share_speced exe_above exe_bind exe_above_bind) ///
		(share_gifted exe_above exe_bind exe_above_bind) ///
		(share_mover exe_above exe_bind exe_above_bind) if exe_bind>=-5.0 & exe_bind<0.0
		
		test exe_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)

		
*Optimal BW triangular
eststo bwtri: sureg	(sex exe_above exe_bind exe_above_bind) ///
		(black exe_above exe_bind exe_above_bind) ///
		(hispanic exe_above exe_bind exe_above_bind) ///
		(master exe_above exe_bind exe_above_bind) ///
		(doctorate exe_above exe_bind exe_above_bind) ///
		(tenure2 exe_above exe_bind exe_above_bind) ///
		(experyrs exe_above exe_bind exe_above_bind) ///
		(l_total_pay exe_above exe_bind exe_above_bind) ///
		(passrate exe_above exe_bind exe_above_bind) ///
		(share_male exe_above exe_bind exe_above_bind) ///
		(share_black exe_above exe_bind exe_above_bind) ///
		(share_hisp exe_above exe_bind exe_above_bind) ///
		(share_white exe_above exe_bind exe_above_bind) ///
		(share_disadv exe_above exe_bind exe_above_bind) ///
		(share_title1 exe_above exe_bind exe_above_bind) ///
		(share_lep exe_above exe_bind exe_above_bind) ///
		(share_speced exe_above exe_bind exe_above_bind) ///
		(share_gifted exe_above exe_bind exe_above_bind) ///
		(share_mover exe_above exe_bind exe_above_bind) if exe_bind>=-3.18 & exe_bind<=3.18
		
		test exe_above
		estadd scalar Chi2=r(chi2)
		estadd scalar pvalue=r(p)

		
esttab using ${rdd_output}exesur.csv, plain b(3) se(3) sfmt(3) scalars(Chi2 pvalue) keep(exe_above) replace
		


log close

}
if `covarregs'==1 {

local covars "share_black share_white share_hisp share_disadv share_gifted share_speced black hispanic white tenure2 experyrs bachelor doctorate sex"

*ACCEPTABLE
use ${working_dir}acclintri_elem_mid_RDD_sample_bw_poly_taks, clear

*redefine acceptable so it means that campus received AT LEAST AN ACCEPTABLE RATING
replace acceptable=1 if recognized==1
replace acceptable=1 if exemplary==1

*restrict sample to include only the observatins that are within 10 percentage points of the threshold
keep if acc_bind>=-10 & acc_bind<=10

*save log file of RD results
log using ${working_dir}ACC_RDD_covarslog.txt, replace text

*First Stages with bandwith of 10
reg acceptable acc_above acc_bind acc_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}first_RD_acc_cov.xls, keep(acc_above) ctitle(Comp Success) replace
reg acceptable acc_above acc_bind acc_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}first_RD_acc_cov.xls, keep(acc_above) ctitle(Within Success) append
reg acceptable acc_above acc_bind acc_above_bind `covars' if transition2!=4, vce(cluster district)
outreg2 using ${rdd_output}first_RD_acc_cov.xls, keep(acc_above) ctitle(Salary Chg) append

*ITT with bandwith of 10
reg success_a2_2 acc_above acc_bind acc_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}itt_RD_acc_cov.xls, keep(acc_above) ctitle(Comp Success) replace
reg successin2 acc_above acc_bind acc_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}itt_RD_acc_cov.xls, keep(acc_above) ctitle(Within Success) append
reg sal_2 acc_above acc_bind acc_above_bind `covars' if transition2!=4, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_acc_cov.xls, keep(acc_above) ctitle(Salary Chg) append

*First Stages with IK bandwith 
reg acceptable acc_above acc_bind acc_above_bind `covars' if acc_IK_a2_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_acc_cov_ik.xls, keep(acc_above) ctitle(Comp Success) replace
reg acceptable acc_above acc_bind acc_above_bind `covars' if acc_IK_in_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_acc_cov_ik.xls, keep(acc_above) ctitle(Within Success) append
reg acceptable acc_above acc_bind acc_above_bind `covars' if transition2!=4 & acc_IK_sal_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_acc_cov_ik.xls, keep(acc_above) ctitle(Salary Chg) append

*ITT with IK bandwith
reg success_a2_2 acc_above acc_bind acc_above_bind `covars' if acc_IK_a2_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_acc_cov_ik.xls, keep(acc_above) ctitle(Comp Success) replace
reg successin2 acc_above acc_bind acc_above_bind `covars' if acc_IK_in_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_acc_cov_ik.xls, keep(acc_above) ctitle(Within Success) append
reg sal_2 acc_above acc_bind acc_above_bind `covars' if transition2!=4 & acc_IK_sal_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_acc_cov_ik.xls, keep(acc_above) ctitle(Salary Chg) append

log close


*RECOGNIZED
use ${working_dir}reclintri_elem_mid_RDD_sample_bw_poly_taks, clear

*redefine acceptable so it means that campus received AT LEAST AN ACCEPTABLE RATING
replace recognized=1 if exemplary==1

*restrict sample to include only the observatins that are within 10 percentage points of the threshold
keep if rec_bind>=-10 & rec_bind<=10

*save log file of RD results
log using ${working_dir}REC_RDD_covarslog.txt, replace text

*First Stages with bandwith of 10
reg recognized rec_above rec_bind rec_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}first_RD_rec_cov.xls, keep(rec_above) ctitle(Comp Success) replace
reg recognized rec_above rec_bind rec_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}first_RD_rec_cov.xls, keep(rec_above) ctitle(Within Success) append
reg recognized rec_above rec_bind rec_above_bind `covars' if transition2!=4, vce(cluster district)
outreg2 using ${rdd_output}first_RD_rec_cov.xls, keep(rec_above) ctitle(Salary Chg) append

*ITT with bandwith of 10
reg success_a2_2 rec_above rec_bind rec_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}itt_RD_rec_cov.xls, keep(rec_above) ctitle(Comp Success) replace
reg successin2 rec_above rec_bind rec_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}itt_RD_rec_cov.xls, keep(rec_above) ctitle(Within Success) append
reg sal_2 rec_above rec_bind rec_above_bind `covars' if transition2!=4, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_rec_cov.xls, keep(rec_above) ctitle(Salary Chg) append

*First Stages with IK bandwith 
reg recognized rec_above rec_bind rec_above_bind `covars' if rec_IK_a2_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_rec_cov_ik.xls, keep(rec_above) ctitle(Comp Success) replace
reg recognized rec_above rec_bind rec_above_bind `covars' if rec_IK_in_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_rec_cov_ik.xls, keep(rec_above) ctitle(Within Success) append
reg recognized rec_above rec_bind rec_above_bind `covars' if transition2!=4 & rec_IK_sal_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_rec_cov_ik.xls, keep(rec_above) ctitle(Salary Chg) append

*ITT with IK bandwith
reg success_a2_2 rec_above rec_bind rec_above_bind `covars' if rec_IK_a2_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_rec_cov_ik.xls, keep(rec_above) ctitle(Comp Success) replace
reg successin2 rec_above rec_bind rec_above_bind `covars' if rec_IK_in_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_rec_cov_ik.xls, keep(rec_above) ctitle(Within Success) append
reg sal_2 rec_above rec_bind rec_above_bind `covars' if transition2!=4 & rec_IK_sal_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_rec_cov_ik.xls, keep(rec_above) ctitle(Salary Chg) append

log close



*EXEMPLARY
use ${working_dir}exelintri_elem_mid_RDD_sample_bw_poly_taks, clear

*restrict sample to include only the observatins that are within 10 percentage points of the threshold
keep if exe_bind>=-10 & exe_bind<=10

*save log file of RD results
log using ${working_dir}EXE_RDD_covarslog.txt, replace text

*First Stages with bandwith of 10
reg exemplary exe_above exe_bind exe_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}first_RD_exe_cov.xls, keep(exe_above) ctitle(Comp Success) replace
reg exemplary exe_above exe_bind exe_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}first_RD_exe_cov.xls, keep(exe_above) ctitle(Within Success) append
reg exemplary exe_above exe_bind exe_above_bind `covars' if transition2!=4, vce(cluster district)
outreg2 using ${rdd_output}first_RD_exe_cov.xls, keep(exe_above) ctitle(Salary Chg) append

*ITT with bandwith of 10
reg success_a2_2 exe_above exe_bind exe_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}itt_RD_exe_cov.xls, keep(exe_above) ctitle(Comp Success) replace
reg successin2 exe_above exe_bind exe_above_bind `covars', vce(cluster district)
outreg2 using ${rdd_output}itt_RD_exe_cov.xls, keep(exe_above) ctitle(Within Success) append
reg sal_2 exe_above exe_bind exe_above_bind `covars' if transition2!=4, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_exe_cov.xls, keep(exe_above) ctitle(Salary Chg) append

*First Stages with IK bandwith 
reg exemplary exe_above exe_bind exe_above_bind `covars' if exe_IK_a2_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_exe_cov_ik.xls, keep(exe_above) ctitle(Comp Success) replace
reg exemplary exe_above exe_bind exe_above_bind `covars' if exe_IK_in_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_exe_cov_ik.xls, keep(exe_above) ctitle(Within Success) append
reg exemplary exe_above exe_bind exe_above_bind `covars' if transition2!=4 & exe_IK_sal_2==1, vce(cluster district)
outreg2 using ${rdd_output}first_RD_exe_cov_ik.xls, keep(exe_above) ctitle(Salary Chg) append

*ITT with IK bandwith
reg success_a2_2 exe_above exe_bind exe_above_bind `covars' if exe_IK_a2_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_exe_cov_ik.xls, keep(exe_above) ctitle(Comp Success) replace
reg successin2 exe_above exe_bind exe_above_bind `covars' if exe_IK_in_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_exe_cov_ik.xls, keep(exe_above) ctitle(Within Success) append
reg sal_2 exe_above exe_bind exe_above_bind `covars' if transition2!=4 & exe_IK_sal_2==1, vce(cluster district)
outreg2 using ${rdd_output}itt_RD_exe_cov_ik.xls, keep(exe_above) ctitle(Salary Chg) append

log close


}
